<?xml version="1.0"?>

<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->


<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    
    <!--Properties-->
    <xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes"/>
    
    <!--Common variables-->
    <xsl:variable name="author_name" select="'INSPIRE Registry team'"/>
    <xsl:variable name="author_email" select="'inspire-registry-info@jrc.ec.europa.eu'"/>
    <xsl:variable name="author_uri" select="'http://inspire.ec.europa.eu/registry'"/>
    
    <xsl:variable name='newline'>&lt;br/&gt;</xsl:variable>
    
    <!--Stylesheet-->
    <xsl:template match="item">
        <feed xmlns="http://www.w3.org/2005/Atom">
            <xsl:variable name="language" select="language/isocode"></xsl:variable>
            <xsl:attribute name="xml:lang">
                <xsl:value-of select="$language"/>
            </xsl:attribute>
            
            <!--Atom id (item uri)-->
            <xsl:element name="id">
                <xsl:value-of select="uri"/>	
            </xsl:element>
            
            <!--Atom title (item label)-->
            <xsl:element name="title">
                <xsl:value-of select="label"/>		
            </xsl:element>
            
            <!--Atom author-->            
            <xsl:element name="author">
                <xsl:element name="name">
                    <xsl:value-of select="$author_name"/>
                </xsl:element>
                <xsl:element name="email">
                    <xsl:value-of select="$author_email"/>
                </xsl:element>
                <xsl:element name="uri">
                    <xsl:value-of select="register/registry/uri"/>
                </xsl:element>	
            </xsl:element>
            
            <!--Atom subtitle (item definition)-->
            <xsl:if test="definition != ''">
                <xsl:element name="subtitle">
                    <xsl:variable name="tmp" select="definition"/>
                    <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                    <xsl:value-of select="$newtext" disable-output-escaping="yes"/>	
                </xsl:element>
            </xsl:if>
            
            <!--Atom category -->
            <xsl:element name="category">
                <xsl:attribute name="term">
                    <xsl:value-of select="itemclass/uriname"/>
                </xsl:attribute>
            </xsl:element>
            
            <!--Atom link to itself -->
            <xsl:element name="link">
                <xsl:attribute name="href">
                    <xsl:value-of select="uri"/>
                </xsl:attribute>                
                <xsl:attribute name="rel">
                    <xsl:text>self</xsl:text>
                </xsl:attribute>
            </xsl:element>
            
            <xsl:if test="thisversion != ''">
                <xsl:element name="link">
                    <xsl:attribute name="href">
                        <xsl:value-of select="thisversion/uri"/>
                    </xsl:attribute>                
                    <xsl:attribute name="rel">
                        <xsl:text>self</xsl:text>
                    </xsl:attribute>
                </xsl:element>   
            </xsl:if>
            
            <xsl:if test="latestversion != ''">
                <xsl:element name="link">
                    <xsl:attribute name="href">
                        <xsl:value-of select="latestversion/uri"/>
                    </xsl:attribute>                
                    <xsl:attribute name="rel">
                        <xsl:text>latest-version</xsl:text>
                    </xsl:attribute>
                </xsl:element>   
            </xsl:if>
            
            <xsl:if test="previousversions != ''">
                <xsl:for-each select="previousversions/version">
                        
                    <xsl:element name="link">
                        <xsl:attribute name="href">
                            <xsl:value-of select="uri"/>
                        </xsl:attribute>                
                        <xsl:attribute name="rel">
                            <xsl:text>version-history</xsl:text>
                        </xsl:attribute>
                    </xsl:element>   
                                     
                </xsl:for-each>
            </xsl:if>
            
            <!-- Reference to the register -->
            <xsl:element name="link">
                <xsl:attribute name="href">
                    <xsl:value-of select="register/uri"/>
                </xsl:attribute>                
                <xsl:attribute name="rel">
                    <xsl:text>collection</xsl:text>
                </xsl:attribute>
            </xsl:element>
            
            <xsl:variable name="codelistFileName" select="concat(codelist/uri,'/',codelist/uriname,'.',$language,'.xml')"/>
        
            <!-- Reference to the codelist -->
            <xsl:element name="link">
                <xsl:attribute name="href">           
                    <xsl:value-of select="codelist/uri"/>
                </xsl:attribute>
                <xsl:attribute name="rel">
                    <xsl:text>up</xsl:text>
                </xsl:attribute>               
            </xsl:element>
            
            <xsl:choose>
                <xsl:when test="predecessors">
                    <xsl:element name="predecessors" >
                        <xsl:for-each select="predecessors/predecessor">
                
                            <xsl:element name="link">
                                <xsl:attribute name="href">               
                                    <xsl:value-of select="uri"/>
                                </xsl:attribute>                
                                <xsl:attribute name="rel">
                                    <xsl:text>previous</xsl:text>
                                </xsl:attribute>
                            </xsl:element>
                            
                        </xsl:for-each>
                    </xsl:element>
                </xsl:when>
                <xsl:otherwise>
                </xsl:otherwise>
            </xsl:choose>
        
            <xsl:choose>
                <xsl:when test="successors">
                    <xsl:element name="successors" >
                        <xsl:for-each select="successors/successor">
                
                            <xsl:element name="link">
                                <xsl:attribute name="href">               
                                    <xsl:value-of select="uri"/>
                                </xsl:attribute>                
                                <xsl:attribute name="rel">
                                    <xsl:text>next</xsl:text>
                                </xsl:attribute>
                            </xsl:element>
                            
                        </xsl:for-each>
                    </xsl:element>
                </xsl:when>
                <xsl:otherwise>
                </xsl:otherwise>
            </xsl:choose>
            
            <!--Atom updated-->
            <xsl:element name="updated">           
                <xsl:choose>
                    <xsl:when test="datelastupdate != ''">
                        <xsl:value-of select="datelastupdate"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="datecreation"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:element> 
                
            <!--External Reference-->
            <xsl:if test="customattributes/customattribute[name/text()='ReferenceSource'] != '' and customattributes/customattribute[name/text()='ReferenceLink'] != ''">
                <xsl:variable name="referenceSource" select="customattributes/customattribute[name/text()='ReferenceSource']/uriname"></xsl:variable>
                <xsl:variable name="referenceLink" select="customattributes/customattribute[name/text()='ReferenceLink']/uriname"></xsl:variable>
 
                <xsl:element name="link">
                    <xsl:attribute name="href">
                        <xsl:value-of select="$referenceLink"/>
                    </xsl:attribute>                
                    <xsl:attribute name="rel">
                        <xsl:text>via</xsl:text>
                    </xsl:attribute>
                </xsl:element>
            </xsl:if>
                
            <xsl:for-each select="children/item">
                <entry>
                    
                    <!--Atom entry id (item uri)-->    
                    <xsl:element name="id">
                        <xsl:value-of select="uri"/>	
                    </xsl:element>
                    
                    <!--Atom entry title (item label)-->    
                    <xsl:element name="title">
                        <xsl:value-of select="label"/>		
                    </xsl:element>
                    
                    <!--Atom entry summary (item definition)-->
                    <xsl:if test="definition != ''">
                        <xsl:element name="summary">
                            <xsl:variable name="tmp" select="definition"/>
                            <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                            <xsl:value-of select="$newtext" disable-output-escaping="yes"/>	
                        </xsl:element>
                    </xsl:if>
                    
                    <!--Atom entry content (item description)-->
                    <xsl:if test="description != ''">
                        <xsl:element name="content">
                            <xsl:variable name="tmp" select="description"/>
                            <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                            <xsl:value-of select="$newtext" disable-output-escaping="yes"/>	
                        </xsl:element>
                    </xsl:if>
                    
                    <!-- Reference to the current item -->
                    <xsl:element name="link">
                        <xsl:attribute name="href">
                            <xsl:value-of select="uri"/>
                        </xsl:attribute>
                        <xsl:attribute name="rel">
                            <xsl:text>self</xsl:text>
                        </xsl:attribute>
                    </xsl:element>
                    
                    <xsl:if test="thisversion != ''">
                        <xsl:element name="link">
                            <xsl:attribute name="href">
                                <xsl:value-of select="thisversion/uri"/>
                            </xsl:attribute>                
                            <xsl:attribute name="rel">
                                <xsl:text>self</xsl:text>
                            </xsl:attribute>
                        </xsl:element>   
                    </xsl:if>
            
                    <xsl:if test="latestversion != ''">
                        <xsl:element name="link">
                            <xsl:attribute name="href">
                                <xsl:value-of select="latestversion/uri"/>
                            </xsl:attribute>                
                            <xsl:attribute name="rel">
                                <xsl:text>latest-version</xsl:text>
                            </xsl:attribute>
                        </xsl:element>   
                    </xsl:if>
            
                    <xsl:if test="previousversions != ''">
                        <xsl:for-each select="previousversions/version">
                        
                            <xsl:element name="link">
                                <xsl:attribute name="href">
                                    <xsl:value-of select="uri"/>
                                </xsl:attribute>                
                                <xsl:attribute name="rel">
                                    <xsl:text>version-history</xsl:text>
                                </xsl:attribute>
                            </xsl:element>   
                                     
                        </xsl:for-each>
                    </xsl:if>
                    
                    <xsl:element name="link">
                        <xsl:attribute name="href">           
                            <xsl:value-of select="codelist/uri"/>
                        </xsl:attribute>
                        <xsl:attribute name="rel">
                            <xsl:text>up</xsl:text>
                        </xsl:attribute>               
                    </xsl:element>
                    
                    <!--Atom category -->
                    <xsl:element name="category">
                        <xsl:attribute name="term">
                            <xsl:value-of select="itemclass/uriname"/>
                        </xsl:attribute>
                    </xsl:element>
                    
                    <xsl:choose>
                        <xsl:when test="predecessors">
                            <xsl:element name="predecessors" >
                                <xsl:for-each select="predecessors/predecessor">
                
                                    <xsl:element name="link">
                                        <xsl:attribute name="href">               
                                            <xsl:value-of select="uri"/>
                                        </xsl:attribute>                
                                        <xsl:attribute name="rel">
                                            <xsl:text>previous</xsl:text>
                                        </xsl:attribute>
                                    </xsl:element>
                            
                                </xsl:for-each>
                            </xsl:element>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
        
                    <xsl:choose>
                        <xsl:when test="successors">
                            <xsl:element name="successors" >
                                <xsl:for-each select="successors/successor">
                
                                    <xsl:element name="link">
                                        <xsl:attribute name="href">               
                                            <xsl:value-of select="uri"/>
                                        </xsl:attribute>                
                                        <xsl:attribute name="rel">
                                            <xsl:text>next</xsl:text>
                                        </xsl:attribute>
                                    </xsl:element>
                            
                                </xsl:for-each>
                            </xsl:element>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                    
                    <!--Atom updated-->
                    <xsl:element name="updated">           
                        <xsl:choose>
                            <xsl:when test="datelastupdate != ''">
                                <xsl:value-of select="datelastupdate"/>
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="datecreation"/>
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:element>
            
                </entry>                    
            </xsl:for-each>       
                
        </feed>
    </xsl:template>
</xsl:stylesheet>