<?xml version="1.0" encoding="UTF-8"?>

<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->


<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"> 
    
    <xsl:include href="dxbox.xsl" />
    <xsl:include href="top_right.xsl" />
    <xsl:include href="footer.xsl" />
    <xsl:include href="res.xsl" />
    
    <!--Properties-->
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    
    <!--Variables & parameters declaration-->
    <xsl:param name="base_db_export_path" />
    <xsl:variable name="base_res_uri" select="item/register/base_uri" />
    <xsl:variable name="language" select="item/language/isocode"/>
    <xsl:variable name="languagefile" select="document(concat('../gui-languages/',$language,'.xml'))" />
    <xsl:variable name='newline'>&lt;br/&gt;</xsl:variable>
    
    <!--Stylesheet-->
    <xsl:template match="/">
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>
        <html>
            <xsl:attribute name="lang">
                <xsl:value-of select="$language" />
            </xsl:attribute>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
                <title>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='codelist-value']"/>
                    <xsl:text>-</xsl:text>
                    <xsl:value-of select="item/label"/>
                </title>
                <xsl:call-template name="res">
                    <xsl:with-param name="base_res_uri" select="item/baseuri"/>
                </xsl:call-template>
            </head>            
            <body>
                <header>
                    <div id="topright">
                        <xsl:call-template name="top_right"/>
                    </div>
                    <div id="breadctxt">
                        <a href="http://ec.europa.eu/index_en.htm">
                            <xsl:value-of select="$languagefile/guilanguage/item[@key='ec']"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a href="http://inspire.ec.europa.eu/">
                            <xsl:value-of select="$languagefile/guilanguage/item[@key='inspire']"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a>
                            <xsl:attribute name="href" >
                                <xsl:value-of select="item/register/registry/uri"/>
                            </xsl:attribute>    
                            <xsl:value-of select="item/register/registry/label"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a>
                            <xsl:attribute name="href" >
                                <xsl:value-of select="item/register/uri"/>
                            </xsl:attribute>
                            <xsl:value-of select="item/register/label"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a>
                            <xsl:attribute name="href">
                                <xsl:value-of select="item/codelist/uri"/>
                            </xsl:attribute>
                            <xsl:value-of select="item/codelist/label" />
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <span>
                            <xsl:value-of select="item/label" />
                        </span>
                    </div>
                </header>
                
                <article class="exp">
                    <xsl:apply-templates select="item"/>
                </article>
                
                <footer>
                    <xsl:call-template name="footer"/>
                </footer>
                
                <xsl:call-template name="dxbox"/>
                
            </body>
        </html>
    </xsl:template>

    <xsl:template match="item">
        
        <h2>
            <xsl:value-of select="label" />
        </h2>
        
        <!--Id and Version-->
        <p>
            <span class="csm">
                <xsl:value-of select="$languagefile/guilanguage/item[@key='id']"/>:</span>  
        </p>
        <div class="dcsm">
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uri"/>       
                </xsl:attribute>    
                <xsl:value-of select="uri"/>
            </a>
        </div>
        
        <xsl:if test="thisversion != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='this-version']"/>:
                </span> 
            </p>
            <div class="dcsm">
                <a>
                    <xsl:attribute name="href">
                        <xsl:value-of select="thisversion/uri"/>       
                    </xsl:attribute>    
                    <xsl:value-of select="thisversion/uri"/>
                </a>
            </div>
        </xsl:if>
        
        <xsl:if test="latestversion != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='latest-version']"/>:
                </span> 
            </p>
            <div class="dcsm">
                <a>
                    <xsl:attribute name="href">
                        <xsl:value-of select="latestversion/uri"/>       
                    </xsl:attribute>    
                    <xsl:value-of select="latestversion/uri"/>
                </a>
            </div>
        </xsl:if>
        
        <xsl:if test="previousversions != ''">
            <p>
                <xsl:choose>
                    <xsl:when test="count(//previousversions/version) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='previous-version']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="previousversions/version/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="previousversions/version/uri"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='previous-versions']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="previousversions/version">
                                    <li>  
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="uri"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </p>
        </xsl:if>
        
        <br/>
        
        <!--Label, Defginition, Description-->
        <xsl:if test="label != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>:
                    <xsl:choose>
                        <xsl:when test="$language != label/@language">
                            <xsl:variable name="notavailable" select="$languagefile/guilanguage/item[@key='not-available-in']"/>   
                            <br/>
                            <span class="sml">
                                <xsl:text>[</xsl:text> 
                                <xsl:value-of select="$notavailable" disable-output-escaping="yes"/>
                                <xsl:text>]</xsl:text>
                            </span>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                </span> 
                <strong>
                    <xsl:value-of select="label" />
                </strong>
            </p>
        </xsl:if>
        
        <xsl:if test="definition != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='definition']"/>:
                    <xsl:choose>
                        <xsl:when test="$language != definition/@language">
                            <xsl:variable name="notavailable" select="$languagefile/guilanguage/item[@key='not-available-in']"/>   
                            <br/>
                            <span class="sml">
                                <xsl:text>[</xsl:text> 
                                <xsl:value-of select="$notavailable" disable-output-escaping="yes"/>
                                <xsl:text>]</xsl:text>
                            </span>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                </span>
            </p>    
            <div class="dcsm">
                <xsl:variable name="tmp" select="definition"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>            
            <div class="clft"></div>
        </xsl:if>
        
        <xsl:if test="description != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='description']"/>:
                    <xsl:choose>
                        <xsl:when test="$language != description/@language">
                            <xsl:variable name="notavailable" select="$languagefile/guilanguage/item[@key='not-available-in']"/>   
                            <br/>
                            <span class="sml">
                                <xsl:text>[</xsl:text> 
                                <xsl:value-of select="$notavailable" disable-output-escaping="yes"/>
                                <xsl:text>]</xsl:text>
                            </span>
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                </span>
            </p>     
            <div class="dcsm">
                <xsl:variable name="tmp" select="description"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>     
            <div class="clft"></div>
        </xsl:if>
        
        <br/>
        
        <!--Custom attributs-->
        <xsl:variable name="codelistFileName">
            <xsl:choose>
                <xsl:when test="document(concat(codelist/uri,'/',codelist/uriname,'.',$language,'.xml'))">
                    <xsl:value-of select="concat(codelist/uri,'/',codelist/uriname,'.',$language,'.xml')" />
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="concat(codelist/uri,'/',codelist/uriname,'.en.xml')" />
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="applicationschemaUri" select="document($codelistFileName)/codelist/applicationschema/@id"/>
        <xsl:variable name="applicationschemaLabel" select="document($codelistFileName)/codelist/applicationschema/label"/>
        
        <xsl:variable name="themeUri" select="document($codelistFileName)/codelist/theme/@id"/>
        <xsl:variable name="themeLabel" select="document($codelistFileName)/codelist/theme/label"/>

        <xsl:if test="$themeUri != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='theme']" />
                    :
                </span>
                <a>
                    <xsl:attribute name="href" select="$themeUri" />
                    <xsl:value-of select="$themeLabel" />
                </a>
            </p>
        </xsl:if>
        
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='application-schema']"/>:</span>     
            <a>
                <xsl:attribute name="href" select="$applicationschemaUri"/>
                <xsl:value-of select="$applicationschemaLabel"/>
            </a>                   
        </p>
   
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='code-list']"/>:</span> 
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="codelist/uri"/>   
                </xsl:attribute>    
                <xsl:value-of select="codelist/label"/>  
            </a>
        </p>
        
        <xsl:if test="customattributes/customattribute[name/text()='ReferenceSource'] != '' and customattributes/customattribute[name/text()='ReferenceLink'] != ''">
            <xsl:variable name="referenceSource" select="customattributes/customattribute[name/text()='ReferenceSource']/uriname"></xsl:variable>
            <xsl:variable name="referenceLink" select="customattributes/customattribute[name/text()='ReferenceLink']/uriname"></xsl:variable>
            
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='reference-source']"/>:</span> 
                <a>
                    <xsl:attribute name="href">
                        <xsl:value-of select="$referenceLink"/>
                    </xsl:attribute>    
                    <xsl:value-of select="$referenceSource"/>  
                </a>
            </p>
            
        </xsl:if>
        
        <br/>
        
        <!--Status, Predecessor, Successor, Parent-->
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='status']"/>:</span>
            <xsl:variable name="status_uri" select="status/uri"/>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="status/baseuri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="status/uriname"/>
                </xsl:attribute>    
                <xsl:value-of select="status/label"/>
            </a>
        </p>
        
        <xsl:if test="parent != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='parent']"/>:</span>
                <a>
                    <xsl:attribute name="href">
                        <xsl:value-of select="parent/uri"/>
                    </xsl:attribute>    
                    <xsl:value-of select="parent/label"/>
                </a>
            </p>
        </xsl:if>
        
        <xsl:if test="predecessors != ''">
            <p>
                <xsl:choose>
                    <xsl:when test="count(//predecessors/predecessor) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='predecessor']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="predecessors/predecessor/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="predecessors/predecessor/uri"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='predecessors']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="predecessors/predecessor">
                                    <li>
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="uri"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </p>
        </xsl:if>
        
        <xsl:if test="successors != ''">
            <p>
                <xsl:choose>
                    <xsl:when test="count(//successors/successor) = 1">
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='successor']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <a>
                                <xsl:attribute name="href">
                                    <xsl:value-of select="successors/successor/uri"/>       
                                </xsl:attribute>    
                                <xsl:value-of select="successors/successor/uri"/>
                            </a>
                        </div>
                    </xsl:when>
                    <xsl:otherwise>
                        <p>
                            <span class="csm">
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='successors']"/>:</span>
                        </p> 
                        <div class="dcsm"> 
                            <ul>
                                <xsl:for-each select="successors/successor">
                                    <li>  
                                        <a>
                                            <xsl:attribute name="href">
                                                <xsl:value-of select="uri"/>       
                                            </xsl:attribute>    
                                            <xsl:value-of select="uri"/>
                                        </a>
                                    </li>             
                                </xsl:for-each>
                            </ul>
                        </div>
                    </xsl:otherwise>
                </xsl:choose>
            </p>
        </xsl:if>
        
        <br/>
        
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='other-formats']"/>:</span>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uristandard"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="uriname"/>
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$language"/>
                    <xsl:text>.xml</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt xml</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'XML'"/>
            </a>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uristandard"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="uriname"/>
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$language"/>
                    <xsl:text>.json</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt json</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'JSON'"/>
            </a>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uristandard"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="uriname"/>
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$language"/>
                    <xsl:text>.atom</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt atom</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'Atom'"/>
            </a>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uristandard" />
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="uriname" />
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$language" />
                    <xsl:text>.rdf</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt rdf</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'RDF/XML'"/>
                <sup>beta</sup>
            </a>
        </p>
        
        <br/>        
        <br/>
        
        <xsl:if test="children != ''">
            <h3>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='narrower']"/>
            </h3>
        
            <div class="tb_cont">
                <table id= "tbl">
                    <thead>
                        <tr>
                            <th>
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>
                            </th>
                            <th>
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='status']"/>
                            </th>
                        </tr>  
                    </thead>          
                    <xsl:for-each select="children/item">                
                        <tr>
                            <td>
                                <a>
                                    <xsl:attribute name="href" select="uri"/>
                                    <xsl:value-of select="label"/>
                                </a>
                            </td>   
                            <td width="15%">
                                <a>
                                    <xsl:attribute name="href">
                                        <xsl:value-of select="status/baseuri"/>
                                        <xsl:text>/</xsl:text>
                                        <xsl:value-of select="status/uriname"/>
                                    </xsl:attribute>    
                                    <xsl:value-of select="status/label"/>
                                </a>
                            </td>                    
                        </tr>
                    </xsl:for-each>
                </table>
            </div>
        </xsl:if>
        
    </xsl:template>
</xsl:stylesheet>