<?xml version="1.0" encoding="UTF-8"?>
<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"> 
    
    <xsl:include href="dxbox.xsl" />
    <xsl:include href="top_right.xsl" />
    <xsl:include href="footer.xsl" />
    <xsl:include href="res.xsl" />
    
    <!--Output settings-->
    <xsl:output method="html" encoding="UTF-8" indent="yes"/>
    
    <!--Variables & parameters declaration-->
    <xsl:param name="base_db_export_path" />
    <xsl:variable name="language" select="registry/language/isocode"/>
        
    <xsl:variable name="languagefile" select="document(concat('../gui-languages/',$language,'.xml'))" />
    
    <xsl:variable name='newline'>&lt;br/&gt;</xsl:variable>
    
    <xsl:template match="/">
        <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html&gt;</xsl:text>   
        <html>
            <xsl:attribute name="lang">
                <xsl:value-of select="$language" />
            </xsl:attribute>
            <head>
                <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
                <title>
                    <xsl:value-of select="registry/label" />
                </title>
                <xsl:call-template name="res">
                    <xsl:with-param name="base_res_uri" select="registry/baseuri"/>
                </xsl:call-template>
            </head>            
            <body>
                <header>
                    <div id="topright">
                        <xsl:call-template name="top_right"/>
                    </div>
                    <div id="breadctxt">
                        <a href="http://ec.europa.eu/index_en.htm">
                            <xsl:value-of select="$languagefile/guilanguage/item[@key='ec']"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <a href="http://inspire.ec.europa.eu/">
                            <xsl:value-of select="$languagefile/guilanguage/item[@key='inspire']"/>
                        </a>
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>nbsp;
                        <xsl:text disable-output-escaping="yes">&amp;</xsl:text>gt;
                        <span>
                            <xsl:value-of select="registry/label" />
                        </span>
                    </div>
                </header>
                
                <article class="exp">
                    <xsl:apply-templates select="registry"/>
                </article>
                
                <footer>
                    <xsl:call-template name="footer"/>
                </footer>
                
                <xsl:call-template name="dxbox"/>                
            </body>
        </html>
    </xsl:template>

    <xsl:template match="registry">     
        <h2>
            <xsl:value-of select="label" />
        </h2>
                
        <xsl:variable name="id" select="uri"/>
        
        <p>
            <span class="csm">
                <xsl:value-of select="$languagefile/guilanguage/item[@key='id']"/>:</span>  
        </p>
        <div class="dcsm">
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uri"/>       
                </xsl:attribute>    
                <xsl:value-of select="uri"/>
            </a>
        </div>
        
        <br/>
        
        <xsl:if test="label != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>:</span> 
                <strong>
                    <xsl:value-of select="label" />
                </strong>
            </p>
        </xsl:if>        
        <xsl:if test="registrymanager != ''">
            <p>
                <span>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='registry-manager']"/>:</span> 
                <strong>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='ec']"/>
                    <xsl:text>, </xsl:text>
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='jrc']"/>
                </strong>
            </p>
        </xsl:if>     
        <xsl:if test="definition != ''">
            <p>
                <span class="csm">
                    <xsl:value-of select="$languagefile/guilanguage/item[@key='content-summary']"/>:</span>
            </p> 
            <div class="dcsm">
                <xsl:variable name="tmp" select="definition"/>
                <xsl:variable name="newtext" select="replace($tmp,'\\n',$newline)"/>
                <xsl:value-of select="$newtext" disable-output-escaping="yes"/>
            </div>            
        </xsl:if>
        
        <br/>
        
        <p>
            <span>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='other-formats']"/>:</span>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="uriname"/>
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$language"/>
                    <xsl:text>.xml</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt xml</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'XML'"/>
            </a>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="uriname"/> 
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$language"/>
                    <xsl:text>.json</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt json</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'JSON'"/>
            </a>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uri"/>
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="uriname"/>
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$language"/>
                    <xsl:text>.atom</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt atom</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'Atom'"/>
            </a>
            <a>
                <xsl:attribute name="href">
                    <xsl:value-of select="uri" />
                    <xsl:text>/</xsl:text>
                    <xsl:value-of select="uriname" />
                    <xsl:text>.</xsl:text>
                    <xsl:value-of select="$language" />
                    <xsl:text>.rdf</xsl:text>       
                </xsl:attribute>
                <xsl:attribute name="class">
                    <xsl:text>fmt rdf</xsl:text>                      
                </xsl:attribute>
                <xsl:value-of select="'RDF/XML'"/>
                <sup>beta</sup>
            </a>
        </p>
                                                     
        <xsl:if test="registers != ''">
            <br/>
            <h3>
                <xsl:value-of select="$languagefile/guilanguage/item[@key='registers']"/>
            </h3>        
            <div class="tb_cont">
                <table id="tbl">
                    <thead>
                        <tr>
                            <th>
                                <xsl:value-of select="$languagefile/guilanguage/item[@key='label']"/>
                            </th>
                        </tr>
                    </thead>
                    <tbody>
                        <xsl:for-each select="registers/register">
                            <tr>
                                <td>
                                    <a>
                                        <xsl:attribute name="href" select="uri"/>
                                        <xsl:value-of select="label"/>
                                    </a>  
                                </td>                           
                            </tr>
                        </xsl:for-each>
                    </tbody>
                </table>
            </div>
        </xsl:if>        
        <br/>
        <br/>
        <br/>
        <p>
            <xsl:value-of select="$languagefile/guilanguage/item[@key='isa-desc']"/>
            <xsl:text>   </xsl:text>
            <a href="http://inspire.ec.europa.eu/registry/system">
                <xsl:value-of select="$languagefile/guilanguage/item[@key='click-here']"/>
            </a>
        </p>  
    </xsl:template>
</xsl:stylesheet>