<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xs="http://www.w3.org/2001/XMLSchema"> 
    
    <!--Output settings-->
    <xsl:output method="text" encoding="UTF-8" media-type="text/plain" omit-xml-declaration="yes"/>

    <!--Variables & parameters declaration-->
    <xsl:param name="base_db_export_path" />
    
    <xsl:template match="/">
        {
        "codelist":{
        <xsl:apply-templates select="item"/>
        }
        }
    </xsl:template>
    
    <xsl:template match="item">
        
        "id":"<xsl:value-of select="uri"/>"
        <xsl:if test="thisversion != ''">
            ,
            "thisversion":"<xsl:value-of select="thisversion/uri" />"
        </xsl:if>
        <xsl:if test="latestversion != ''">
            ,
            "latestversion":"<xsl:value-of select="latestversion/uri" />"
        </xsl:if>
        <xsl:choose>
            <xsl:when test="previousversions">
                ,
                "historyversion":[
                <xsl:for-each select="previousversions/version">   
                    {
                    "version":"<xsl:value-of select="uri"/>"
                    }                
                    <xsl:choose>
                        <xsl:when test="following-sibling::version">
                            , 
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
                ]
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
        <xsl:variable name="language" select="language/isocode"></xsl:variable>   
        ,"language":"<xsl:value-of select="$language"/>",
        <xsl:if test="label != ''">
            "label":{
            "lang":"<xsl:value-of select="label/@language"/>",
            "text":"<xsl:value-of select="label" />"
            },
        </xsl:if>   
        <xsl:if test="definition != ''">
            <xsl:variable name="tmp" select="definition"/>
            <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
            "definition":{
            "lang":"<xsl:value-of select="definition/@language"/>",
            "text":"<xsl:value-of select="$newtext" />"
            },
        </xsl:if>
        <xsl:if test="description != ''">
            <xsl:variable name="tmp" select="description"/>
            <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
            "description":{
            "lang":"<xsl:value-of select="description/@language"/>",
            "text":"<xsl:value-of select="$newtext" />"
            },
        </xsl:if>
      "itemclass":{
            "id":" <xsl:value-of select="itemclass/uriname"/>",
            "label":{
                "lang":"<xsl:value-of select="itemclass/label/@language"/>",
                "text":"<xsl:value-of select="itemclass/label" />"
                }
            }
        ,"status":{
            "id":" <xsl:value-of select="status/baseuri"/>
            <xsl:text>/</xsl:text>
            <xsl:value-of select="status/uriname"/>",
            "label":{
                "lang":"<xsl:value-of select="status/label/@language"/>",
                "text":"<xsl:value-of select="status/label" />"
                }
            },
        <xsl:if test="parent != ''">
            "parent":{
                "id":"<xsl:value-of select="parent-uri"/>",
                "label":{
                    "lang":"<xsl:value-of select="parent/label/@language"/>",
                    "text":"<xsl:value-of select="parent/label" />"
            }
            },
        </xsl:if>
        <xsl:variable name="extensibility_label" select="customattributes/customattribute[name/text()='Extensibility']/uriname"></xsl:variable>
        <xsl:variable name="extensibility_url" select="concat(register/registry/uri,'/extensibility/', $extensibility_label)"/>
        <xsl:if test="$extensibility_label != ''">
            "extensibility":{
            "id":"<xsl:value-of select="$extensibility_url"/>",
            "uriname":"<xsl:value-of select="$extensibility_label" />"
            },
        </xsl:if>
        "register":{
            "id":"<xsl:value-of select="register/uri"/>",
            "label":{
                "lang":"<xsl:value-of select="register/label/@language"/>",
                "text":"<xsl:value-of select="register/label"/>"
        },
        "registry":{
            "id":"<xsl:value-of select="register/registry/uri"/>",
            "label":{
                "lang":"<xsl:value-of select="register/registry/label/@language"/>",
                "text":"<xsl:value-of select="register/registry/label"/>"
            }
        }
        }
        <xsl:variable name="applicationschemaUri" select="customattributes/customattribute[name/text()='ApplicationSchema']/uri"></xsl:variable>
        <xsl:variable name="applicationschemaLabel" select="customattributes/customattribute[name/text()='ApplicationSchema']/label"></xsl:variable>
        <xsl:variable name="applicationschemaLabelLanguage" select="customattributes/customattribute[name/text()='ApplicationSchema']/label/@language"></xsl:variable>
        <xsl:variable name="applicationschemaUriname" select="customattributes/customattribute[name/text()='ApplicationSchema']/uriname"></xsl:variable>
        <xsl:variable name="applicationschemaFileName">
            <xsl:choose>
                <xsl:when test="document(concat(baseuri, '/applicationschema/', $applicationschemaUriname,'/',$applicationschemaUriname,'.',$applicationschemaLabelLanguage,'.xml'))">
                    <xsl:value-of select="concat(baseuri, '/applicationschema/', $applicationschemaUriname,'/',$applicationschemaUriname,'.',$applicationschemaLabelLanguage,'.xml')" />
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="concat(baseuri, '/applicationschema/', $applicationschemaUriname,'/',$applicationschemaUriname,'.en.xml')" />
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="themeUri" select="document($applicationschemaFileName)/applicationschema/theme/@id"/>
        <xsl:variable name="themeLabel" select="document($applicationschemaFileName)/applicationschema/theme/label"/>
        <xsl:if test="$themeUri != ''">
            ,"theme":{
                "id":"<xsl:value-of select="$themeUri" />",
                "label":{
                    "lang":"<xsl:value-of select="$applicationschemaLabelLanguage"/>",
                    "text":"<xsl:value-of select="$themeLabel"/>"
            }
            }</xsl:if>
        ,"applicationschema":{
            "id":"<xsl:value-of select="$applicationschemaUri" />",
            "label":{
                "lang":"<xsl:value-of select="$applicationschemaLabelLanguage"/>",
                "text":"<xsl:value-of select="$applicationschemaLabel"/>"
        }
        }
        <xsl:if test="customattributes/customattribute[name/text()='Document'] != ''">
            <xsl:variable name="externalreference_base_uri" select="externalreference/base_uri"/>
            <xsl:variable name="documentUri" select="customattributes/customattribute[name/text()='Document']/uri"></xsl:variable>
            <xsl:variable name="documentLabel" select="customattributes/customattribute[name/text()='Document']/label"></xsl:variable>
            <xsl:variable name="documentLabelLanguage" select="customattributes/customattribute[name/text()='Document']/label/@language"></xsl:variable>
            ,
            "externalreference":{
                "id":"<xsl:value-of select="$documentUri" />",
                "label":{
                    "lang":"<xsl:value-of select="$documentLabelLanguage"/>",
                    "text":"<xsl:value-of select="$documentLabel"/>"
            }
            }	
        </xsl:if>
        <xsl:choose>
            <xsl:when test="predecessors">
                ,"predecessors":[
                <xsl:for-each select="predecessors/predecessor">   
                    {
                    "predecessor":{
                    "id":"<xsl:value-of select="uri"/>",
                    "label":{
                    "lang":"<xsl:value-of select="label/@language"/>",
                    "text":"<xsl:value-of select="label" />"
                    }
                    }
                    }                
                    <xsl:choose>
                        <xsl:when test="following-sibling::predecessor">
                            , 
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
                ]
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
                    
        <xsl:choose>
            <xsl:when test="successors">
                ,"successors":[
                <xsl:for-each select="successors/successor">   
                    {
                    "successor":{
                    "id":"<xsl:value-of select="uri"/>",
                    "label":{
                    "lang":"<xsl:value-of select="label/@language"/>",
                    "text":"<xsl:value-of select="label" />"
                    }
                    }
                    }                
                    <xsl:choose>
                        <xsl:when test="following-sibling::successor">
                            , 
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
                ]
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
        
        <xsl:choose>
            <xsl:when test="collection">
                ,"containeditems":[
                <xsl:for-each select="collection/item">
                    {        
                    "value":{
                    "id":"<xsl:value-of select="uri"/>" <xsl:if test="thisversion != ''">
                        ,
                        "thisversion":"<xsl:value-of select="thisversion/uri" />"
                    </xsl:if>
                    <xsl:if test="latestversion != ''">
                        ,
                        "latestversion":"<xsl:value-of select="latestversion/uri" />"
                    </xsl:if>
                    <xsl:choose>
                        <xsl:when test="previousversions">
                            ,
                            "historyversion":[
                            <xsl:for-each select="previousversions/version">   
                                {
                                "version":"<xsl:value-of select="uri"/>"
                                }                
                                <xsl:choose>
                                    <xsl:when test="following-sibling::version">
                                        , 
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:for-each>
                            ]
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                    ,
                    "label":{
                        "lang":"<xsl:value-of select="label/@language"/>",
                        "text":"<xsl:value-of select="label"/>"
                    },
                    <xsl:if test="definition != ''">
                        <xsl:variable name="tmp" select="definition"/>
                        <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
                        "definition":{
                        "lang":"<xsl:value-of select="definition/@language"/>",
                        "text":"<xsl:value-of select="$newtext" />"
                        },
                    </xsl:if>
                    <xsl:if test="description != ''">
                        <xsl:variable name="tmp" select="description"/>
                        <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
                        "description":{
                        "lang":"<xsl:value-of select="description/@language"/>",
                        "text":"<xsl:value-of select="$newtext" />"
                        },
                    </xsl:if>
                     "itemclass":{
                        "id":" <xsl:value-of select="itemclass/uriname"/>",
                        "label":{
                            "lang":"<xsl:value-of select="itemclass/label/@language"/>",
                            "text":"<xsl:value-of select="itemclass/label" />"
                            }
                        },
                    "status":{
                        "id":"<xsl:value-of select="status/baseuri"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="status/uriname"/>",
                        "label":{
                            "lang":"<xsl:value-of select="status/label/@language"/>",
                            "text":"<xsl:value-of select="status/label" />"
                    }
                    },
                    <xsl:if test="parent != ''">
                        "parent":{
                            "id":"<xsl:value-of select="parent/uri"/>",
                            "label":{
                                "lang":"<xsl:value-of select="parent/label/@language"/>",
                                "text":"<xsl:value-of select="parent/label" />"
                        }
                        },
                    </xsl:if>
                    "register":{
                        "id":"<xsl:value-of select="register/uri"/>",
                        "label":{
                            "lang":"<xsl:value-of select="register/label/@language"/>",
                            "text":"<xsl:value-of select="register/label"/>"
                    },
                    "registry":{
                        "id":"<xsl:value-of select="register/registry/uri"/>",
                        "label":{
                            "lang":"<xsl:value-of select="register/registry/label/@language"/>",
                            "text":"<xsl:value-of select="register/registry/label"/>"
                    }
                    }
                    }
                    <xsl:if test="$themeUri != ''">
                        ,"theme":{
                            "id":"<xsl:value-of select="$themeUri"/>",
                            "label":{
                                "lang":"<xsl:value-of select="$applicationschemaLabelLanguage"/>",
                                "text":"<xsl:value-of select="$themeLabel"/>"
                        }
                        }</xsl:if>
                    ,"applicationschema":{
                        "id":"<xsl:value-of select="$applicationschemaUri"/>",
                        "label":{
                            "lang":"<xsl:value-of select="$applicationschemaLabelLanguage"/>",
                            "text":"<xsl:value-of select="$applicationschemaLabel"/>"
                    }
                    },    
                    "codelist":{
                        "id":"<xsl:value-of select="codelist/uri"/>",
                        "label":{
                            "lang":"<xsl:value-of select="codelist/label/@language"/>",
                            "text":"<xsl:value-of select="codelist/label"/>"
                    }
                    }
                    <xsl:if test="customattributes/customattribute[name/text()='ReferenceSource'] != '' and customattributes/customattribute[name/text()='ReferenceLink'] != ''">
                        <xsl:variable name="referenceSource" select="customattributes/customattribute[name/text()='ReferenceSource']/uriname"/>
                        <xsl:variable name="referenceLink" select="customattributes/customattribute[name/text()='ReferenceLink']/uriname"/>
                        ,
                        "reference":{
                            "source":"<xsl:value-of select="$referenceSource"/>",
                            "link":"<xsl:value-of select="$referenceLink"/>"
                        }	
                    </xsl:if>
                    <xsl:choose>
                        <xsl:when test="predecessors">
                            ,"predecessors":[
                            <xsl:for-each select="predecessors/predecessor">   
                                {
                                "predecessor":{
                                    "id":"<xsl:value-of select="uri"/>",
                                    "label":{
                                        "lang":"<xsl:value-of select="label/@language"/>",
                                        "text":"<xsl:value-of select="label" />"
                                }
                                }
                                }                
                                <xsl:choose>
                                    <xsl:when test="following-sibling::predecessor">
                                        , 
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:for-each>
                            ]
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                    
                    <xsl:choose>
                        <xsl:when test="successors">
                            ,"successors":[
                            <xsl:for-each select="successors/successor">   
                                {
                                "successor":{
                                    "id":"<xsl:value-of select="uri"/>",
                                    "label":{
                                        "lang":"<xsl:value-of select="label/@language"/>",
                                        "text":"<xsl:value-of select="label" />"
                                }
                                }
                                }                
                                <xsl:choose>
                                    <xsl:when test="following-sibling::successor">
                                        , 
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:for-each>
                            ]
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>
                    }
                    }
                    <xsl:choose>
                        <xsl:when test="following-sibling::item">
                            , 
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
                ]            
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>      
        
        <!--Codelist-->
        <xsl:choose>
            <xsl:when test="children">
                ,"containeditems":[
                <xsl:for-each select="children/item">   
                    {
                    "codelist":{
                    "id":"<xsl:value-of select="uri"/>",
                    "version":"<xsl:value-of select="versionnumber"/>",    
                    <xsl:if test="label != ''">
                        "label":{
                            "lang":"<xsl:value-of select="label/@language"/>",
                            "text":"<xsl:value-of select="label" />"
                        },
                    </xsl:if>
                    <xsl:if test="definition != ''">
                        <xsl:variable name="tmp" select="definition" />
                        <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
                        "definition":{
                            "lang":"<xsl:value-of select="definition/@language"/>",
                            "text":"<xsl:value-of select="$newtext" disable-output-escaping="yes" />"
                        },
                    </xsl:if>
                    <xsl:if test="description != ''">
                        <xsl:variable name="tmp" select="description"/>
                        <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
                        "description":{
                            "lang":"<xsl:value-of select="description/@language"/>",
                            "text":"<xsl:value-of select="$newtext" disable-output-escaping="yes" />"
                        },
                    </xsl:if>
                     "itemclass":{
                        "id":" <xsl:value-of select="itemclass/uriname"/>",
                        "label":{
                            "lang":"<xsl:value-of select="itemclass/label/@language"/>",
                            "text":"<xsl:value-of select="itemclass/label" />"
                            }
                        },
                    "status":{
                        "id":"<xsl:value-of select="status/baseuri"/>
                        <xsl:text>/</xsl:text>
                        <xsl:value-of select="status/uriname"/>",
                        "label":{
                            "lang":"<xsl:value-of select="status/label/@language"/>",
                            "text":"<xsl:value-of select="status/label"/>"
                    }
                    },
                    <xsl:if test="parent != ''">
                        "parent":{
                            "id":"<xsl:value-of select="parent/uri"/>",
                            "label":{
                                "lang":"<xsl:value-of select="parent/label/@language"/>",
                                "text":"<xsl:value-of select="parent/label"/>"
                        }
                        },                                    
                    </xsl:if>
                    <xsl:variable name="extensibility_label" select="customattributes/customattribute[name/text()='Extensibility']/uriname"></xsl:variable>
                    <xsl:variable name="extensibility_url" select="concat(baseuri, '/extensibility/', $extensibility_label)"/>
                    <xsl:if test="$extensibility_label != ''">
                        "extensibility":{
                            "id":"<xsl:value-of select="$extensibility_url"/>",
                            "uriname":"<xsl:value-of select="$extensibility_label" />"
                        },
                    </xsl:if> 
                    "register":{
                        "id":"<xsl:value-of select="register/uri"/>",
                        "label":{
                            "lang":"<xsl:value-of select="register/label/@language"/>",
                            "text":"<xsl:value-of select="register/label"/>"
                    },
                    "registry":{
                        "id":"<xsl:value-of select="register/registry/uri"/>",
                        "label":{
                            "lang":"<xsl:value-of select="register/registry/label/@language"/>",
                            "text":"<xsl:value-of select="register/registry/label"/>"
                    }
                    }
                    }
                    <xsl:variable name="applicationschemaUri" select="customattributes/customattribute[name/text()='ApplicationSchema']/uri"></xsl:variable>
                    <xsl:variable name="applicationschemaLabel" select="customattributes/customattribute[name/text()='ApplicationSchema']/label"></xsl:variable>
                    <xsl:variable name="applicationschemaLabelLanguage" select="customattributes/customattribute[name/text()='ApplicationSchema']/label/@language"></xsl:variable>
                    <xsl:variable name="applicationschemaUriname" select="customattributes/customattribute[name/text()='ApplicationSchema']/uriname"></xsl:variable>
                    <xsl:variable name="applicationschemaFileName">
                        <xsl:choose>
                            <xsl:when test="document(concat(baseuri, '/applicationschema/', $applicationschemaUriname,'/',$applicationschemaUriname,'.',$applicationschemaLabelLanguage,'.xml'))">
                                <xsl:value-of select="concat(baseuri, '/applicationschema/', $applicationschemaUriname,'/',$applicationschemaUriname,'.',$applicationschemaLabelLanguage,'.xml')" />
                            </xsl:when>
                            <xsl:otherwise>
                                <xsl:value-of select="concat(baseuri, '/applicationschema/', $applicationschemaUriname,'/',$applicationschemaUriname,'.en.xml')" />
                            </xsl:otherwise>
                        </xsl:choose>
                    </xsl:variable>
                    <xsl:variable name="themeUri" select="document($applicationschemaFileName)/applicationschema/theme/@id"/>
                    <xsl:variable name="themeLabel" select="document($applicationschemaFileName)/applicationschema/theme/label"/>
                    <xsl:if test="$themeUri != ''">
                        ,"theme":{
                            "id":"<xsl:value-of select="$themeUri" />",
                            "label":{
                                "lang":"<xsl:value-of select="$applicationschemaLabelLanguage"/>",
                                "text":"<xsl:value-of select="$themeLabel"/>"
                        }
                        }</xsl:if>
                    ,"applicationschema":{
                        "id":"<xsl:value-of select="$applicationschemaUri" />",
                        "label":{
                            "lang":"<xsl:value-of select="$applicationschemaLabelLanguage"/>",
                            "text":"<xsl:value-of select="$applicationschemaLabel"/>"
                    }
                    }
                    <xsl:if test="customattributes/customattribute[name/text()='Document'] != ''">
                        <xsl:variable name="externalreference_base_uri" select="externalreference/base_uri"/>
                        <xsl:variable name="documentUri" select="customattributes/customattribute[name/text()='Document']/uri"></xsl:variable>
                        <xsl:variable name="documentLabel" select="customattributes/customattribute[name/text()='Document']/label"></xsl:variable>
                        <xsl:variable name="documentLabelLanguage" select="customattributes/customattribute[name/text()='Document']/label/@language"></xsl:variable>
                        ,"externalreference":{
                            "id":"<xsl:value-of select="$documentUri" />",
                            "label":{
                                "lang":"<xsl:value-of select="$documentLabelLanguage"/>",
                                "text":"<xsl:value-of select="$documentLabel"/>"
                        }
                        }	
                    </xsl:if>
                    <xsl:choose>
                        <xsl:when test="collection">
                            ,"containeditems":[
                            <xsl:for-each select="collection/item">
                                {        
                                "value":{
                                "id":"<xsl:value-of select="uri"/>" <xsl:if test="thisversion != ''">
                                    ,
                                    "thisversion":"<xsl:value-of select="thisversion/uri" />"
                                </xsl:if>
                                <xsl:if test="latestversion != ''">
                                    ,
                                    "latestversion":"<xsl:value-of select="latestversion/uri" />"
                                </xsl:if>
                                <xsl:choose>
                                    <xsl:when test="previousversions">
                                        ,
                                        "historyversion":[
                                        <xsl:for-each select="previousversions/version">   
                                            {
                                            "version":"<xsl:value-of select="uri"/>"
                                            }                
                                            <xsl:choose>
                                                <xsl:when test="following-sibling::version">
                                                    , 
                                                </xsl:when>
                                            </xsl:choose>
                                        </xsl:for-each>
                                        ]
                                    </xsl:when>
                                    <xsl:otherwise>
                                    </xsl:otherwise>
                                </xsl:choose>
                                ,
                                "label":{
                                    "lang":"<xsl:value-of select="label/@language"/>",
                                    "text":"<xsl:value-of select="label"/>"
                                },
                                <xsl:if test="definition != ''">
                                    <xsl:variable name="tmp" select="definition"/>
                                    <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
                                    "definition":{
                                        "lang":"<xsl:value-of select="definition/@language"/>",
                                        "text":"<xsl:value-of select="$newtext" />"
                                    },
                                </xsl:if>
                                <xsl:if test="description != ''">
                                    <xsl:variable name="tmp" select="description"/>
                                    <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
                                    "description":{
                                        "lang":"<xsl:value-of select="description/@language"/>",
                                        "text":"<xsl:value-of select="$newtext" />"
                                    },
                                </xsl:if>
                                 "itemclass":{
                                    "id":" <xsl:value-of select="itemclass/uriname"/>",
                                    "label":{
                                        "lang":"<xsl:value-of select="itemclass/label/@language"/>",
                                        "text":"<xsl:value-of select="itemclass/label" />"
                                        }
                                    },
                                "status":{
                                    "id":"<xsl:value-of select="status/baseuri"/>
                                    <xsl:text>/</xsl:text>
                                    <xsl:value-of select="status/uriname"/>",
                                    "label":{
                                        "lang":"<xsl:value-of select="status/label/@language"/>",
                                        "text":"<xsl:value-of select="status/label" />"
                                }
                                },
                                <xsl:if test="parent != ''">
                                    "parent":{
                                        "id":"<xsl:value-of select="parent/uri"/>",
                                        "label":{
                                            "lang":"<xsl:value-of select="parent/label/@language"/>",
                                            "text":"<xsl:value-of select="parent/label" />"
                                    }
                                    },
                                </xsl:if>
                                "register":{
                                    "id":"<xsl:value-of select="register/uri"/>",
                                    "label":{
                                        "lang":"<xsl:value-of select="register/label/@language"/>",
                                        "text":"<xsl:value-of select="register/label"/>"
                                },
                                "registry":{
                                    "id":"<xsl:value-of select="register/registry/uri"/>",
                                    "label":{
                                        "lang":"<xsl:value-of select="register/registry/label/@language"/>",
                                        "text":"<xsl:value-of select="register/registry/label"/>"
                                }
                                }
                                }
                                <xsl:if test="$themeUri != ''">
                                    ,"theme":{
                                        "id":"<xsl:value-of select="$themeUri"/>",
                                        "label":{
                                            "lang":"<xsl:value-of select="$applicationschemaLabelLanguage"/>",
                                            "text":"<xsl:value-of select="$themeLabel"/>"
                                    }
                                    }</xsl:if>
                                ,"applicationschema":{
                                    "id":"<xsl:value-of select="$applicationschemaUri"/>",
                                    "label":{
                                        "lang":"<xsl:value-of select="$applicationschemaLabelLanguage"/>",
                                        "text":"<xsl:value-of select="$applicationschemaLabel"/>"
                                }
                                },    
                                "codelist":{
                                    "id":"<xsl:value-of select="codelist/uri"/>",
                                    "label":{
                                        "lang":"<xsl:value-of select="codeslist/label/@language"/>",
                                        "text":"<xsl:value-of select="codelist/label"/>"
                                }
                                }
                                <xsl:if test="customattributes/customattribute[name/text()='ReferenceSource'] != '' and customattributes/customattribute[name/text()='ReferenceLink'] != ''">
                                    <xsl:variable name="referenceSource" select="customattributes/customattribute[name/text()='ReferenceSource']/uriname"/>
                                    <xsl:variable name="referenceLink" select="customattributes/customattribute[name/text()='ReferenceLink']/uriname"/>
                                    ,
                                    "reference":{
                                        "source":"<xsl:value-of select="$referenceSource"/>",
                                        "link":"<xsl:value-of select="$referenceLink"/>"
                                    }	
                                </xsl:if>
                                <xsl:choose>
                                    <xsl:when test="predecessors">
                                        ,"predecessors":[
                                        <xsl:for-each select="predecessors/predecessor">   
                                            {
                                            "predecessor":{
                                                "id":"<xsl:value-of select="uri"/>",
                                                "label":{
                                                    "lang":"<xsl:value-of select="label/@language"/>",
                                                    "text":"<xsl:value-of select="label" />"
                                            }
                                            }
                                            }                
                                            <xsl:choose>
                                                <xsl:when test="following-sibling::predecessor">
                                                    , 
                                                </xsl:when>
                                            </xsl:choose>
                                        </xsl:for-each>
                                        ]
                                    </xsl:when>
                                    <xsl:otherwise>
                                    </xsl:otherwise>
                                </xsl:choose>
                    
                                <xsl:choose>
                                    <xsl:when test="successors">
                                        ,"successors":[
                                        <xsl:for-each select="successors/successor">   
                                            {
                                            "successor":{
                                                "id":"<xsl:value-of select="uri"/>",
                                                "label":{
                                                    "lang":"<xsl:value-of select="label/@language"/>",
                                                    "text":"<xsl:value-of select="label" />"
                                            }
                                            }
                                            }                
                                            <xsl:choose>
                                                <xsl:when test="following-sibling::successor">
                                                    , 
                                                </xsl:when>
                                            </xsl:choose>
                                        </xsl:for-each>
                                        ]
                                    </xsl:when>
                                    <xsl:otherwise>
                                    </xsl:otherwise>
                                </xsl:choose>
                                }
                                }
                                <xsl:choose>
                                    <xsl:when test="following-sibling::item">
                                        , 
                                    </xsl:when>
                                </xsl:choose>
                            </xsl:for-each>
                            ]            
                        </xsl:when>
                        <xsl:otherwise>
                        </xsl:otherwise>
                    </xsl:choose>      
                    }
                    }                
                    <xsl:choose>
                        <xsl:when test="following-sibling::item">
                            , 
                        </xsl:when>
                    </xsl:choose>
                </xsl:for-each>
                ]
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>            
    </xsl:template>
</xsl:stylesheet>