<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xs="http://www.w3.org/2001/XMLSchema"> 
    
    <!--Output settings-->
    <xsl:output method="text" encoding="UTF-8" media-type="text/plain" omit-xml-declaration="yes"/>

    <!--Variables & parameters declaration-->
    <xsl:param name="base_db_export_path" />
    
    <xsl:template match="/">
    {
        "register":{
        <xsl:apply-templates select="register"/>
        }
    }
    </xsl:template>
    
    <xsl:template match="register">
        
        "id":"<xsl:value-of select="uri"/>",
         <xsl:variable name="language" select="language/isocode"></xsl:variable>   
        "language":"<xsl:value-of select="$language"/>",
        <xsl:if test="label != ''">
        "label":{
            "lang":"<xsl:value-of select="label/@language"/>",
            "text":"<xsl:value-of select="label" />"
        },
        </xsl:if>   
        <xsl:if test="definition != ''">
        <xsl:variable name="tmp" select="definition"/>
        <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
        "contentsummary":{
            "lang":"<xsl:value-of select="definition/@language"/>",
            "text":"<xsl:value-of select="$newtext" />"
        },
        </xsl:if>
        <xsl:if test="description != ''">
        <xsl:variable name="tmp" select="description"/>
        <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
        "description":{
            "lang":"<xsl:value-of select="description/@language"/>",
            "text":"<xsl:value-of select="$newtext" />"
        },
        </xsl:if>
        "owner":"<xsl:value-of select="owner" />",
        "manager":"<xsl:value-of select="manager" />",
        "controlbody":"<xsl:value-of select="controlbody" />",
        "registry":{
            "id":"<xsl:value-of select="registry/uri"/>",
            "label":{
                "lang":"<xsl:value-of select="registry/label/@language"/>",
                "text":"<xsl:value-of select="registry/label" />"
            }
        }        
        <xsl:choose>
            <xsl:when test="items">
            ,"containeditems":[
                <xsl:for-each select="items/item">   
                {
                    "applicationschema":{
                                    "id":"<xsl:value-of select="uri"/>",
                                    "version":"<xsl:value-of select="versionnumber"/>",
                                    <xsl:if test="label != ''">
                                    "label":{
                                        "lang":"<xsl:value-of select="label/@language"/>",
                                        "text":"<xsl:value-of select="label" />"
                                    },
                                    </xsl:if>   
                                    <xsl:if test="definition != ''">
                                    <xsl:variable name="tmp" select="definition"/>
                                    <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
                                    "definition":{
                                        "lang":"<xsl:value-of select="definition/@language"/>",
                                        "text":"<xsl:value-of select="$newtext" />"
                                    },
                                    </xsl:if>
                                    <xsl:if test="description != ''">
                                    <xsl:variable name="tmp" select="description"/>
                                    <xsl:variable name="newtext" select="replace($tmp,'&quot;','')"/>
                                    "description":{
                                        "lang":"<xsl:value-of select="description/@language"/>",
                                        "text":"<xsl:value-of select="$newtext" />"
                                    },
                                    </xsl:if>
                                    "itemclass":{
                                        "id":" <xsl:value-of select="itemclass/uriname"/>",
                                        "label":{
                                            "lang":"<xsl:value-of select="itemclass/label/@language"/>",
                                            "text":"<xsl:value-of select="itemclass/label" />"
                                            }
                                        },
                                     "status":{
                                        "id":" <xsl:value-of select="status/baseuri"/><xsl:text>/</xsl:text><xsl:value-of select="status/uriname"/>",
                                        "label":{
                                            "lang":"<xsl:value-of select="status/label/@language"/>",
                                            "text":"<xsl:value-of select="status/label" />"
                                        }
                                    },
                                    "register":{
                                        "id":"<xsl:value-of select="register/uri"/>",
                                        "label":{
                                            "lang":"<xsl:value-of select="register/label/@language"/>",
                                            "text":"<xsl:value-of select="register/label"/>"
                                        },
                                        "registry":{
                                            "id":"<xsl:value-of select="register/registry/uri"/>",
                                            "label":{
                                                "lang":"<xsl:value-of select="register/registry/label/@language"/>",
                                                "text":"<xsl:value-of select="register/registry/label"/>"
                                            }
                                        }
                                    }
                                    <xsl:if test="customattributes/customattribute[name/text()='Theme'] != ''">
                                    ,"theme":{
                                        <xsl:variable name="themeUri" select="customattributes/customattribute[name/text()='Theme']/uri"></xsl:variable>
                                        <xsl:variable name="themeLabel" select="customattributes/customattribute[name/text()='Theme']/label"></xsl:variable>
                                        <xsl:variable name="themeLabelLanguage" select="customattributes/customattribute[name/text()='Theme']/label/@language"></xsl:variable>
                                        "id":"<xsl:value-of select="$themeUri" />",
                                        "label":{
                                                "lang":"<xsl:value-of select="$themeLabelLanguage"/>",
                                                "text":"<xsl:value-of select="$themeLabel"/>"
                                            }
                                  }</xsl:if>
                    }
                }                
                <xsl:choose>
                <xsl:when test="following-sibling::item">
                , 
                </xsl:when>
                </xsl:choose>
                </xsl:for-each>
            ]
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose> 
    </xsl:template>
</xsl:stylesheet>