<?xml version="1.0" encoding="ISO-8859-1"?>

<!--  Copyright 2010,2014 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 26/09/2014
  Authors: European Commission, Joint Research Centre
  Andrea Perego, Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<!--

GENERAL COMMENTS:

- URIs for internal/external, extensible/not extensible, empty/not empty
- URIs for manager, owner, control body

-->  

<!--
TBD
- Remove unused namespace declarations
- Remove blank lines
-->

<!--
<xsl:stylesheet version="2.0"
-->
<xsl:transform version="2.0" 
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
  xmlns:dc="http://purl.org/dc/elements/1.1/" 
  xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
  xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
  xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#"
  xmlns:owl ="http://www.w3.org/2002/07/owl#"
  xmlns:skos="http://www.w3.org/2004/02/skos/core#"
  xmlns:dct="http://purl.org/dc/terms/"
  xmlns:foaf="http://xmlns.com/foaf/0.1/"
  xmlns:dcat="http://www.w3.org/ns/dcat#"
  xmlns:adms="http://www.w3.org/ns/adms#"
  xmlns:vann="http://purl.org/vocab/vann/"
> 
    
<!--Output settings-->

  <xsl:output method="xml" media-type="application/rdf+xml" version="1.0" encoding="UTF-8" indent="yes"/>

<!--Variables & parameters declaration-->

  <xsl:param name="base_db_export_path" />
  <xsl:param name="xs">http://www.w3.org/2001/XMLSchema#</xsl:param>
  <xsl:param name="rdfs">http://www.w3.org/2000/01/rdf-schema#</xsl:param>
  <xsl:param name="dcat">http://www.w3.org/ns/dcat#</xsl:param>
  <xsl:param name="skos">http://www.w3.org/2004/02/skos/core#</xsl:param>
  <xsl:param name="foaf">http://xmlns.com/foaf/0.1/</xsl:param>
  <xsl:param name="vann">http://purl.org/vocab/vann/</xsl:param>
  <xsl:param name="prv">http://purl.org/net/provenance/ns#</xsl:param>
  
  <xsl:param name="op_at">http://publications.europa.eu/resource/authority</xsl:param>
  <xsl:param name="op_at_lang" select="concat($op_at,'/','language')"/>

<!-- 
  The $formats parameter is just a placeholder for the list of available formats and it is not used.
  NB: This information should be stored elsewhere in a single location - as in a config file.
  
  About media type URIs, we have a number of options:
  - IANA has URIs for some of the registered media types, but it returns just a plain text description of them
    (see http://www.iana.org/assignments/media-types/)
  - W3C operates a Linked Data register for a number media types, concerning formats related to W3C Recommendations 
    (see http://www.w3.org/ns/formats/)
  - The Publications Office of the EU operates a register of file types, that is already used in the EU ODP, and whose
    use is recommended in the DCAT-AP specification. This register is available in HTML, XML and RDF (SKOS), but the
    corresponding URIs are not dereferenceable (but they are likely to be in the future). The register is not covering 
    all media types, but requests for inclusion of missing media types may be taken into account by the Publications 
    Office.
  - A media type register for INSPIRE download services is available in the form of an Atom feed 
    (see http://inspire.ec.europa.eu/media-types/). This register covers just a subset of the existing media types. 
-->
  
  <xsl:param name="formats">
<!-- Media type URIs from the Publications Office of the EU -->    
<!--  
    <format label="HTML" name="http://publications.europa.eu/resource/authority/file-type/HTML" ext="html"/>
    <format label="CSV" name="http://publications.europa.eu/resource/authority/file-type/CSV" ext="csv"/>
    <format label="JSON" name="http://publications.europa.eu/resource/authority/file-type/JSON" ext="json"/>
    <format label="XML" name="http://publications.europa.eu/resource/authority/file-type/XML" ext="xml"/>
    <format label="19135" uri="http://publications.europa.eu/resource/authority/file-type/XML" ext="19135.xml"/>
    <format label="Atom" name="http://www.iana.org/assignments/media-types/application/atom+xml" ext="atom"/>
    <format label="RDF/XML" name="http://publications.europa.eu/resource/authority/file-type/RDF_XML" ext="rdf"/>
-->    
<!-- Media type URIs from IANA register + W3C (for RDF/XML) -->
    <format label="HTML" uri="http://www.iana.org/assignments/media-types/text/html" ext="html"/>
    <format label="CSV" uri="http://www.iana.org/assignments/media-types/text/csv" ext="csv"/>
    <format label="JSON" uri="http://www.iana.org/assignments/media-types/application/json" ext="json"/>
    <format label="XML" uri="http://www.iana.org/assignments/media-types/application/xml" ext="xml"/>
    <format label="19135" uri="http://www.iana.org/assignments/media-types/application/xml" ext="19135.xml"/>
    <format label="Atom" uri="http://www.iana.org/assignments/media-types/application/atom+xml" ext="atom"/>
    <format label="RDF/XML" uri="http://www.w3.org/ns/formats/RDF_XML" ext="rdf"/>
  </xsl:param>
  
<!-- IMPORTANT! The following templates are meant to generate RDF including ALL what is in the standard XML file -->
<!-- General template -->
    
  <xsl:template match="/">
    <rdf:RDF>
      <xsl:apply-templates select="registry|registry/registers/register"/>
      <xsl:apply-templates select="register|register/items/item"/>
      <xsl:apply-templates select="item|item/collection/item"/>
    </rdf:RDF>
  </xsl:template>

<!-- Registries -->
    
  <xsl:template match="registry|register/registers/register">
    <xsl:call-template name="common"/>
  </xsl:template>
  
<!-- Registers -->
    
  <xsl:template match="register|item/items/item">
    <xsl:call-template name="common"/>
  </xsl:template>

<!-- Items -->
    
  <xsl:template match="item|item/collection/item">
    <xsl:call-template name="common"/>
  </xsl:template>
  
<!-- 
  IMPORTANT! The following templates are meant to generate RDF including ONLY the main resource(s) described in the
  standard XML file.
  
  This solution is the most consistent and scalable, but it has been currently replaced with the one currently enabled,
  which is meant to generate RDF for both the main resource(s) and the direct children described in the standard XML
  file.  
-->
<!-- General template -->
<!--    
  <xsl:template match="/">
    <rdf:RDF>
      <xsl:apply-templates select="registry"/>
      <xsl:apply-templates select="register"/>
      <xsl:apply-templates select="item"/>
    </rdf:RDF>
  </xsl:template>
-->
<!-- Registries -->
<!--    
  <xsl:template match="registry">
    <xsl:call-template name="common"/>
  </xsl:template>
-->
<!-- Registers -->
<!--    
  <xsl:template match="register">
    <xsl:call-template name="common"/>
  </xsl:template>
-->
<!-- Items -->
<!--    
  <xsl:template match="item">
    <xsl:call-template name="common"/>
  </xsl:template>  
-->
<!-- Common template, including statements common to all resource types, and calling the relevant sub-templates -->
  
  <xsl:template name="common">
    <rdf:Description rdf:about="{uri}">
      <dct:identifier rdf:datatype="{$rdfs}Literal"><xsl:value-of select="uriname"/></dct:identifier>
<!-- ?? Is the versioned URI dereferenceable? -->      
      <xsl:if test="thisversion">
<!-- owl:sameAs may not be a suitable mapping -->      
        <owl:sameAs rdf:resource="{thisversion/uri}"/>
      </xsl:if>
      <xsl:if test="latestversion">
        <adms:last rdf:resource="{latestversion/uri}"/>
      </xsl:if>
      <xsl:choose>
        <xsl:when test="local-name() = 'registry'">
          <rdf:type rdf:resource="{$dcat}Catalog"/>
        </xsl:when>
        <xsl:when test="local-name() = 'register'">
          <rdf:type rdf:resource="{$dcat}Dataset"/>
          <xsl:if test="uriname = 'theme' or uriname = 'glossary'">
            <rdf:type rdf:resource="{$skos}ConceptScheme"/>
          </xsl:if>
        </xsl:when>
        <xsl:when test="local-name() = 'item'">
          <rdf:type rdf:resource="{$prv}DataItem"/>
          <xsl:choose>
            <xsl:when test="itemclass/uriname = 'CodeList' or itemclass/uriname = 'MetadataCodeList'">
              <rdf:type rdf:resource="{$dcat}Dataset"/>
              <rdf:type rdf:resource="{$skos}ConceptScheme"/>
            </xsl:when>
            <xsl:when test="itemclass/uriname = 'CodeListValue'">
              <rdf:type rdf:resource="{$skos}Concept"/>
            </xsl:when>
            <xsl:when test="itemclass/uriname = 'Document'">
              <rdf:type rdf:resource="{$foaf}Document"/>
            </xsl:when>
          </xsl:choose>
        </xsl:when>
      </xsl:choose>
<!-- For items -->      
      <xsl:for-each select="codelist">
        <skos:inScheme rdf:resource="{uri}"/>
        <xsl:if test="not(parent) or parent = ''">
          <skos:topConceptOf rdf:resource="{uri}"/>
        </xsl:if>
      </xsl:for-each>
      <xsl:for-each select="parent">
        <skos:broader rdf:resource="{uri}"/>
      </xsl:for-each>
<!-- Calling template for free text elements -->      
      <xsl:call-template name="text"/>
<!-- Calling template for dates -->      
      <xsl:call-template name="dates"/>
<!-- Calling template for responsible organisations -->      
      <xsl:call-template name="resporg"/>
<!-- ?? Licence?? -->      
<!--
      <dct:license rdf:about=""/>
-->      
<!-- Contained items -->
<!-- For a registry -->
      <xsl:if test="registers">
        <xsl:for-each select="registers/register">
          <dcat:dataset rdf:resource="{uri}"/>
        </xsl:for-each>
      </xsl:if>
<!-- For a register -->      
      <xsl:if test="items">
        <xsl:for-each select="items/item">
          <dct:hasPart rdf:resource="{uri}"/>
        </xsl:for-each>
      </xsl:if>
<!-- For items with sub-items -->
      <xsl:if test="collection">
        <xsl:for-each select="collection/item">
          <dct:hasPart rdf:resource="{uri}"/>
          <xsl:if test="not(parent) or parent =''">
            <skos:hasTopConcept rdf:resource="{uri}"/>
          </xsl:if>
        </xsl:for-each>
      </xsl:if>
<!-- Custom attributes -->      
      <xsl:if test="customattributes">
        <xsl:for-each select="customattributes/customattribute">
          <xsl:if test="name = 'Document' or name = 'ApplicationSchema'">
            <rdfs:isDefinedBy rdf:resource="{uri}"/>
          </xsl:if>
        </xsl:for-each>
      </xsl:if>
      <xsl:if test="status">
        <adms:status rdf:resource="{status/baseuri}/{status/uriname}"/>
      </xsl:if>
    </rdf:Description>
<!-- Parent register and corresponding registry -->
<!-- WARNING: This block may create redundancies if the relationship is specified this way. Consider revising.  -->
<!-- NOTE: This block has been commented to avoid redundancies -->
<!-- For registers -->
<!--    
    <xsl:if test="registry">
      <rdf:Description rdf:about="{registry/uri}">
        <dcat:dataset rdf:resource="{uri}"/>
      </rdf:Description>
    </xsl:if>
-->    
<!-- For items -->
<!--    
    <xsl:if test="register">
      <rdf:Description rdf:about="{register/uri}">
        <dct:hasPart rdf:resource="{uri}"/>
      </rdf:Description>
      <xsl:if test="register/registry">
        <rdf:Description rdf:about="{register/registry/uri}">
          <dcat:dataset rdf:resource="{register/uri}"/>
        </rdf:Description>
      </xsl:if>
    </xsl:if>
-->
<!-- Distributions -->    
    <xsl:call-template name="format"/>
  </xsl:template>

<!-- Template for free text elements -->

  <xsl:template name="text">
    <xsl:for-each select="label">
      <dct:title xml:lang="{@language}"><xsl:value-of select="."/></dct:title>
    </xsl:for-each>
<!-- ?? Which is the difference bw definition and description? Any of them is always mandatory? -->      
    <xsl:for-each select="definition[. != '']">
      <dct:description xml:lang="{@language}"><xsl:value-of select="."/></dct:description>
    </xsl:for-each>
    <xsl:for-each select="description[. != '']">
      <vann:usageNote xml:lang="{@language}"><xsl:value-of select="."/></vann:usageNote>
    </xsl:for-each>
    <xsl:choose>
      <xsl:when test="uriname = 'theme' or uriname = 'glossary' or itemclass/uriname = 'CodeList' or itemclass/uriname = 'MetadataCodeList' or itemclass/uriname = 'CodeListValue'">
        <xsl:for-each select="label">
          <skos:prefLabel xml:lang="{@language}"><xsl:value-of select="."/></skos:prefLabel>
        </xsl:for-each>
<!-- ?? Which is the difference bw definition and description? Any of them is always mandatory? -->      
        <xsl:for-each select="definition[. != '']">
          <skos:definition xml:lang="{@language}"><xsl:value-of select="."/></skos:definition>
        </xsl:for-each>
<!--        
        <xsl:for-each select="description[. != '']">
          <vann:usageNote xml:lang="{@language}"><xsl:value-of select="."/></vann:usageNote>
        </xsl:for-each>
-->        
      </xsl:when>
    </xsl:choose>
  </xsl:template>
  
<!-- Template for dates -->  
  
  <xsl:template name="dates">
<!-- ?? What is the creation date? -->      
    <xsl:if test="datecreation != ''">
      <dct:issued rdf:datatype="{$xs}dateTime"><xsl:value-of select="datecreation"/></dct:issued>
    </xsl:if>
<!-- ?? What is the addition date? -->      
    <xsl:if test="datetimeaddition != ''">
      <dct:issued rdf:datatype="{$xs}dateTime"><xsl:value-of select="datetimeaddition"/></dct:issued>
    </xsl:if>
  </xsl:template>
  
<!-- Template for responsible organisations -->  

  <xsl:template name="resporg">
<!-- ?? We should have a URI also for the registry manager -->
<!-- ?? Can the registry manager be considered as its publisher? -->     
<!-- ?? Why "registrymanager" and not simply "manager"? --> 
    <xsl:for-each select="registrymanager">
      <dct:publisher>
        <foaf:Agent>
          <foaf:name xml:lang="en"><xsl:value-of select="."/></foaf:name>
        </foaf:Agent>
      </dct:publisher>
    </xsl:for-each>
<!-- ?? We should have a URI also for the owner -->
    <xsl:for-each select="owner">
      <dct:rightsHolder>
        <foaf:Agent>
          <foaf:name xml:lang="en"><xsl:value-of select="."/></foaf:name>
        </foaf:Agent>
      </dct:rightsHolder>
    </xsl:for-each>
<!-- ?? We should have a URI also for the manager -->
<!-- ?? Can the manager be considered as its publisher? -->      
    <xsl:for-each select="manager">
      <dct:publisher>
        <foaf:Agent>
          <foaf:name xml:lang="en"><xsl:value-of select="."/></foaf:name>
        </foaf:Agent>
      </dct:publisher>
    </xsl:for-each>
<!-- ?? We should have a URI also for the controlbody -->
<!-- ?? Can the control body be considered as its creator? -->      
    <xsl:for-each select="controlbody">
      <dct:creator>
        <foaf:Agent>
          <foaf:name xml:lang="en"><xsl:value-of select="."/></foaf:name>
        </foaf:Agent>
      </dct:creator>
    </xsl:for-each>
  </xsl:template>
  
<!-- 
  The list of available formats should be fetched from elsewhere - e.g., config file
  The code below should be generated dynamically. 
-->  
  
  <xsl:template name="format">
    <xsl:variable name="localname" select="local-name()"/>
    <xsl:variable name="langcode" select="concat('.',label/@language)"/>
    <xsl:variable name="itemclass" select="itemclass/uriname"/>
    <xsl:variable name="disturiprefix" select="concat(uri,'/',uriname)"/>
    <xsl:variable name="distlangs">
      <xsl:call-template name="distlangs"/>
    </xsl:variable>
    <xsl:choose>
      <xsl:when test="$localname = 'registry' or $itemclass = 'Document'">
        <rdf:Description rdf:about="{uri}/{uriname}">
          <foaf:primaryTopic rdf:resource="{uri}"/>
          <xsl:for-each select="document('')/*/xsl:param[@name='formats']/*">
<!-- 
  1/3. Currently, items do not have a .csv encoding available.
       The following xsl:if statement is to be removed is this will change. 
-->    
            <xsl:if test="not(@ext = 'csv' and $localname = 'item')">
            <dct:hasFormat rdf:resource="{$disturiprefix}{$langcode}.{@ext}"/>
            </xsl:if>
          </xsl:for-each>
        </rdf:Description>
      </xsl:when>
      <xsl:otherwise>
        <rdf:Description rdf:about="{uri}">
          <xsl:for-each select="document('')/*/xsl:param[@name='formats']/*">
<!-- 
  2/3. Currently, items do not have a .csv encoding available.
       The following xsl:if statement is to be removed is this will change. 
-->    
            <xsl:if test="not(@ext = 'csv' and $localname = 'item')">
            <dct:hasFormat rdf:resource="{$disturiprefix}{$langcode}.{@ext}"/>
            </xsl:if>
          </xsl:for-each>
        </rdf:Description>
      </xsl:otherwise>
    </xsl:choose>
    <xsl:for-each select="document('')/*/xsl:param[@name='formats']/*">
<!-- 
  3/3. Currently, items do not have a .csv encoding available.
       The following xsl:if statement is to be removed is this will change. 
-->    
      <xsl:if test="not(@ext = 'csv' and $localname = 'item')">
      <rdf:Description rdf:about="{$disturiprefix}{$langcode}.{@ext}">
        <rdfs:label xml:lang="en"><xsl:value-of select="@label"/></rdfs:label>
        <dct:format rdf:resource="{@uri}"/>
        <xsl:copy-of select="$distlangs"/>
      </rdf:Description>
      </xsl:if>
    </xsl:for-each>
  </xsl:template>
  
<!-- 
  The distlangs template is meant to map alpha 2 language codes into the corresponding language URIs from
  the Metadata Registry of the Publications Office of the EU.
-->  
  <xsl:template name="distlangs">  
    <xsl:variable name="langtwo" select="label/@language"/>
<!-- The $langthree variable is meant to map alpha-2 language code to their alpha-3 representation -->
    <xsl:variable name="langthree">
      <xsl:choose>
        <xsl:when test="$langtwo = 'bg'">
          <xsl:text>bul</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'cs'">
          <xsl:text>cze</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'da'">
          <xsl:text>dan</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'de'">  
          <xsl:text>ger</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'el'">
          <xsl:text>gre</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'en'">
          <xsl:text>eng</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'es'">
          <xsl:text>spa</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'et'">
          <xsl:text>est</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'fi'">
          <xsl:text>fin</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'fr'">
          <xsl:text>fre</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'ga'">
          <xsl:text>gle</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'hr'">
          <xsl:text>hrv</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'it'">
          <xsl:text>ita</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'lv'">
          <xsl:text>lav</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'lt'">
          <xsl:text>lit</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'hu'">
          <xsl:text>hun</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'mt'">
          <xsl:text>mlt</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'nl'">
          <xsl:text>dut</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'pl'">
          <xsl:text>pol</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'pt'">
          <xsl:text>por</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'ru'">
          <xsl:text>rum</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'sk'">
          <xsl:text>slo</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'sl'">
          <xsl:text>slv</xsl:text>
        </xsl:when>
        <xsl:when test="$langtwo = 'sv'">
          <xsl:text>swe</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="$langtwo"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="langUri" select="concat($op_at_lang,'/',translate($langthree,'abcdefghijklmnopqrstuvwxyz','ABCDEFGHIJKLMNOPQRSTUVWXYZ'))"/>
    <dct:language rdf:resource="{$langUri}"/>
  </xsl:template>
  
<!--
</xsl:stylesheet>
-->
</xsl:transform>
