<?xml version="1.0" encoding="ISO-8859-1"?>

<!--  Copyright 2010,2013 EUROPEAN UNION
  Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
  the European Commission - subsequent versions of the EUPL (the "Licence");
  You may not use this work except in compliance with the Licence.
  You may obtain a copy of the Licence at:
 
  http://ec.europa.eu/idabc/eupl
 
  Unless required by applicable law or agreed to in writing, software
  distributed under the Licence is distributed on an "AS IS" basis,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the Licence for the specific language governing permissions and
  limitations under the Licence.
 
  Date: 14/06/2013
  Authors: European Commission, Joint Research Centre
  Daniele Francioli, Emanuela Epure
  inspire-registry-info@jrc.ec.europa.eu
 
This work was supported by the EU  Interoperability Solutions for
European Public Administrations Programme (http://ec.europa.eu/isa)
through Action 1.17: Re-usable INSPIRE Reference Platform 
(http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).-->

<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:xs="http://www.w3.org/2001/XMLSchema" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"> 
    
    <!--Output settings-->
    <xsl:output method="xml" media-type="application/xml" version="1.0" encoding="UTF-8" indent="yes"/>
    
    <!--Variables & parameters declaration-->
    <xsl:param name="base_db_export_path" />
    
    <xsl:template match="/">
        <register  xsi:noNamespaceSchemaLocation="http://inspire.ec.europa.eu/draft-schemas/registry/0.4/metadata-codelist_register.xsd" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:xlink="http://www.w3.org/1999/xlink" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">
            <xsl:apply-templates select="register"/>
        </register>
    </xsl:template>

    <xsl:template match="register">
     
        <xsl:attribute name="id">
            <xsl:value-of select="uri"/>
        </xsl:attribute>
        
        <xsl:variable name="language" select="language/isocode"></xsl:variable>  
        <xsl:element name="language" >
            <xsl:value-of select="$language" />
        </xsl:element>
        
        <!-- CodeListRegister-->    
        <xsl:if test="label != ''">
            <xsl:element name="label" >
                <xsl:attribute name="xml:lang">
                    <xsl:value-of select="label/@language"/>
                </xsl:attribute>
                <xsl:value-of select="label" />
            </xsl:element>
        </xsl:if>
        
        <xsl:if test="definition != ''">
            <xsl:variable name="tmp" select="definition"/>
            
            <xsl:element name="contentsummary" >
                <xsl:attribute name="xml:lang">
                    <xsl:value-of select="definition/@language"/>
                </xsl:attribute>
                <xsl:value-of select="$tmp" />
            </xsl:element>
        </xsl:if>
        
        <xsl:if test="description != ''">
            <xsl:variable name="tmp" select="description"/>
            
            <xsl:element name="description" >
                <xsl:attribute name="xml:lang">
                    <xsl:value-of select="description/@language"/>
                </xsl:attribute>
                <xsl:value-of select="$tmp" />
            </xsl:element>
        </xsl:if>
        
        <xsl:if test="owner != ''">
            <xsl:element name="owner" >
                <xsl:value-of select="owner" />
            </xsl:element>
        </xsl:if>
        
        <xsl:if test="manager != ''">
            <xsl:element name="manager" >
                <xsl:value-of select="manager" />
            </xsl:element>
        </xsl:if>
        
        <xsl:if test="controlbody != ''">
            <xsl:element name="controlbody" >
                <xsl:value-of select="controlbody" />
            </xsl:element>
        </xsl:if>
   
        <xsl:element name="registry" >
            <xsl:attribute name="id">
                <xsl:value-of select="registry/uri"/>
            </xsl:attribute>
            
            <label>
                <xsl:attribute name="xml:lang">
                    <xsl:value-of select="registry/label/@language"/>
                </xsl:attribute>
                <xsl:value-of select="registry/label"/>
            </label>
        </xsl:element>
   
        <!-- MetadataCodeLists-->
        <xsl:choose>
            <xsl:when test="items">
                <xsl:element name="containeditems" >
                    <xsl:for-each select="items/item">
                
                        <xsl:element name="metadata-codelist" >
                            <xsl:attribute name="id">
                                <xsl:value-of select="uri"/>
                            </xsl:attribute>
                            
                            <xsl:element name="version">
                                <xsl:value-of select="versionnumber"/>
                            </xsl:element>  
                            
                            <xsl:if test="label != ''">
                                <xsl:element name="label" >
                                    <xsl:attribute name="xml:lang">
                                        <xsl:value-of select="label/@language"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="label" />
                                </xsl:element>
                            </xsl:if>
                    
                            <xsl:if test="definition != ''">
                                <xsl:variable name="tmp" select="definition"/>

                                <xsl:element name="definition" >
                                    <xsl:attribute name="xml:lang">
                                        <xsl:value-of select="definition/@language"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="$tmp" />
                                </xsl:element>
                            </xsl:if>

                            <xsl:if test="description != ''">
                                <xsl:variable name="tmp" select="description"/>

                                <xsl:element name="description" >
                                    <xsl:attribute name="xml:lang">
                                        <xsl:value-of select="description/@language"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="$tmp" />
                                </xsl:element>
                            </xsl:if>
                    
                            <xsl:element name="itemclass" >
                                <xsl:attribute name="uriname">
                                    <xsl:value-of select="itemclass/uriname"/>
                                </xsl:attribute>
            
                                <xsl:element name="label" >
                                    <xsl:attribute name="xml:lang">
                                        <xsl:value-of select="itemclass/label/@language"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="itemclass/label" />
                                </xsl:element>
                            </xsl:element>
                            
                            <xsl:element name="status" >
                                <xsl:attribute name="id">
                                    <xsl:value-of select="status/baseuri"/>
                                    <xsl:text>/</xsl:text>
                                    <xsl:value-of select="status/uriname"/>
                                </xsl:attribute>
            
                                <xsl:element name="label" >
                                    <xsl:attribute name="xml:lang">
                                        <xsl:value-of select="status/label/@language"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="status/label" />
                                </xsl:element>
                            </xsl:element> 
        
                            <xsl:variable name="extensibility_label" select="customattributes/customattribute[name/text()='Extensibility']/uriname"></xsl:variable>
                            <xsl:variable name="extensibility_url" select="concat(baseuri, '/extensibility/', $extensibility_label)"/>
                            <xsl:if test="$extensibility_label != ''">
                                <xsl:element name="extensibility" >
                                    <xsl:attribute name="id">
                                        <xsl:value-of select="$extensibility_url"/>
                                    </xsl:attribute>
            
                                    <xsl:element name="uriname" >
                                        <xsl:value-of select="$extensibility_label" />
                                    </xsl:element>
                                </xsl:element>
                            </xsl:if>
                            
                            <xsl:if test="parent != ''">
                                <xsl:element name="parent" >
                                    <xsl:attribute name="id">
                                        <xsl:value-of select="parent/uri"/>
                                    </xsl:attribute>
                                    <label>
                                        <xsl:attribute name="xml:lang">
                                            <xsl:value-of select="parent/label/@language"/>
                                        </xsl:attribute>
                                        <xsl:value-of select="parent/label"/>
                                    </label>
                                </xsl:element>     
                            </xsl:if>
                            
                            <xsl:element name="register" >
                                <xsl:attribute name="id">
                                    <xsl:value-of select="register/uri"/>
                                </xsl:attribute>
            
                                <label>
                                    <xsl:attribute name="xml:lang">
                                        <xsl:value-of select="register/label/@language"/>
                                    </xsl:attribute>
                                    <xsl:value-of select="register/label"/>
                                </label>
                                
                                <xsl:element name="registry" >
                                    <xsl:attribute name="id">
                                        <xsl:value-of select="register/registry/uri"/>
                                    </xsl:attribute>
            
                                    <label>
                                        <xsl:attribute name="xml:lang">
                                            <xsl:value-of select="register/registry/label/@language"/>
                                        </xsl:attribute>
                                        <xsl:value-of select="register/registry/label"/>
                                    </label>
                                </xsl:element>
                            </xsl:element>   
                            
                            <xsl:if test="customattributes/customattribute[name/text()='Document'] != ''">
                                <xsl:variable name="documentUri" select="customattributes/customattribute[name/text()='Document']/uri"></xsl:variable>
                                <xsl:variable name="documentLabel" select="customattributes/customattribute[name/text()='Document']/label"></xsl:variable>
                                <xsl:variable name="documentLabelLanguage" select="customattributes/customattribute[name/text()='Document']/label/@language"></xsl:variable>
 
                                <xsl:element name="document" >
                                    <xsl:attribute name="id">
                                        <xsl:value-of select="$documentUri"/>
                                    </xsl:attribute>
                                
                                    <label>
                                        <xsl:attribute name="xml:lang">
                                            <xsl:value-of select="$documentLabelLanguage"/>
                                        </xsl:attribute>
                                        <xsl:value-of select="$documentLabel"/>
                                    </label>
                                </xsl:element> 
                            </xsl:if> 
                                
                        </xsl:element>
                    </xsl:for-each>
                </xsl:element>
        
            </xsl:when>
            <xsl:otherwise>
            </xsl:otherwise>
        </xsl:choose>
        
    </xsl:template>
</xsl:stylesheet>