/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistry.utils;

import eu.europa.ec.re3gistrycommon.utils.Configuration;
import java.util.Properties;
import javax.servlet.http.HttpServletRequest;

public class Application {

    private static Properties properties;

    /**
     * This method load all the properties related to the main module in the
     * static variable modules. Returns the instance of properties.
     *
     * @return the Properties instance
     */
    public static Properties getProperties() {
        if (properties == null) {
            properties = Configuration.getInstance().getProperties();
        }
        return properties;
    }

    /**
     * This return a string representing the basepath of the webapp.
     *
     * @param request the HttpServletRequest instance
     * @return a string representing the basepath of the webapp.
     */
    public static String getBasepath(HttpServletRequest request) {
        if (request != null) {
            String url = request.getRequestURL().toString();
            if (url != null) {
                String baseurl = url.substring(0, url.length() - request.getRequestURI().length()) + request.getContextPath() + "/";
                return baseurl;
            }
        }
        return null;
    }

}
