/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrycommon.constants;

public class Constants {

    /**
     * The name of this module
     */
    public static final String MODULE_NAME = "Re3gistryCommon";

    /* ########################################### */
    /* ########## Properties files keys ########## */
    /**
     * Persistence unit name property key
     */
    public static final String KEY_PERSISTENCE_UNIT_NAME = "application.persistenceunitname";

    /**
     * Base application properties file
     */
    public static final String BASE_APP_PROPERTY_FILE_NAME = "Application.properties";

    /* ########################################### */
    /* ############### Common keys ############### */
    /**
     * Configuration folder name
     */
    public static final String CONFIGURATIONS_FOLDER_NAME = "configurations";

    /**
     * Module folder name
     */
    public static final String MODULES_FOLDER_NAME = "modules";

    /**
     * Configuration file suffix
     */
    public static final String CONFIGURATIONS_FILE_SUFFIX = ".properties";

    /**
     * Log configuration file name
     */
    public static final String LOGCONFIG_FILE_NAME = "logcfg.xml";

    /**
     * MD5 message digest key
     */
    public static final String MD5_MESSAGE_DIGEST_KEY = "MD5";

    /* ########################################### */
    /* ################## Mail ################### */
    public static final String KEY_MAIL_CSV_SEPARATOR = "mail.attach.csv_separator";
    /**
     * Key properties mail smtp host
     */
    public static final String KEY_EXPORT_MAIL_HOST = "mail.smtp.host";

    /**
     * Key properties mail smtp port
     */
    public static final String KEY_EXPORT_MAIL_PORT = "mail.smtp.port";

    /**
     * Key properties mail smtp auth
     */
    public static final String KEY_EXPORT_MAIL_AUTH = "mail.smtp.auth";

    /**
     * Key properties mail smtp starttls
     */
    public static final String KEY_EXPORT_MAIL_STARTTLS = "mail.smtp.starttls.enable";

    /**
     * Key properties mail user
     */
    public static final String KEY_EXPORT_MAIL_USER = "mail.user";

    /**
     * Key properties mail password
     */
    public static final String KEY_EXPORT_MAIL_PASSWORD = "mail.password";

    /**
     * Key properties mail sender
     */
    public static final String KEY_EXPORT_MAIL_SENDER = "mail.sender";

    /**
     * Key properties mail sender
     */
    public static final String KEY_EXPORT_MAIL_DEFAULT_RECIPIENT = "mail.recipient";

    /* ########################################### */
    /* ############ Localization keys ############ */
    /**
     * Localizations properties prefix
     */
    public static final String LOCALIZATION_PREFIX = "localization.";

    /**
     * Localizations properties suffix
     */
    public static final String LOCALIZATION_SUFFIX = ".LocalizationBundle";

    /**
     * Base appname
     */
    public static final String BASEAPP_NAME = "Application";

    /**
     * Localizations language key
     */
    public static final String LANGUAGE_SESSION_KEY = "language";

    /* ########################################### */
    /* ########## Additional SQL query ########### */
    /**
     * Max item's version number
     */
    public static final String SQL_MAXVERSION_BY_ITEM = "select max(versionnumber) from item where uriname=?";

    /**
     * Select latest itemcollection by item
     */
    public static final String SQL_LARESTVERSION_OF_COLLECTION_BY_ITEM = "SELECT * FROM Itemcollection p JOIN Item i ON p.collection=i.uuid WHERE i.versionnumber = 0 and p.item = ?";

    /**
     * Select latest itemparent by item
     */
    public static final String SQL_LARESTVERSION_OF_PARENT_BY_ITEM = "SELECT * FROM Itemparent p JOIN Item i ON p.parent=i.uuid WHERE i.versionnumber = 0 and p.item = ?";
    public static final String SQL_LARESTVERSION_OF_ITEM_BY_PARENT = "SELECT * FROM Itemparent p JOIN Item i ON p.parent=i.uuid WHERE i.versionnumber = 0 and p.parent = ?";

    /**
     * Select successors by item
     */
    public static final String SQL_LARESTVERSION_OF_SUCCESSOR_BY_ITEM = "SELECT * FROM Itemsuccessor p JOIN Item i ON p.successor=i.uuid WHERE i.versionnumber = 0 and p.item = ?";

    /**
     * Select successors by item
     */
    public static final String SQL_LARESTVERSION_OF_PREDECESSOR_BY_ITEM = "SELECT * FROM Itemsuccessor p JOIN Item i ON p.item=i.uuid WHERE i.versionnumber = 0 and p.item = ?";

    /**
     * Check custom attribute value by name & value
     */
    public static final String SQL_CUSTOM_ATTRIBUTE_BY_NAME_VALUE = "SELECT * FROM customattribute ca JOIN customattributevalue cav ON ca.uuid = cav.customattribute JOIN localization lo ON cav.uuid = lo.customattributevalue WHERE ca.name=? AND lo.label = ?";

    /**
     * Get all the version of an item
     */
    public static final String SQL_ITEM_ALL_VERSION = "SELECT * FROM Item i WHERE i.uriname = ? AND i.itemclass = ? ORDER BY versionnumber ASC";
    public static final String SQL_ITEM_ALL_VERSION_COLLECTION = "SELECT * FROM Item i WHERE i.uuid IN (SELECT ic.item FROM Itemcollection ic WHERE ic.item IN (SELECT ii.uuid FROM Item ii WHERE ii.uriname = ? AND ii.itemclass = ?) AND ic.collection IN (SELECT iii.uuid FROM Item iii WHERE iii.uriname = ?)) ORDER BY versionnumber ASC";

    /**
     * Clean old child relations
     */
    public static final String SQL_CLEAN_CHILDREN_REL = "DELETE FROM Itemparent WHERE uuid IN (SELECT ip.uuid FROM Itemparent ip JOIN Item i ON ip.item=i.uuid WHERE ip.parent = ? AND i.versionnumber>0)";
    public static final String SQL_CLEAN_PARENT_REL = "DELETE FROM Itemparent WHERE uuid IN (SELECT ip.uuid FROM Itemparent ip JOIN Item i ON ip.parent=i.uuid WHERE ip.item = ? AND i.versionnumber>0)";
}
