/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrycommon.model;

import eu.europa.ec.re3gistrycommon.utils.StringUtils;
import java.io.Serializable;
import java.util.Date;
import java.util.List;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

@Entity
@Table(name = "dataprocedure")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Dataprocedure.findAll", query = "SELECT d FROM Dataprocedure d"),
    @NamedQuery(name = "Dataprocedure.findByUuid", query = "SELECT d FROM Dataprocedure d WHERE d.uuid = :uuid"),
    @NamedQuery(name = "Dataprocedure.findByDatecompleted", query = "SELECT d FROM Dataprocedure d WHERE d.datecompleted = :datecompleted"),
    @NamedQuery(name = "Dataprocedure.findByFolder", query = "SELECT d FROM Dataprocedure d WHERE d.folder = :folder"),
    /**
     * custom query
     */
    @NamedQuery(name = "Dataprocedure.findByProcedurestatus", query = "SELECT d FROM Dataprocedure d WHERE d.procedurestatus = :procedurestatus"),
    @NamedQuery(name = "Dataprocedure.findAllOrderAscByDatecompleted", query = "SELECT d FROM Dataprocedure d WHERE d.datecompleted is not null"),
    @NamedQuery(name = "Dataprocedure.findAllAfterDateOrderAscByDatecompleted", query = "SELECT d FROM Dataprocedure d WHERE d.datecompleted is not null AND d.datecompleted >= :date ORDER BY d.datecompleted ASC"),
    @NamedQuery(name = "Dataprocedure.findAllBetweenDatesOrderAscByDatecompleted", query = "SELECT d FROM Dataprocedure d WHERE d.datecompleted is not null AND d.datecompleted >= :dateinit AND d.datecompleted <= :datefinal ORDER BY d.datecompleted ASC")
})
public class Dataprocedure implements Serializable {

    private static final long serialVersionUID = 1L;
    
    @Id
    @Basic(optional = false)
    @Column(name = "uuid")
    private String uuid;
    
    @Basic(optional = false)
    @Column(name = "folder")
    private String folder;
    @Basic(optional = false)
    @Column(name = "comment")
    private String comment;
    
    @Basic(optional = false)
    @Column(name = "datestarted")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datestarted;
    @Column(name = "datecompleted")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datecompleted;
    
    @JoinColumn(name = "procedurestatus", referencedColumnName = "uuid")
    @ManyToOne(optional = false)
    private Procedurestatus procedurestatus;

    @OneToMany(cascade = CascadeType.ALL, mappedBy = "dataprocedure")
    private List<Changelog> changelogList;

    public Dataprocedure() {
    }

    public Dataprocedure(String uuid) {
        this.uuid = uuid;
    }

    public Dataprocedure(String uuid, Date datecompleted) {
        this.uuid = uuid;
        this.datecompleted = datecompleted;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getFolder() {
        return folder;
    }

    public void setFolder(String folder) {
        this.folder = folder;
    }

    public Date getDatestarted() {
        return datestarted;
    }

    public void setDatestarted(Date datestarted) {
        this.datestarted = datestarted;
    }

    public Date getDatecompleted() {
        return datecompleted;
    }

    public void setDatecompleted(Date datecompleted) {
        this.datecompleted = datecompleted;
    }

    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public Procedurestatus getProcedurestatus() {
        return procedurestatus;
    }

    public void setProcedurestatus(Procedurestatus procedurestatus) {
        this.procedurestatus = procedurestatus;
    }

    @XmlTransient
    public List<Changelog> getChangelogList() {
        return changelogList;
    }

    public void setChangelogList(List<Changelog> changelogList) {
        this.changelogList = changelogList;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (uuid != null ? uuid.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof Dataprocedure)) {
            return false;
        }
        Dataprocedure other = (Dataprocedure) object;
        return (this.uuid != null || other.uuid == null) && (this.uuid == null || this.uuid.equals(other.uuid));
    }

    @Override
    public String toString() {
        return "eu.europa.ec.re3gistrycommon.model.Dataprocedure[ uuid=" + uuid + " ]";
    }

    /**
     * Creates the uuid for the Dataprocedure's objects
     *
     * @param timestamp
     * @return the uuid
     * @throws Exception
     */
    public static String createUuid(long timestamp) throws Exception {
        return StringUtils.createUUID(Long.toString(timestamp), Dataprocedure.class);
    }
}
