/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrycommon.model;

import eu.europa.ec.re3gistrycommon.utils.StringUtils;
import java.io.Serializable;
import java.util.Date;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.xml.bind.annotation.XmlRootElement;

@Entity
@Table(name = "itemsuccessor")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Itemsuccessor.findAll", query = "SELECT i FROM Itemsuccessor i"),
    @NamedQuery(name = "Itemsuccessor.findByUuid", query = "SELECT i FROM Itemsuccessor i WHERE i.uuid = :uuid"),
    /**
     * custom query
     */
    @NamedQuery(name = "Itemsuccessor.findByItem", query = "SELECT i FROM Itemsuccessor i WHERE i.item = :item"),
    @NamedQuery(name = "Itemsuccessor.findBySuccessor", query = "SELECT i FROM Itemsuccessor i WHERE i.successor = :successor"),
})
public class Itemsuccessor implements Serializable {
    @Basic(optional = false)
    @Column(name = "datecreation")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datecreation;
    @Column(name = "datelastupdate")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datelastupdate;

    private static final long serialVersionUID = 1L;
    @Id
    @Basic(optional = false)
    @Column(name = "uuid")
    private String uuid;
    @JoinColumn(name = "successor", referencedColumnName = "uuid")
    @ManyToOne(optional = false)
    private Item successor;
    @JoinColumn(name = "item", referencedColumnName = "uuid")
    @ManyToOne(optional = false)
    private Item item;

    public Itemsuccessor() {
    }

    public Itemsuccessor(String uuid) {
        this.uuid = uuid;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public Item getSuccessor() {
        return successor;
    }

    public void setSuccessor(Item successor) {
        this.successor = successor;
    }

    public Item getItem() {
        return item;
    }

    public void setItem(Item item) {
        this.item = item;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (uuid != null ? uuid.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof Itemsuccessor)) {
            return false;
        }
        Itemsuccessor other = (Itemsuccessor) object;
        return (this.uuid != null || other.uuid == null) && (this.uuid == null || this.uuid.equals(other.uuid));
    }

    @Override
    public String toString() {
        return "eu.europa.ec.re3gistrycommon.model.Itemsuccessor[ uuid=" + uuid + " ]";
    }

    /**
     * Creates the uuid for the Itemsuccessor's objects
     *
     * @param itemLocalId The item's local id
     * @param successorItemLocalId The successor item's local id
     * @return the uuid
     * @throws Exception
     */
    public static String createUuid(String itemLocalId, String successorItemLocalId) throws Exception {
        return StringUtils.createUUID(itemLocalId + successorItemLocalId, Itemsuccessor.class);
    }

    public Date getDatecreation() {
        return datecreation;
    }

    public void setDatecreation(Date datecreation) {
        this.datecreation = datecreation;
    }

    public Date getDatelastupdate() {
        return datelastupdate;
    }

    public void setDatelastupdate(Date datelastupdate) {
        this.datelastupdate = datelastupdate;
    }

}
