/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrycommon.model;

import java.io.Serializable;
import java.util.List;
import javax.persistence.Basic;
import javax.persistence.CascadeType;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

@Entity
@Table(name = "languagecode")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Languagecode.findAll", query = "SELECT l FROM Languagecode l"),
    @NamedQuery(name = "Languagecode.findByUuid", query = "SELECT l FROM Languagecode l WHERE l.uuid = :uuid"),
    @NamedQuery(name = "Languagecode.findByLabel", query = "SELECT l FROM Languagecode l WHERE l.label = :label"),
    @NamedQuery(name = "Languagecode.findByIsocode", query = "SELECT l FROM Languagecode l WHERE l.isocode = :isocode"),
    /**
     * custom query
     */
    @NamedQuery(name = "Languagecode.findMasterLanguagecode", query = "SELECT l FROM Languagecode l WHERE l.masterlanguage = '1'")
})
public class Languagecode implements Serializable {

    private static final long serialVersionUID = 1L;
    @Id
    @Basic(optional = false)
    @Column(name = "uuid")
    private String uuid;
    @Basic(optional = false)
    @Column(name = "label")
    private String label;
    @Basic(optional = false)
    @Column(name = "isocode")
    private String isocode;
    @Column(name = "masterlanguage")
    private Boolean masterlanguage;
    @OneToMany(cascade = CascadeType.ALL, mappedBy = "language")
    private List<Localization> localizationList;
    @OneToMany(mappedBy = "languagecode")
    private List<Changelog> changelogList;

    public Languagecode() {
    }

    public Languagecode(String uuid) {
        this.uuid = uuid;
    }

    public Languagecode(String uuid, String label, String isocode) {
        this.uuid = uuid;
        this.label = label;
        this.isocode = isocode;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getLabel() {
        return label;
    }

    public void setLabel(String label) {
        this.label = label;
    }

    public String getIsocode() {
        return isocode;
    }

    public void setIsocode(String isocode) {
        this.isocode = isocode;
    }

    public Boolean getMasterlanguage() {
        return masterlanguage;
    }

    public void setMasterlanguage(Boolean masterlanguage) {
        this.masterlanguage = masterlanguage;
    }

    @XmlTransient
    public List<Localization> getLocalizationList() {
        return localizationList;
    }

    public void setLocalizationList(List<Localization> localizationList) {
        this.localizationList = localizationList;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (uuid != null ? uuid.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof Languagecode)) {
            return false;
        }
        Languagecode other = (Languagecode) object;
        return (this.uuid != null || other.uuid == null) && (this.uuid == null || this.uuid.equals(other.uuid));
    }

    @Override
    public String toString() {
        return "eu.europa.ec.re3gistrycommon.model.Languagecode[ uuid=" + uuid + " ]";
    }

    @XmlTransient
    public List<Changelog> getChangelogList() {
        return changelogList;
    }

    public void setChangelogList(List<Changelog> changelogList) {
        this.changelogList = changelogList;
    }
}
