/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrycommon.model;

import java.io.Serializable;
import java.util.Date;
import java.util.List;
import javax.persistence.Basic;
import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.OneToMany;
import javax.persistence.Table;
import javax.persistence.Temporal;
import javax.persistence.TemporalType;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlTransient;

@Entity
@Table(name = "staticizer")
@XmlRootElement
@NamedQueries({
    @NamedQuery(name = "Staticizer.findAll", query = "SELECT s FROM Staticizer s"),
    @NamedQuery(name = "Staticizer.findByUuid", query = "SELECT s FROM Staticizer s WHERE s.uuid = :uuid"),
    @NamedQuery(name = "Staticizer.findByDatestart", query = "SELECT s FROM Staticizer s WHERE s.datestart = :datestart"),
    @NamedQuery(name = "Staticizer.findByDateend", query = "SELECT s FROM Staticizer s WHERE s.dateend = :dateend"),
    /**
     * * custom query*
     */
    @NamedQuery(name = "Staticizer.findAllOrderDescByDateStart", query = "SELECT s FROM Staticizer s ORDER by s.datestart DESC"),
    @NamedQuery(name = "Staticizer.findLastCompletedOrderDescByDateStart", query = "SELECT s FROM Staticizer s WHERE s.procedurestatus = :procedurestatus ORDER by s.datestart DESC"),
    @NamedQuery(name = "Staticizer.findAllCompletedAfterDateOrderDescByAndDateStart", query = "SELECT s FROM Staticizer s WHERE s.procedurestatus = :procedurestatus AND s.datestart >= :date ORDER by s.datestart DESC"),
    @NamedQuery(name = "Staticizer.findQueuedOrderAscByDateStart", query = "SELECT s FROM Staticizer s WHERE s.procedurestatus = :procedurestatus ORDER by s.datestart ASC"),
    @NamedQuery(name = "Staticizer.findInProgressOrderDescByDateStart", query = "SELECT s FROM Staticizer s WHERE s.procedurestatus = :procedurestatus ORDER by s.datestart DESC")
})
public class Staticizer implements Serializable {

    private static final long serialVersionUID = 1L;
    
    @Id
    @Basic(optional = false)
    @Column(name = "uuid")
    private String uuid;
    
    @Basic(optional = false)
    @Column(name = "datestart")
    @Temporal(TemporalType.TIMESTAMP)
    private Date datestart;
    @Column(name = "dateend")
    @Temporal(TemporalType.TIMESTAMP)
    private Date dateend;
    
    @JoinColumn(name = "procedurestatus", referencedColumnName = "uuid")
    @ManyToOne(optional = false)
    private Procedurestatus procedurestatus;
    
    @OneToMany(mappedBy = "staticizer")
    private List<Changelog> changelogList;

    public Staticizer() {
    }

    public Staticizer(String uuid) {
        this.uuid = uuid;
    }

    public Staticizer(String uuid, Date datestart) {
        this.uuid = uuid;
        this.datestart = datestart;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public Date getDatestart() {
        return datestart;
    }

    public void setDatestart(Date datestart) {
        this.datestart = datestart;
    }

    public Date getDateend() {
        return dateend;
    }

    public void setDateend(Date dateend) {
        this.dateend = dateend;
    }

    public Procedurestatus getProcedurestatus() {
        return procedurestatus;
    }

    public void setProcedurestatus(Procedurestatus procedurestatus) {
        this.procedurestatus = procedurestatus;
    }

    @XmlTransient
    public List<Changelog> getChangelogList() {
        return changelogList;
    }

    public void setChangelogList(List<Changelog> changelogList) {
        this.changelogList = changelogList;
    }

    @Override
    public int hashCode() {
        int hash = 0;
        hash += (uuid != null ? uuid.hashCode() : 0);
        return hash;
    }

    @Override
    public boolean equals(Object object) {
        if (!(object instanceof Staticizer)) {
            return false;
        }
        Staticizer other = (Staticizer) object;
        return (this.uuid != null || other.uuid == null) && (this.uuid == null || this.uuid.equals(other.uuid));
    }

    @Override
    public String toString() {
        return "eu.europa.ec.re3gistrycommon.model.Staticizer[ uuid=" + uuid + " ]";
    }
}
