/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrycommon.utils;

import eu.europa.ec.re3gistrycommon.constants.Constants;
import java.io.File;
import java.io.IOException;
import java.util.Date;
import java.util.Locale;
import java.util.Properties;
import java.util.ResourceBundle;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import org.apache.log4j.Logger;
import javax.mail.Authenticator;
import javax.mail.Message;
import javax.mail.Multipart;
import javax.mail.PasswordAuthentication;
import javax.mail.Session;
import javax.mail.Transport;
import javax.mail.internet.InternetAddress;
import javax.mail.internet.MimeBodyPart;
import javax.mail.internet.MimeMessage;
import javax.mail.internet.MimeMultipart;

public class Mail {

    private static final Logger log = Logger.getLogger(Constants.MODULE_NAME);

    public void sendbyMail(HttpServletRequest request, File file, String subject, String body) throws ServletException, IOException {
        try {
            HttpSession s = request.getSession();
            String currentLanguage = (String) s.getAttribute(Constants.LANGUAGE_SESSION_KEY);
            if (currentLanguage == null) {
                currentLanguage = request.getLocale().toString();
            }            
            ResourceBundle localization = ResourceBundle.getBundle(Constants.LOCALIZATION_PREFIX + Constants.BASEAPP_NAME + Constants.LOCALIZATION_SUFFIX, new Locale(currentLanguage));
            
            // sets SMTP server properties
            final Properties props = Configuration.getInstance().getProperties();
            
            //Mail properties
            Properties properties = new Properties();
            properties.put("mail.smtp.host", props.getProperty(Constants.KEY_EXPORT_MAIL_HOST));
            properties.put("mail.smtp.port", props.getProperty(Constants.KEY_EXPORT_MAIL_PORT));
            properties.put("mail.smtp.auth", props.getProperty(Constants.KEY_EXPORT_MAIL_AUTH));
            properties.put("mail.smtp.starttls.enable", props.getProperty(Constants.KEY_EXPORT_MAIL_STARTTLS));
            properties.put("mail.user", props.getProperty(Constants.KEY_EXPORT_MAIL_USER));
            properties.put("mail.password", props.getProperty(Constants.KEY_EXPORT_MAIL_PASSWORD));

            // creates a new session with an authenticator
            Authenticator auth = new Authenticator() {
                @Override
                public PasswordAuthentication getPasswordAuthentication() {
                    return new PasswordAuthentication(props.getProperty(Constants.KEY_EXPORT_MAIL_USER), props.getProperty(Constants.KEY_EXPORT_MAIL_PASSWORD));
                }
            };
            Session session = Session.getInstance(properties, auth);

            // creates a new e-mail message
            Message msg = new MimeMessage(session);
            
            //Getting attribute
            String to = request.getParameter("to");
            to = (to == null || to.length()<=0) ? props.getProperty(Constants.KEY_EXPORT_MAIL_DEFAULT_RECIPIENT) : to;
      
            msg.setFrom(new InternetAddress(props.getProperty(Constants.KEY_EXPORT_MAIL_SENDER)));
            InternetAddress[] toAddresses = {new InternetAddress(to)};
            msg.setRecipients(Message.RecipientType.TO, toAddresses);
            msg.setSubject(subject);
            msg.setSentDate(new Date());

            // creates message part
            MimeBodyPart messageBodyPart = new MimeBodyPart();
                   
            messageBodyPart.setContent(localization.getString("mail.title") + body + localization.getString("mail.footer"), "text/html");

            // creates multi-part
            Multipart multipart = new MimeMultipart();
            multipart.addBodyPart(messageBodyPart);

            // adds attachments
            if (file != null) {
                MimeBodyPart attachPart = new MimeBodyPart();
                try {
                    attachPart.attachFile(file);
                } catch (IOException ex) {
                    ex.printStackTrace();
                }
                multipart.addBodyPart(attachPart);
            }

            // sets the multi-part as e-mail's content
            msg.setContent(multipart);

            // sends the e-mail
            Transport.send(msg);

        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
