/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrydata.constants;

/**
 * Collected constants of general utility.
 */
public final class Constants {

    /* ###################################### */
    /* ########## Common constants ########## */
    /**
     * The name of this module
     */
    public static final String MODULE_NAME = "Re3gistryData";

    /**
     * File encoding
     */
    public static final String FILE_ENCODING = "UTF-8";

    /**
     * Common checks language
     */
    public static final String CHECK_COMMON_LANGUAGE = "en";

    /**
     * The hashmap key separator
     */
    public static final String HASHMAP_KEY_SEPARATOR = "_";

    /**
     * Data file extension
     */
    public static final String ACTION_FILE_EXTENSION = ".csv";

    /**
     * Zip file extension
     */
    public static final String ZIP_FILE_EXTENSION = ".zip";

    /**
     * The name of the default folder for temp files
     */
    public static final String DEFAULT_TEMP_FOLDER_NAME = "temp";

    /**
     * Report type error
     */
    public static final String REPORT_TYPE_ERROR = "Error";

    /**
     * Report type warning
     */
    public static final String REPORT_TYPE_WARNING = "Warning";

    /* ###################################### */
    /* ########## Form fields names ########## */
    /**
     * The name of the form data procedure comment field
     */
    public static final String FORM_FIELD_COMMENT = "lbl";

    /**
     * The name of the form data procedure force warnings field
     */
    public static final String FORM_FIELD_FWARNINGS = "fwarnings";
    /**
     * Check box on value
     */
    public static final String CHECKBOX_ON_VALUE = "on";

    /* ###################################### */
    /* ####### Request attribute keys ####### */
    /**
     * The request attribute key for the reports
     */
    public static final String REPORTS_KEY = "reports";

    /**
     * The request attribute key for the temp data file
     */
    public static final String TEMPDATAFILE_KEY = "tmpdatafile";

    /**
     * The request attribute key for the error
     */
    public static final String ERROR_TYPE = "errortype";

    /**
     * The request attribute key for the format error
     */
    public static final String ERROR_KEY_FORMAT = "format";

    /**
     * The request attribute key for the analyzer error
     */
    public static final String ERROR_KEY_ANALYZER = "analyzer";

    /**
     * The request attribute key for the store error
     */
    public static final String ERROR_KEY_STORE = "store";

    /**
     * The request attribute key for the analyzer error
     */
    public static final String KEY_COMPLETE = "complete";

    /**
     * The request attribute key for the generic error
     */
    public static final String ERROR_KEY_GENERIC = "generic";

    /**
     * The request attribute key for the successful action
     */
    public static final String PROCEDURE_COMPLETED = "completed";

    /* ################################################ */
    /* ################ Report context ################ */
    /**
     * The key for the Procedure Start report context
     */
    public static final String REPORT_CONTEXT_DATAPROCEDUTE = "Data procedure";

    /**
     * The key for the Addition manager context
     */
    public static final String REPORT_CONTEXT_ADDITIONMGR = "Addition manager";

    /**
     * The key for the Retirement manager context
     */
    public static final String REPORT_CONTEXT_RETIREMENTMGR = "Retirement manager";

    /**
     * The key for the Invalidation manager context
     */
    public static final String REPORT_CONTEXT_INVALIDATIONMGR = "Invalidation manager";

    /**
     * The key for the Supersession manager context
     */
    public static final String REPORT_CONTEXT_SUPERSESSIONMGR = "Supersession manager";

    /**
     * The key for the Clarification manager context
     */
    public static final String REPORT_CONTEXT_CLARIFICATIONMGR = "Clarification manager";

    /**
     * The key for the Data manager context
     */
    public static final String REPORT_CONTEXT_DATAMGR = "Data manager";


    /* ################################################ */
    /* ################ Report actions ################ */
    /**
     * The key for the Procedure Start report action
     */
    public static final String REPORT_ACTION_DATAPROCEDUTE = "Process data";

    /**
     * The key for the store addition action
     */
    public static final String REPORT_ACTION_STOREADDITION = "Store addition";

    /**
     * The key for the analyze addition action
     */
    public static final String REPORT_ACTION_ANALYZEADDITION = "Analyze addition";

    /**
     * The key for the Fix parent collection action
     */
    public static final String REPORT_ACTION_FIXPARENTCOLLECTION = "Fix parent collection";

    /**
     * The key for the Process retirement report action
     */
    public static final String REPORT_ACTION_PROCESSRETIREMENT = "Process retirement";

    /**
     * The key for the Process invalidation report action
     */
    public static final String REPORT_ACTION_PROCESSINVALIDATION = "Process invalidation";

    /**
     * The key for the process supersession report action
     */
    public static final String REPORT_ACTION_PROCESSSUPERSESSION = "Process supersession";

    /**
     * The key for the process clarification action
     */
    public static final String REPORT_ACTION_PROCESSCLARIFICATION = "Process clarification";

    /**
     * The key for the Data manager check check files
     */
    public static final String REPORT_ACTION_DATAMGR_CHECKFILES = "Check files";

    /**
     * The key for the analyze retirement action
     */
    public static final String REPORT_ACTION_ANALYZERETIREMENT = "Analyze retirement";

    /**
     * The key for the analyze invalidation action
     */
    public static final String REPORT_ACTION_ANALYZEINVALIDATION = "Analyze invalidation";

    /**
     * The key for the analyze supersession action
     */
    public static final String REPORT_ACTION_ANALYZESUPERSESSION = "Analyze supersession";

    /**
     * The key for the analyze clarification action
     */
    public static final String REPORT_ACTION_ANALYZECLARIFICATION = "Analyze clarification";


    /* ################################################ */
    /* ############# Item status constants ############ */
    /**
     * Procedure status constant: valid
     */
    public static final String ITEMSTATUS_VALID = "1";
    /**
     * Procedure status constant: valid text
     */
    public static final String ITEMSTATUS_VALID_TEXT = "valid";

    /**
     * Procedure status constant: submitted
     */
    public static final String ITEMSTATUS_SUBMITTED = "3";
    /**
     * Procedure status constant: submitted text
     */
    public static final String ITEMSTATUS_SUBMITTED_TEXT = "submitted";

    /**
     * Procedure status constant: superseded
     */
    public static final String ITEMSTATUS_SUPERSEDED = "4";
    /**
     * Procedure status constant: superseded text
     */
    public static final String ITEMSTATUS_SUPERSEDED_TEXT = "superseded";

    /**
     * Procedure status constant: invalid
     */
    public static final String ITEMSTATUS_INVALID = "2";
    /**
     * Procedure status constant: invalid text
     */
    public static final String ITEMSTATUS_INVALID_TEXT = "invalid";

    /**
     * Procedure status constant: retired
     */
    public static final String ITEMSTATUS_RETIRED = "5";
    /**
     * Procedure status constant: retired text
     */
    public static final String ITEMSTATUS_RETIRED_TEXT = "retired";

    /**
     * Procedure status constant: in progress uuid
     */
    public static final String PROCEDURESTATUS_INPROGRESS = "1";
    /**
     * Procedure status constant: failed uuid
     */
    public static final String PROCEDURESTATUS_FAILED = "2";
    /**
     * Procedure status constant: completed uuid
     */
    public static final String PROCEDURESTATUS_COMPLETED = "3";

    /* ####################################### */
    /* ########## Actions constants ########## */
    /**
     * Actions constant: addition
     */
    public static final String ACTION_ADDITION = "addition";

    /**
     * Actions constant: clarification
     */
    public static final String ACTION_CLARIFICATION = "clarification";

    /**
     * Actions constant: invalidation
     */
    public static final String ACTION_INVALIDATION = "invalidation";

    /**
     * Actions constant: retirement
     */
    public static final String ACTION_RETIREMENT = "retirement";

    /**
     * Actions constant: supersession
     */
    public static final String ACTION_SUPERSESSION = "supersession";

    /* ########################################### */
    /* ########## Properties files keys ########## */
    /**
     * Key data available languages
     */
    public static final String KEY_OPERATING_LANGUAGES = "data.operatinglanguage";
    /**
     * Key data available languages
     */
    public static final String KEY_DATA_LANGUAGES = "data.supportedlanguage";

    /**
     * Key latest version
     */
    public static final String KEY_LATEST_VERSION = "data.latestversion";

    /**
     * Key Temp data folder
     */
    public static final String KEY_CUSTOM_TEMP_FOLDER = "data.customtempfolder";

    /**
     * Key CSV delimiter
     */
    public static final String KEY_CSV_DELIMITER = "data.csv.delimiter";

    /**
     * Key Custom attribute prefix
     */
    public static final String KEY_CUSTOMATTRIBUTE_PREFIX = "data.customattribute.prefix";

    /**
     * Key custom attribute property open
     */
    public static final String KEY_CUSTOM_ATTRIBUTE_OPEN = "data.customattribute.open";

    /**
     * Key custom attribute property close
     */
    public static final String KEY_CUSTOM_ATTRIBUTE_CLOSE = "data.customattribute.close";

    /**
     * Key custom attribute property delimiter
     */
    public static final String KEY_CUSTOM_ATTRIBUTE_DELIMITER = "data.customattribute.delimiter";

    /**
     * Key mandatory field list delimiter
     */
    public static final String KEY_MANDATORY_FIELD_DELIMITER = "data.mandatoryfields.delimiter";

    /**
     * Key for the number of required csv fields
     */
    public static final String KEY_COMMONFIELDS_NUMBER = "data.commonfields.";

    /**
     * Key for the mandatory field
     */
    public static final String KEY_MANDATORY_FIELDS = "data.mantatoryfields.";

    /* ################################################################## */
    /* ############### Error and warning list export keys ############### */
    /**
     * Key separator parameter
     */
    public static final String KEY_EXPORT_SEPARATOR = "separator";

    /**
     * Key standard csv separator
     */
    public static final String KEY_EXPORT_STANDARD_CSV_SEPARATOR = ",";

    /**
     * Key export for the temp file attachment (prefix)
     */
    public static final String KEY_EXPORT_MAIL_TMPFILE_PREFIX = "mailexport_";

    /**
     * Key export for the temp file attachment (suffix)
     */
    public static final String KEY_EXPORT_MAIL_TMPFILE_SUFFIX = "_attachment.csv";

    /**
     * Key export type CSV
     */
    public static final String MAILATTACH_CSV_SEPARATOR = ",";

    /**
     * Key export type mail
     */
    public static final String KEY_EXPORT_MODE_MAIL = "2";

    /**
     * Key export type mail key
     */
    public static final String KEY_MODE_MAIL = "mode";

    /**
     * Key export mail attachment name
     */
    public static final String KEY_MAIL_ATTACHMENT_NAME = "output.csv";

    /* ########################################### */
    /* ############ Localization keys ############ */
    /**
     * Localizations properties prefix
     */
    public static final String LOCALIZATION_PREFIX = "localization.";

    /**
     * Localizations properties suffix
     */
    public static final String LOCALIZATION_SUFFIX = ".LocalizationBundle";

    /**
     * Base appname
     */
    public static final String BASEAPP_NAME = "Application";

    /**
     * Localizations language key
     */
    public static final String LANGUAGE_SESSION_KEY = "language";

    /* ########################################### */
    /* ################## Getter ################# */
    /**
     * Getter for JSP EL for the REPORTS_KEY
     *
     * @return String code
     */
    public String getREPORTS_KEY() {
        return REPORTS_KEY;
    }

    /**
     * Getter for JSP EL for the ERROR_TYPE
     *
     * @return String code
     */
    public String getERROR_TYPE() {
        return ERROR_TYPE;
    }

    /**
     * Getter for JSP EL for the ERROR_KEY_FORMAT
     *
     * @return String code
     */
    public String getERROR_KEY_FORMAT() {
        return ERROR_KEY_FORMAT;
    }

    /**
     * Getter for JSP EL for the ERROR_KEY_ANALYZER
     *
     * @return String code
     */
    public String getERROR_KEY_ANALYZER() {
        return ERROR_KEY_ANALYZER;
    }

    /**
     * Getter for JSP EL for the ERROR_KEY_GENERIC
     *
     * @return String code
     */
    public String getERROR_KEY_GENERIC() {
        return ERROR_KEY_GENERIC;
    }

    /**
     * Getter for JSP EL for the ERROR_KEY_STORE
     *
     * @return String code
     */
    public String getERROR_KEY_STORE() {
        return ERROR_KEY_STORE;
    }

    /**
     * Getter for JSP EL for the PROCEDURE_COMPLETED
     *
     * @return String code
     */
    public String getPROCEDURE_COMPLETED() {
        return PROCEDURE_COMPLETED;
    }

    /**
     * Getter for JSP EL for the FORM_FIELD_FWARNINGS
     *
     * @return String code
     */
    public String getFORM_FIELD_FWARNINGS() {
        return FORM_FIELD_FWARNINGS;
    }

    /**
     * Getter for JSP EL for the CHECKBOX_ON_VALUE
     *
     * @return String code
     */
    public String getCHECKBOX_ON_VALUE() {
        return CHECKBOX_ON_VALUE;
    }
}
