/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrydata.managers;

import eu.europa.ec.re3gistrycommon.model.Dataprocedure;
import eu.europa.ec.re3gistrydata.constants.Constants;
import eu.europa.ec.re3gistrydata.managers.actions.AdditionMgr;
import eu.europa.ec.re3gistrydata.managers.actions.ClarificationMgr;
import eu.europa.ec.re3gistrydata.managers.actions.InvalidationMgr;
import eu.europa.ec.re3gistrydata.managers.actions.RetirementMgr;
import eu.europa.ec.re3gistrydata.managers.actions.SupersessionMgr;
import javax.persistence.EntityManager;
import org.apache.log4j.Logger;

public class AnalyzerMgr {

    //static variables
    private static final Logger log = Logger.getLogger(Constants.MODULE_NAME);

    //Common variables
    private final ReportMgr reportMgr;
    private final DataMgr dataMgr;
    private Dataprocedure dataprocedure;

    //Managers
    private AdditionMgr additionMgr;
    private RetirementMgr retirementMgr;
    private InvalidationMgr invalidationMgr;
    private SupersessionMgr supersessionMgr;
    private ClarificationMgr clarificationMgr;

    /**
     * Class initializer
     *
     * @param reportMgr
     * @param dataMgr
     * @throws Exception
     */
    public AnalyzerMgr(ReportMgr reportMgr, DataMgr dataMgr) throws Exception {
        log.info("# Initializing the analyzer manager ...");

        this.reportMgr = reportMgr;
        this.dataMgr = dataMgr;

        log.info("# Analyzer manager initialized.");
    }

    /**
     * Start the data store procedure
     *
     * @throws Exception
     */
    public void analyzeData(EntityManager em) throws Exception {
        log.info("# Starting analyzers.");
     
        //Initializing managers
        additionMgr = new AdditionMgr(em, reportMgr, dataMgr, this.dataprocedure);
        retirementMgr = new RetirementMgr(em, reportMgr, dataMgr, this.dataprocedure);
        invalidationMgr = new InvalidationMgr(em, reportMgr, dataMgr, this.dataprocedure);
        supersessionMgr = new SupersessionMgr(em, reportMgr, dataMgr, this.dataprocedure);
        clarificationMgr = new ClarificationMgr(em, reportMgr, dataMgr, this.dataprocedure);

        //Analyze the additions
        additionMgr.analyzeAdditions();

        //Analyze clarifications
        clarificationMgr.analyzeClarifications();
        
        //Analyze retirements
        retirementMgr.analyzeRetirements();

        //Analyze invalidations
        invalidationMgr.analyzeInvalidations();

        //Analyze supersession
        supersessionMgr.analyzeSupersessions();

    }
}
