/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrydata.servlet;

import eu.europa.ec.re3gistrydata.constants.Constants;
import eu.europa.ec.re3gistrydata.managers.DataMgr;
import eu.europa.ec.re3gistrydata.managers.ReportMgr;
import java.io.File;
import java.io.IOException;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.apache.commons.io.FileUtils;
import org.apache.log4j.Logger;

public class ProcedureStart extends HttpServlet {

    private static final Logger log = Logger.getLogger(Constants.MODULE_NAME);

    /**
     * Processes requests for both HTTP <code>GET</code> and <code>POST</code>
     * methods.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    protected void startProcedure(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        log.info("###");
        log.info("### STARTING DATA PROCEDURE ###");

        //Reset the error and warning list session variable. This is for the error and warning list export            
        request.getSession().setAttribute(Constants.REPORTS_KEY, null);

        ReportMgr reportMgr = new ReportMgr();

        try {
            DataMgr dataMgr = new DataMgr(request, reportMgr);
            dataMgr.startProcedure();

            //Set the error and warning list request and session variable.
            request.setAttribute(Constants.PROCEDURE_COMPLETED, true);
            request.setAttribute(Constants.REPORTS_KEY, reportMgr.getReports());

            if (request.getAttribute(Constants.FORM_FIELD_FWARNINGS) != null) {
                request.setAttribute(Constants.FORM_FIELD_FWARNINGS, request.getAttribute(Constants.FORM_FIELD_FWARNINGS));
            }

            try {
                request.getSession().setAttribute(Constants.REPORTS_KEY, reportMgr.getReports());
            } catch (Exception e) {
            }

            //Removing temp folder
            this.removeTempFiles(request, false);

            log.info("### DATA PROCEDURE COMPLETED ###");
            log.info("###");

        } catch (Exception e) {
            //If the report manager is empty, fill with current error
            if (reportMgr.size() <= 0) {
                reportMgr.addReport(Constants.REPORT_CONTEXT_DATAPROCEDUTE, Constants.REPORT_ACTION_DATAPROCEDUTE, "An error occurs while executing the operations. Error: " + e.getMessage(), Constants.REPORT_TYPE_ERROR, -1);
                log.error("@@ Data procedure, an error occurs while executing the operations: Error: " + e.getMessage());
            }

            //Set the error and warning list request and session variable.   
            if (request.getAttribute(Constants.ERROR_TYPE) == null) {
                request.setAttribute(Constants.ERROR_TYPE, Constants.ERROR_KEY_GENERIC);
            }
            request.setAttribute(Constants.REPORTS_KEY, reportMgr.getReports());

            try {
                request.getSession().setAttribute(Constants.REPORTS_KEY, reportMgr.getReports());
            } catch (Exception ex) {
            }

            //Removing temp folder and zip data file
            this.removeTempFiles(request, true);

            log.info("### DATA PROCEDURE NOT COMPLETED DUE TO ERRORS ###");
            log.info("###");
        }

        request.getRequestDispatcher("?m=Re3gistryData").forward(request, response);
    }

    /**
     * Handles the HTTP <code>GET</code> method.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        startProcedure(request, response);
    }

    /**
     * Handles the HTTP <code>POST</code> method.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        startProcedure(request, response);
    }

    /**
     * Returns a short description of the servlet.
     *
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }

    private void removeTempFiles(HttpServletRequest request, boolean removezip) {
        String tempFolderName = (String) request.getSession().getAttribute(Constants.TEMPDATAFILE_KEY);
        String tempZipFileName = tempFolderName + Constants.ZIP_FILE_EXTENSION;

        if (tempFolderName!=null && tempZipFileName!=null) {
            File tmpFolder = new File(tempFolderName);
            File tmpZipFile = new File(tempZipFileName);

            if (tmpFolder.exists()) {
                try {
                    FileUtils.deleteDirectory(tmpFolder);
                } catch (IOException ex) {
                }
            }
            if (tmpZipFile.exists() && removezip) {
                tmpZipFile.delete();
            }
        }
    }
}
