/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard;

import eu.europa.ec.re3gistrycommon.model.Languagecode;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.ApplicationSchemaAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.CustomattributeLabelList;

import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.ItemClassLabel;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.ParentItemLabel;

import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.StatusLabel;

import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.CodelistAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DefinitionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DescriptionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.PreviousVersions;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.LabelAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.LatestVersion;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.RegisterAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.ThemeAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.ThisVersion;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.CollectionItemLabel;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.ItemChildrenLabelList;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.PredecessorItemLabelList;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.SuccessorItemLabelList;
import java.util.Date;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name = "item")
@XmlAccessorType(XmlAccessType.FIELD)
public class ItemStandard {

    /**
     * unique elements
     */
    @XmlElement(name = "uuid")
    private String uuid;
    
    @XmlElement(name = "baseuri")
    private String baseuri;
    @XmlElement(name = "uriname")
    private String uriname;
    @XmlElement(name = "uri")
    private String uri;
    @XmlElement(name = "uristandard")
    private String uristandard;
   
    @XmlElement(name = "language")
    private Languagecode language;
    @XmlElement(name = "versionnumber")
    private int versionnumber;
    @XmlElement(name = "thisversion")
    private ThisVersion thisversion;
    @XmlElement(name = "latestversion")
    private LatestVersion lastestversion;
    @XmlElement(name = "previousversions")
    private PreviousVersions previousversion;
    /**
     * elements from localization
     */
    @XmlElement(name = "label")
    private LabelAttribute label;
    @XmlElement(name = "definition")
    private DefinitionAttribute definition;
    @XmlElement(name = "description")
    private DescriptionAttribute description;
    /**
     * standard elements
     */
    @XmlElement(name = "status")
    private StatusLabel status;
    @XmlElement(name = "itemclass")
    private ItemClassLabel itemclass;
    @XmlElement(name = "parent")
    private ParentItemLabel parentItemLabel;
    @XmlElement(name = "predecessors")
    private PredecessorItemLabelList predecessorItemLabelList;
    @XmlElement(name = "successors")
    private SuccessorItemLabelList successorItemLabelList;
    @XmlElement(name = "register")
    private RegisterAttribute register;
    @XmlElement(name = "theme")
    private ThemeAttribute theme;
    @XmlElement(name = "applicationschema")
    private ApplicationSchemaAttribute applicationschema;
    @XmlElement(name = "codelist")
    private CodelistAttribute codelist;
    @XmlElement(name = "customattributes")
    private CustomattributeLabelList CustomattributeLabelList;
    @XmlElement(name = "collection")
    private CollectionItemLabel collectionlabelList;
    @XmlElement(name = "children")
    private ItemChildrenLabelList children;
    /**
     * date elements
     */
    @XmlElement(name = "datecreation")
    private Date datecreation;
    @XmlElement(name = "datelastupdate")
    private Date datelastupdate;
    @XmlElement(name = "datetimeaddition")
    private Date datetimeaddition;
    @XmlElement(name = "datetimesupersession")
    private Date datetimesupersession;
    @XmlElement(name = "datetimeretirment")
    private Date datetimeretirment;
    @XmlElement(name = "datetimeinvalidation")
    private Date datetimeinvalidation;

    public ItemStandard() {
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getUri() {
        return uri;
    }

    public void setUri(String uri) {
        this.uri = uri;
    }

    public String getBaseuri() {
        return baseuri;
    }

    public void setBaseuri(String baseuri) {
        this.baseuri = baseuri;
    }

    public String getUriname() {
        return uriname;
    }

    public void setUriname(String uriname) {
        this.uriname = uriname;
    }

    public int getVersionnumber() {
        return versionnumber;
    }

    public void setVersionnumber(int versionnumber) {
        this.versionnumber = versionnumber;
    }

    public LabelAttribute getLabel() {
        return label;
    }

    public void setLabel(LabelAttribute label) {
        this.label = label;
    }

    public DefinitionAttribute getDefinition() {
        return definition;
    }

    public void setDefinition(DefinitionAttribute definition) {
        this.definition = definition;
    }

    public DescriptionAttribute getDescription() {
        return description;
    }

    public void setDescription(DescriptionAttribute description) {
        this.description = description;
    }

    public StatusLabel getStatus() {
        return status;
    }

    public void setStatus(StatusLabel status) {
        this.status = status;
    }

    public ItemClassLabel getItemclass() {
        return itemclass;
    }

    public void setItemclass(ItemClassLabel itemclass) {
        this.itemclass = itemclass;
    }

    public ParentItemLabel getParentItemLabel() {
        return parentItemLabel;
    }

    public void setParentItemLabel(ParentItemLabel parentItemLabel) {
        this.parentItemLabel = parentItemLabel;
    }

    public PredecessorItemLabelList getPredecessorItemLabelList() {
        return predecessorItemLabelList;
    }

    public void setPredecessorItemLabelList(PredecessorItemLabelList predecessorItemLabelList) {
        this.predecessorItemLabelList = predecessorItemLabelList;
    }

    public SuccessorItemLabelList getSuccessorItemLabelList() {
        return successorItemLabelList;
    }

    public void setSuccessorItemLabelList(SuccessorItemLabelList successorItemLabelList) {
        this.successorItemLabelList = successorItemLabelList;
    }

    public RegisterAttribute getRegister() {
        return register;
    }

    public void setRegister(RegisterAttribute register) {
        this.register = register;
    }

    public ThemeAttribute getTheme() {
        return theme;
    }

    public void setTheme(ThemeAttribute theme) {
        this.theme = theme;
    }

    public ApplicationSchemaAttribute getApplicationschema() {
        return applicationschema;
    }

    public void setApplicationschema(ApplicationSchemaAttribute applicationschema) {
        this.applicationschema = applicationschema;
    }

    public CodelistAttribute getCodelist() {
        return codelist;
    }

    public void setCodelist(CodelistAttribute codelist) {
        this.codelist = codelist;
    }

    public CustomattributeLabelList getCustomattributeLabelList() {
        return CustomattributeLabelList;
    }

    public void setCustomattributeLabelList(CustomattributeLabelList CustomattributeLabelList) {
        this.CustomattributeLabelList = CustomattributeLabelList;
    }

    public CollectionItemLabel getCollectionlabelList() {
        return collectionlabelList;
    }

    public void setCollectionlabelList(CollectionItemLabel collectionlabelList) {
        this.collectionlabelList = collectionlabelList;
    }

    public ItemChildrenLabelList getChildren() {
        return children;
    }

    public void setChildren(ItemChildrenLabelList children) {
        this.children = children;
    }

    public Date getDatecreation() {
        return datecreation;
    }

    public void setDatecreation(Date datecreation) {
        this.datecreation = datecreation;
    }

    public Date getDatelastupdate() {
        return datelastupdate;
    }

    public void setDatelastupdate(Date datelastupdate) {
        this.datelastupdate = datelastupdate;
    }

    public Date getDatetimeaddition() {
        return datetimeaddition;
    }

    public void setDatetimeaddition(Date datetimeaddition) {
        this.datetimeaddition = datetimeaddition;
    }

    public Date getDatetimesupersession() {
        return datetimesupersession;
    }

    public void setDatetimesupersession(Date datetimesupersession) {
        this.datetimesupersession = datetimesupersession;
    }

    public Date getDatetimeretirment() {
        return datetimeretirment;
    }

    public void setDatetimeretirment(Date datetimeretirment) {
        this.datetimeretirment = datetimeretirment;
    }

    public Date getDatetimeinvalidation() {
        return datetimeinvalidation;
    }

    public void setDatetimeinvalidation(Date datetimeinvalidation) {
        this.datetimeinvalidation = datetimeinvalidation;
    }

    public String getUristandard() {
        return uristandard;
    }

    public void setUristandard(String uristandard) {
        this.uristandard = uristandard;
    }

    public PreviousVersions getPreviousversion() {
        return previousversion;
    }

    public void setPreviousversion(PreviousVersions previousversion) {
        this.previousversion = previousversion;
    }

    public ThisVersion getThisversion() {
        return thisversion;
    }

    public void setThisversion(ThisVersion thisversion) {
        this.thisversion = thisversion;
    }

    public LatestVersion getLastestversion() {
        return lastestversion;
    }

    public void setLastestversion(LatestVersion lastestversion) {
        this.lastestversion = lastestversion;
    }

    public Languagecode getLanguage() {
        return language;
    }

    public void setLanguage(Languagecode language) {
        this.language = language;
    }

}
