/*
 * Copyright 2010,2013 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 14/06/2013
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 * (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
 */
package eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard;

import eu.europa.ec.re3gistrycommon.model.Languagecode;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DefinitionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DescriptionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.LabelAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.RegisterStandardList;
import java.io.Serializable;
import java.util.Date;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name = "registry")
@XmlAccessorType(XmlAccessType.FIELD)
public class RegistryStandard implements Serializable {

    @XmlElement(name = "uuid")
    private String uuid;

    @XmlElement(name = "baseuri")
    private String baseuri;
    @XmlElement(name = "uriname")
    private String uriname;
    @XmlElement(name = "uri")
    private String uri;
    @XmlElement(name = "uristandard")
    private String uristandard;

    @XmlElement(name = "language")
    private Languagecode language;

    @XmlElement(name = "label")
    private LabelAttribute label;
    @XmlElement(name = "definition")
    private DefinitionAttribute definition;
    @XmlElement(name = "description")
    private DescriptionAttribute description;

    @XmlElement(name = "registrymanager")
    private String registrymanager;

    @XmlElement(name = "datecreation")
    private Date datecreation;
    @XmlElement(name = "datelastupdate")
    private Date datelastupdate;

    @XmlElement(name = "registers")
    private RegisterStandardList registerStandardList;

    public RegistryStandard() {
    }

    public RegistryStandard(String uuid) {
        this.uuid = uuid;
    }

    public String getUuid() {
        return uuid;
    }

    public void setUuid(String uuid) {
        this.uuid = uuid;
    }

    public String getUriname() {
        return uriname;
    }

    public void setUriname(String uriname) {
        this.uriname = uriname;
    }

    public String getBaseuri() {
        return baseuri;
    }

    public void setBaseuri(String baseuri) {
        this.baseuri = baseuri;
    }

    public String getUri() {
        return uri;
    }

    public void setUri(String uri) {
        this.uri = uri;
    }

    public String getUristandard() {
        return uristandard;
    }

    public void setUristandard(String uristandard) {
        this.uristandard = uristandard;
    }

    public LabelAttribute getLabel() {
        return label;
    }

    public void setLabel(LabelAttribute label) {
        this.label = label;
    }

    public DefinitionAttribute getDefinition() {
        return definition;
    }

    public void setDefinition(DefinitionAttribute definition) {
        this.definition = definition;
    }

    public DescriptionAttribute getDescription() {
        return description;
    }

    public void setDescription(DescriptionAttribute description) {
        this.description = description;
    }

    public String getRegistrymanager() {
        return registrymanager;
    }

    public void setRegistrymanager(String registrymanager) {
        this.registrymanager = registrymanager;
    }

    public Date getDatecreation() {
        return datecreation;
    }

    public void setDatecreation(Date datecreation) {
        this.datecreation = datecreation;
    }

    public Date getDatelastupdate() {
        return datelastupdate;
    }

    public void setDatelastupdate(Date datelastupdate) {
        this.datelastupdate = datelastupdate;
    }

    public RegisterStandardList getRegisterStandardList() {
        return registerStandardList;
    }

    public void setRegisterStandardList(RegisterStandardList registerStandardList) {
        this.registerStandardList = registerStandardList;
    }

    public Languagecode getLanguage() {
        return language;
    }

    public void setLanguage(Languagecode language) {
        this.language = language;
    }

}
