/*
* Copyright 2010,2013 EUROPEAN UNION
* Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
* the European Commission - subsequent versions of the EUPL (the "Licence");
* You may not use this work except in compliance with the Licence.
* You may obtain a copy of the Licence at:
*
* http://ec.europa.eu/idabc/eupl
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the Licence is distributed on an "AS IS" basis,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the Licence for the specific language governing permissions and
* limitations under the Licence.
*
* Date: 14/06/2013
* Authors: European Commission, Joint Research Centre
* Daniele Francioli, Emanuela Epure
* inspire-registry-info@jrc.ec.europa.eu
*
* This work was supported by the EU  Interoperability Solutions for
* European Public Administrations Programme (http://ec.europa.eu/isa)
* through Action 1.17: Re-usable INSPIRE Reference Platform 
* (http://ec.europa.eu/isa/actions/01-trusted-information-exchange/1-17action_en.htm).
*/

package eu.europa.ec.re3gistrystaticizer.manager;


import eu.europa.ec.re3gistrycommon.utils.log.LogClass;
import eu.europa.ec.re3gistrycommon.utils.log.LogManager;
import java.io.*;
import java.util.Enumeration;
import java.util.Properties;

public class Configuration {

    private static Configuration instance;
    private Properties props;
    private boolean fileReady;

    public static Configuration getInstance() {
        if (instance == null) {
            instance = new Configuration();
        }
        return instance;
    }

    private Configuration() {
        fileReady = true;
        try {
            props = new Properties(System.getProperties());
            String filePropertiesPath = System.getProperty("conf");
            File propertiesFile = new File(filePropertiesPath + File.separator + "webapp.properties");
            if (!propertiesFile.exists()) {
                fileReady = false;
                throw new FileNotFoundException("Properties file not found: " + propertiesFile.getAbsolutePath());
            }
            InputStream inStream = new FileInputStream(propertiesFile);
            props.load(inStream);
            inStream.close();
        } catch (Exception e) {
            System.err.println("ERROR READING CONFIGURATION: " + e.getMessage());
            e.printStackTrace();
        }
        initLogging();
    }

    public boolean isFileReady() {
        return fileReady;
    }

    public String getProperty(String key) {
        return props.getProperty(key);
    }

    public String getProperty(String key, String defaultValue) {
        return props.getProperty(key, defaultValue);
    }

    public int getProperty(String key, int defaultValue) {
        String value = props.getProperty(key);
        if (value == null || value.length() == 0) {
            return defaultValue;
        } else {
            return Integer.parseInt(value);
        }
    }

    public long getProperty(String key, long defaultValue) {
        String value = props.getProperty(key);
        if (value == null || value.length() == 0) {
            return defaultValue;
        } else {
            return Long.parseLong(value);
        }
    }

    public boolean getProperty(String key, boolean defaultValue) {
        String value = props.getProperty(key);
        if (value == null || value.length() == 0) {
            return defaultValue;
        } else {
            return Boolean.valueOf(value).booleanValue();
        }
    }

    public int getServerId() {
        return getProperty("server", 0);
    }

    public Properties getProperties() {
        return props;
    }

    public Properties getProperties(String prefix) {
        Properties subProps = new Properties();
        Enumeration<Object> enumeration = props.keys();
        do {
            if (!enumeration.hasMoreElements()) {
                break;
            }
            String key = (String) enumeration.nextElement();
            if (key.startsWith(prefix)) {
                subProps.setProperty(key, props.getProperty(key));
            }
        } while (true);
        return subProps;
    }

    private void initLogging() {
        String filePropertiesPath = System.getProperty("conf");
        File logCfgFile = new File(filePropertiesPath + File.separator + "logcfg.xml");
        if (logCfgFile.exists() && logCfgFile.isFile()) {
            LogManager.config(logCfgFile.getAbsolutePath());
        } else {
            System.err.println("Logger - file logcfg not found: " + logCfgFile.getAbsolutePath());
        }
    }

    public LogClass getLogClass(String className) {
        return LogManager.getLogClass(className);
    }
}
