/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrystaticizer.marshaller;

import eu.europa.ec.re3gistrycommon.managers.LanguagecodeMgr;
import eu.europa.ec.re3gistrycommon.managers.LocalizationMgr;
import eu.europa.ec.re3gistrycommon.managers.RegisterMgr;
import eu.europa.ec.re3gistrycommon.managers.RegistryMgr;
import eu.europa.ec.re3gistrycommon.model.Languagecode;
import eu.europa.ec.re3gistrycommon.model.Localization;
import eu.europa.ec.re3gistrycommon.model.Register;
import eu.europa.ec.re3gistrycommon.model.Registry;
import eu.europa.ec.re3gistrycommon.utils.StringUtils;
import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.RegisterStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.RegistryStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DefinitionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DescriptionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.LabelAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.RegistryAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.RegisterStandardList;
import eu.europa.ec.re3gistrystaticizer.servlet.StartStaticizer;
import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.persistence.EntityManager;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.transform.Transformer;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import net.sf.saxon.TransformerFactoryImpl;

public class RegistryStaticizer {

    private final String folderSeparator;
    private final String folderStandardStaticizer;
    private final EntityManager em;
    private static org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);
    private final String folderCustomStaticizer;
    private final StartStaticizer startStaticizer;
    private final List<Languagecode> allLanguagecode;
    private final Languagecode masterLanguage;

    /**
     *
     * @param startStaticizer
     * @param em
     */
    public RegistryStaticizer(StartStaticizer startStaticizer, EntityManager em) throws Exception {
        this.startStaticizer = startStaticizer;
        this.folderSeparator = startStaticizer.getFolderSeparator();
        this.folderStandardStaticizer = startStaticizer.getFolderStandardStaticizer();
        this.folderCustomStaticizer = startStaticizer.getFolderCustomStaticizer();

        this.em = em;

        LanguagecodeMgr languagecodeMgr = new LanguagecodeMgr(em);
        allLanguagecode = languagecodeMgr.findAll();

        masterLanguage = languagecodeMgr.getMasterLanguagecode();
    }

    public List<File> addRegistryFiles() {
        List<File> list = new ArrayList<File>();
        try {
            RegistryMgr registryMgr = new RegistryMgr(em);
            List<Registry> registryList = registryMgr.findAll();

            for (Iterator<Registry> it = registryList.iterator(); it.hasNext();) {
                Registry registry = it.next();

                LocalizationMgr localizationMgr = new LocalizationMgr(em);
                for (Languagecode languagecode : allLanguagecode) {
                    Localization registryLocalization = localizationMgr.findByRegistryAndLanguagecode(registry, languagecode);
                    String isocode = languagecode.getIsocode();
                    if (registryLocalization == null) {
                        registryLocalization = localizationMgr.findByRegistryAndLanguagecode(registry, masterLanguage);
                        isocode = masterLanguage.getIsocode();
                    }
                    RegistryStandard registryStandard = createRegistry(registry, registryLocalization);
                    list.add(createXMLRegistryFile(registryStandard, isocode));
                }
            }
        } catch (Exception ex) {
            log.error(ex.getMessage());
        }
        return list;
    }

    public RegistryStandard createRegistry(Registry registry, Localization registryLocalization) {
        RegistryStandard registryStandard = new RegistryStandard();
        registryStandard.setUuid(registry.getUuid());
        registryStandard.setBaseuri(registry.getBaseuri());
        registryStandard.setUriname(registry.getUriname());
        registryStandard.setUri(registry.getBaseuri() + "/" + registry.getUriname());
        registryStandard.setUristandard(registry.getBaseuri() + "/" + registry.getUriname());

        String language = registryLocalization.getLanguage().getIsocode();

        registryStandard.setLanguage(registryLocalization.getLanguage());

        LabelAttribute registryLabelAttribute = new LabelAttribute();
        registryLabelAttribute.setLanguage(language);
        registryLabelAttribute.setValue(registryLocalization.getLabel());
        registryStandard.setLabel(registryLabelAttribute);

        StringUtils stringUtils = new StringUtils();

        DefinitionAttribute registryDefinitionAttribute = new DefinitionAttribute();
        registryDefinitionAttribute.setLanguage(language);

        String definition = stringUtils.replaceSpecialCharacters(registryLocalization.getDefinition());
        registryDefinitionAttribute.setValue(definition);
        registryStandard.setDefinition(registryDefinitionAttribute);

        DescriptionAttribute registryDescriptionAttribute = new DescriptionAttribute();
        registryDescriptionAttribute.setLanguage(language);

        String description = stringUtils.replaceSpecialCharacters(registryLocalization.getDescription());
        registryDescriptionAttribute.setValue(description);
        registryStandard.setDescription(registryDescriptionAttribute);

        registryStandard.setRegistrymanager(registry.getRegistrymanager());

        registryStandard.setDatecreation(registry.getDatecreation());
        registryStandard.setDatelastupdate(registry.getDatelastupdate());

        RegisterStandardList registerStandardList = new RegisterStandardList();
        ArrayList<RegisterStandard> registerStandardArrayList = new ArrayList<RegisterStandard>();
        RegisterMgr registerMgr = new RegisterMgr(em);
        try {
            List<Register> registerList = registerMgr.findAll();

            for (Iterator<Register> it = registerList.iterator(); it.hasNext();) {
                Register register = it.next();

                LocalizationMgr localizationMgr = new LocalizationMgr(em);
                Localization registerLocalization = localizationMgr.findByRegisterAndLanguagecode(register, registryLocalization.getLanguage());
                if (registerLocalization == null) {
                    registerLocalization = localizationMgr.findByRegisterAndLanguagecode(register, masterLanguage);
                }

                RegisterStandard registerStandard = addRegisterStandard(register, language, registerLocalization, registryLabelAttribute, registry);
                registerStandardArrayList.add(registerStandard);
            }
        } catch (Exception ex) {
            Logger.getLogger(RegistryStaticizer.class.getName()).log(Level.SEVERE, null, ex);
        }
        registerStandardList.setRegisterStandard(registerStandardArrayList);
        registryStandard.setRegisterStandardList(registerStandardList);

        return registryStandard;
    }

    private RegisterStandard addRegisterStandard(Register register, String language, Localization registerLocalization, LabelAttribute registryLabelAttribute, Registry registry) {
        RegisterStandard registerStandard = new RegisterStandard();
        registerStandard.setUuid(register.getUuid());
        registerStandard.setBaseuri(register.getBaseuri());
        registerStandard.setUriname(register.getUriname());
        registerStandard.setUri(register.getBaseuri() + "/" + register.getUriname());
        registerStandard.setUristandard(register.getBaseuri() + "/" + register.getUriname());

        registerStandard.setDatecreation(register.getDatecreation());
        registerStandard.setDatelastupdate(register.getDatelastupdate());

        registerStandard.setLanguage(registerLocalization.getLanguage());

        LabelAttribute registerLabelAttribute = new LabelAttribute();
        registerLabelAttribute.setLanguage(language);
        registerLabelAttribute.setValue(registerLocalization.getLabel());
        registerStandard.setLabel(registerLabelAttribute);

        StringUtils stringUtils = new StringUtils();

        DefinitionAttribute registerDefinitionAttribute = new DefinitionAttribute();
        registerDefinitionAttribute.setLanguage(language);

        String definition = stringUtils.replaceSpecialCharacters(registerLocalization.getDefinition());
        registerDefinitionAttribute.setValue(definition);
        registerStandard.setDefinition(registerDefinitionAttribute);

        DescriptionAttribute registerDescriptionAttribute = new DescriptionAttribute();
        registerDescriptionAttribute.setLanguage(language);

        String description = stringUtils.replaceSpecialCharacters(registerLocalization.getDescription());
        registerDescriptionAttribute.setValue(description);
        registerStandard.setDescription(registerDescriptionAttribute);

        registerStandard.setOwner(register.getRegisterowner());
        registerStandard.setManager(register.getRegistermanager());
        registerStandard.setControlbody(register.getRegistercontrolbody());

        RegistryAttribute registryAttribute = new RegistryAttribute();
        registryAttribute.setLabel(registryLabelAttribute);
        registryAttribute.setUri(registry.getBaseuri() + "/" + registry.getUriname());
        registerStandard.setRegistry(registryAttribute);
        return registerStandard;
    }

    private File createXMLRegistryFile(RegistryStandard registryStandard, String isocode) {
        String registryStandardFolderPath = folderStandardStaticizer;
        String registryCustomFolderPath = folderCustomStaticizer;
        File registryStandardFolder = new File(registryStandardFolderPath);
        File registryCustomFolder = new File(registryCustomFolderPath);

        if (!registryStandardFolder.exists()) {
            registryStandardFolder.mkdirs();
        }
        if (!registryCustomFolder.exists()) {
            registryCustomFolder.mkdirs();
        }

        String registry = registryStandard.getUriname();
        String registryFilePath = registryStandardFolder.getAbsolutePath() + folderSeparator + registry + "." + isocode + ".xml";
        File registryFile = new File(registryFilePath);

        try {
            /**
             * STANDARD XML
             */
            JAXBContext jaxbContextLang = JAXBContext.newInstance(RegistryStandard.class);
            Marshaller marshallerclassLanguage = jaxbContextLang.createMarshaller();
            marshallerclassLanguage.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
            marshallerclassLanguage.marshal(registryStandard, registryFile);
            log.info("Create with success: " + registryFile);

            /**
             * CUSTOM XML, JSON, HTML, ATOM
             */
            for (String ext : startStaticizer.getEXTENSIONS()) {
                try {
                    String registryXSL = startStaticizer.getStaticizerXSLFolder() + "/" + ext + "/" + registry + "." + ext + ".xsl";
                    String finalOutputPath = registryFile.getAbsolutePath().replace("standard", "custom").replace("xml", ext);

                    File finalOutFile = new File(finalOutputPath);
                    finalOutFile.createNewFile();
                    File transformerFile = new File(registryXSL);

                    TransformerFactoryImpl factory = new net.sf.saxon.TransformerFactoryImpl();
                    Transformer transformer = factory.newTransformer(new StreamSource(transformerFile));
                    transformer.transform(new StreamSource(registryFile), new StreamResult(finalOutFile));

                    log.info("Create with success: " + finalOutFile);
                } catch (Exception ex) {
                    log.error("Error in creation the transformation file: " + ex.getMessage());
                }
            }

        } catch (JAXBException ex) {
            log.error("Error in creation file: " + registryFile + " -JAXBException- " + ex.getMessage());
        }

        return registryCustomFolder;
    }
}
