/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrystaticizer.marshaller;

import eu.europa.ec.re3gistrycommon.model.Register;
import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.collection.ContainerCollectionRegisterStandard;
import eu.europa.ec.re3gistrystaticizer.servlet.StartStaticizer;
import java.io.File;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.transform.Transformer;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import net.sf.saxon.TransformerFactoryImpl;

public class SolrRegisterStaticizer {

    private final String folderSeparator;
    private final String folderSolrStaticizer;
    private final String folderSolrcustomStaticizer;
    private static org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);
    private final StartStaticizer startStaticizer;

    public SolrRegisterStaticizer(StartStaticizer startStaticizer) {
        this.startStaticizer = startStaticizer;
        this.folderSeparator = startStaticizer.getFolderSeparator();
        this.folderSolrStaticizer = startStaticizer.getFolderSolrStaticizer();
        this.folderSolrcustomStaticizer = startStaticizer.getFolderSolrCustomStaticizer();
    }

    public File createSOLRRegisterFile(ContainerCollectionRegisterStandard containerCollectionRegisterStandard, Register register) {
        String registerFolderSolrPath = folderSolrStaticizer + folderSeparator + register.getUriname();
        String registerFolderSolrcustomPath = folderSolrcustomStaticizer + folderSeparator + register.getUriname();
        File registerSolrFolder = new File(registerFolderSolrPath);
        File registerSolrcustomFolder = new File(registerFolderSolrcustomPath);

        if (!registerSolrFolder.exists()) {
            registerSolrFolder.mkdirs();
        }
        if (!registerSolrcustomFolder.exists()) {
            registerSolrcustomFolder.mkdirs();
        }

        String registerUriname = register.getUriname();
        String registerSolrFilePath = registerSolrFolder + folderSeparator + registerUriname + ".xml";
        File registerSolrFile = new File(registerSolrFilePath);

        try {
            /**
             * STANDARD XML
             */
            JAXBContext jaxbContextLang = JAXBContext.newInstance(ContainerCollectionRegisterStandard.class);
            Marshaller marshallerclassLanguage = jaxbContextLang.createMarshaller();
            marshallerclassLanguage.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
            marshallerclassLanguage.marshal(containerCollectionRegisterStandard, registerSolrFile);
            log.info("Create with success: " + registerSolrFile);

            /**
             * CUSTOM SOLR
             */
            for (String ext : startStaticizer.getEXTENSIONSSOLR()) {
                try {
                    String registerXSL = startStaticizer.getStaticizerXSLFolder() + "/" + ext + "/" + registerUriname + "_register." + ext + ".xsl";
                    String registerCustomFilePath = registerSolrcustomFolder + folderSeparator + registerUriname + ".xml";

                    File finalOutFile = new File(registerCustomFilePath);
                    finalOutFile.createNewFile();
                    File transformerFile = new File(registerXSL);

                    TransformerFactoryImpl factory = new net.sf.saxon.TransformerFactoryImpl();
                    Transformer transformer = factory.newTransformer(new StreamSource(transformerFile));
                    transformer.transform(new StreamSource(registerSolrFile), new StreamResult(finalOutFile));

                    log.info("Create with success: " + finalOutFile);
                } catch (Exception ex) {
                    log.error("Error in creation the transformation file: " + ex.getMessage());
                }
            }

        } catch (JAXBException ex) {
            log.error("Error in creation file: " + registerSolrFile + " -JAXBException- " + ex.getMessage());
        }

        return registerSolrcustomFolder;
    }
}
