/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrystaticizer.marshaller;

import eu.europa.ec.re3gistrycommon.managers.CustomattributevalueMgr;
import eu.europa.ec.re3gistrycommon.managers.ItemMgr;
import eu.europa.ec.re3gistrycommon.managers.ItemclassMgr;
import eu.europa.ec.re3gistrycommon.managers.ItemclasscustomattributeMgr;
import eu.europa.ec.re3gistrycommon.managers.ItemcollectionMgr;
import eu.europa.ec.re3gistrycommon.managers.ItemparentMgr;
import eu.europa.ec.re3gistrycommon.managers.ItemsuccessorMgr;
import eu.europa.ec.re3gistrycommon.managers.LanguagecodeMgr;
import eu.europa.ec.re3gistrycommon.managers.LocalizationMgr;
import eu.europa.ec.re3gistrycommon.model.Customattribute;
import eu.europa.ec.re3gistrycommon.model.Customattributevalue;
import eu.europa.ec.re3gistrycommon.model.Item;
import eu.europa.ec.re3gistrycommon.model.Itemclass;
import eu.europa.ec.re3gistrycommon.model.Itemclasscustomattribute;
import eu.europa.ec.re3gistrycommon.model.Itemcollection;
import eu.europa.ec.re3gistrycommon.model.Itemparent;
import eu.europa.ec.re3gistrycommon.model.Itemsuccessor;
import eu.europa.ec.re3gistrycommon.model.Languagecode;
import eu.europa.ec.re3gistrycommon.model.Localization;
import eu.europa.ec.re3gistrycommon.model.Register;
import eu.europa.ec.re3gistrycommon.model.Registry;
import eu.europa.ec.re3gistrycommon.utils.StringUtils;
import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.ItemStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.CodelistAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DefinitionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.DescriptionAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.PreviousVersions;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.LabelAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.LatestVersion;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.RegisterAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.RegistryAttribute;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.ThisVersion;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.attribute.Version;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.CollectionItemLabel;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.CustomattributeLabel;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.ItemClassLabel;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.ParentItemLabel;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.PredecessorItemLabel;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.StatusLabel;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.label.SuccessorItemLabel;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.CustomattributeLabelList;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.ItemChildrenLabelList;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.PredecessorItemLabelList;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.list.SuccessorItemLabelList;
import eu.europa.ec.re3gistrystaticizer.servlet.StartStaticizer;
import java.io.File;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import javax.persistence.EntityManager;
import javax.xml.bind.JAXBContext;
import javax.xml.bind.JAXBException;
import javax.xml.bind.Marshaller;
import javax.xml.transform.Transformer;
import javax.xml.transform.stream.StreamResult;
import javax.xml.transform.stream.StreamSource;
import net.sf.saxon.TransformerFactoryImpl;
import org.apache.log4j.Logger;

public class StaticizeLastImportedItems {

    private final EntityManager em;
    private static Logger log = Logger.getLogger(Constants.MODULE_NAME);
    private final String folderSeparator;
    private final String folderStandardStaticizer;
    private final String folderCustomStaticiser;
    private final Languagecode masterLanguage;
    private final StartStaticizer startStaticizer;

    public StaticizeLastImportedItems(StartStaticizer startStaticizer, EntityManager em) throws Exception {
        this.startStaticizer = startStaticizer;
        this.folderSeparator = startStaticizer.getFolderSeparator();

        this.folderStandardStaticizer = startStaticizer.getFolderStandardStaticizer();
        this.folderCustomStaticiser = startStaticizer.getFolderCustomStaticizer();

        this.em = em;

        LanguagecodeMgr languagecodeMgr = new LanguagecodeMgr(em);
        masterLanguage = languagecodeMgr.getMasterLanguagecode();
    }

    public ArrayList<File> createItemFiles(Item item, Localization localization, Languagecode languagecodeMissing) {
        /**
         * create itemStandard
         */
        try {
            ItemStandard itemStandard = createItemStandard(item, localization, languagecodeMissing);
            return createItemStandardFile(item, languagecodeMissing.getIsocode(), itemStandard);
        } catch (Exception ex) {
            log.error("createItemWhenMissingLocalization " + ex.getMessage());
            return null;
        }
    }

    public ItemStandard createItemStandard(Item item, Localization localization, Languagecode languagecode) {
        try {
            /**
             * CREATE A NEW ITEM STANDARD
             */
//            Languagecode languagecode = localization.getLanguage();

            ItemStandard itemStandard = new ItemStandard();
            addItemStandardFields(itemStandard, item);
            addLanguage(itemStandard, languagecode);
            addStandardItemLabel(localization, item, itemStandard);
            addStandardItemDefinition(localization, item, itemStandard);
            addStandardItemDescription(localization, item, itemStandard);
            addStandardItemStatus(item, languagecode, itemStandard);
            addStandardItemItemClass(item, languagecode, itemStandard);
            addStandardItemParent(item, languagecode, itemStandard);
            addStandardItemPredecessor(item, languagecode, itemStandard);
            addStandardItemSuccessor(item, languagecode, itemStandard);
            addStandardItemRegister(item, languagecode, itemStandard);
            addStandardItemCustomattribut(languagecode, item, itemStandard);
            addItemStandardCodelist(languagecode, item, itemStandard);
            addItemStandardCollectionItems(item, languagecode, itemStandard);
            addItemStandardChildren(item, languagecode, itemStandard);
            addItemStandardDates(itemStandard, item);

            return itemStandard;
        } catch (Exception ex) {
            log.error("createItemStandard " + ex.getMessage());
        }
        return null;
    }

    public ItemStandard createMiniItemStandard(Item item, Localization localization, Languagecode languagecode) {
        try {
            /**
             * LANGUAGE CODE
             */
//            Languagecode languagecode = localization.getLanguage();

            /**
             * CREATE A NEW ITEM STANDARD
             */
            ItemStandard itemStandard = new ItemStandard();
            addItemStandardFields(itemStandard, item);
            addLanguage(itemStandard, languagecode);
            addStandardItemLabel(localization, item, itemStandard);
            addStandardItemDefinition(localization, item, itemStandard);
            addStandardItemDescription(localization, item, itemStandard);
            addStandardItemStatus(item, languagecode, itemStandard);
            addStandardItemItemClass(item, languagecode, itemStandard);
            addStandardItemParent(item, languagecode, itemStandard);
            addStandardItemPredecessor(item, languagecode, itemStandard);
            addStandardItemSuccessor(item, languagecode, itemStandard);
            addStandardItemRegister(item, languagecode, itemStandard);
            addStandardItemCustomattribut(languagecode, item, itemStandard);
            addItemStandardCodelist(languagecode, item, itemStandard);
//            addItemStandardCollectionItems(item, languagecode, itemStandard);
            addMiniItemStandardChildren(item, languagecode, itemStandard);
            addItemStandardDates(itemStandard, item);

            return itemStandard;
        } catch (Exception ex) {
            log.error("createMiniItemStandard " + ex.getMessage());
        }
        return null;
    }

    private void addLanguage(ItemStandard itemStandard, Languagecode languagecode) {
        itemStandard.setLanguage(languagecode);
    }

    private ArrayList<File> createItemStandardFile(Item item, String isocode, ItemStandard itemStandard) throws Exception {
        ArrayList<File> files = new ArrayList<File>();
        Register register = item.getItemclass().getRegister();
        String registerUriname = register.getUriname();

        String registerStandardFolderPath = folderStandardStaticizer + folderSeparator + registerUriname;
        String registerCustomFolderPath = folderCustomStaticiser + folderSeparator + registerUriname;
        File registerStandardFolder = new File(registerStandardFolderPath);
        File registerCustomFolder = new File(registerCustomFolderPath);

        if (!registerStandardFolder.exists()) {
            registerStandardFolder.mkdirs();
        }
        if (!registerCustomFolder.exists()) {
            registerCustomFolder.mkdirs();
        }

        ItemcollectionMgr itemcollectionMgr = new ItemcollectionMgr(em);
        ItemMgr itemMgr = new ItemMgr(em);
        List<Item> previousVersions = itemMgr.getAllItemVersionOrderDescByVersionnumber(item);
        int lastestVersion = previousVersions.get(previousVersions.size() - 1).getVersionnumber() + 1;

        File fileStandard;
        File fileCustom = null;
        String itemVersionStandardFolderPath = null;
        String itemVersionCustomFolderPath = null;

        File latestFileStandard;
        File latestFileCustom = null;
        String latestItemVersionStandardFolderPath = null;
        String latestItemVersionCustomFolderPath = null;

        try {
            Itemcollection itemcollection = itemcollectionMgr.findByItem(item).get(0);

            if (itemcollection != null) {
                Item collection = itemcollection.getCollection();
                if (item.getVersionnumber() == 0) {
                    fileStandard = new File(registerStandardFolderPath + folderSeparator + collection.getUriname() + folderSeparator + item.getUriname());
                    fileCustom = new File(registerCustomFolderPath + folderSeparator + collection.getUriname() + folderSeparator + item.getUriname());
                    fileStandard.mkdirs();
                    fileCustom.mkdirs();
                    itemVersionStandardFolderPath = fileStandard.getAbsolutePath() + folderSeparator + item.getUriname() + "." + isocode + ".xml";
                    itemVersionCustomFolderPath = fileCustom.getAbsolutePath() + folderSeparator + item.getUriname() + "." + isocode + ".xml";

                    latestFileStandard = new File(registerStandardFolderPath + folderSeparator + collection.getUriname() + folderSeparator + item.getUriname() + folderSeparator + lastestVersion);
                    latestFileCustom = new File(registerCustomFolderPath + folderSeparator + collection.getUriname() + folderSeparator + item.getUriname() + folderSeparator + lastestVersion);
                    latestFileStandard.mkdirs();
                    latestFileCustom.mkdirs();
                    latestItemVersionStandardFolderPath = latestFileStandard.getAbsolutePath() + folderSeparator + item.getUriname() + "." + isocode + ".xml";
                    latestItemVersionCustomFolderPath = latestFileCustom.getAbsolutePath() + folderSeparator + item.getUriname() + "." + isocode + ".xml";
                } else {
                    fileStandard = new File(registerStandardFolderPath + folderSeparator + collection.getUriname() + folderSeparator + item.getUriname() + folderSeparator + item.getVersionnumber());
                    fileCustom = new File(registerCustomFolderPath + folderSeparator + collection.getUriname() + folderSeparator + item.getUriname() + folderSeparator + item.getVersionnumber());
                    fileStandard.mkdirs();
                    fileCustom.mkdirs();
                    itemVersionStandardFolderPath = fileStandard.getAbsolutePath() + folderSeparator + item.getUriname() + "." + isocode + ".xml";
                    itemVersionCustomFolderPath = fileCustom.getAbsolutePath() + folderSeparator + item.getUriname() + "." + isocode + ".xml";
                }
            }
        } catch (Exception ex) {
            if (item.getVersionnumber() == 0) {
                fileStandard = new File(registerStandardFolderPath + folderSeparator + item.getUriname());
                fileCustom = new File(registerCustomFolderPath + folderSeparator + item.getUriname());
                fileStandard.mkdirs();
                fileCustom.mkdirs();
                itemVersionStandardFolderPath = registerStandardFolderPath + folderSeparator + item.getUriname() + folderSeparator + item.getUriname() + "." + isocode + ".xml";
                itemVersionCustomFolderPath = registerCustomFolderPath + folderSeparator + item.getUriname() + folderSeparator + item.getUriname() + "." + isocode + ".xml";

                latestFileStandard = new File(registerStandardFolderPath + folderSeparator + item.getUriname() + folderSeparator + lastestVersion);
                latestFileCustom = new File(registerCustomFolderPath + folderSeparator + folderSeparator + item.getUriname() + folderSeparator + lastestVersion);
                latestFileStandard.mkdirs();
                latestFileCustom.mkdirs();
                latestItemVersionStandardFolderPath = latestFileStandard.getAbsolutePath() + folderSeparator + item.getUriname() + "." + isocode + ".xml";
                latestItemVersionCustomFolderPath = latestFileCustom.getAbsolutePath() + folderSeparator + item.getUriname() + "." + isocode + ".xml";
            } else {
                fileStandard = new File(registerStandardFolderPath + folderSeparator + item.getUriname() + folderSeparator + item.getVersionnumber());
                fileCustom = new File(registerCustomFolderPath + folderSeparator + item.getUriname() + folderSeparator + item.getVersionnumber());
                fileStandard.mkdirs();
                fileCustom.mkdirs();
                itemVersionStandardFolderPath = fileStandard.getAbsolutePath() + folderSeparator + item.getUriname() + "." + isocode + ".xml";
                itemVersionCustomFolderPath = fileCustom.getAbsolutePath() + folderSeparator + item.getUriname() + "." + isocode + ".xml";
            }
        }

        File itemVersionStandardFile = new File(itemVersionStandardFolderPath);
        File itemVersionCustomFile = new File(itemVersionCustomFolderPath);

        /**
         * create file in the version folder
         */
        createXMLFile(itemStandard, itemVersionStandardFile, itemVersionCustomFile);
        files.add(fileCustom);

        if (latestItemVersionStandardFolderPath != null) {
            File actualItemVersionStandardFile = new File(latestItemVersionStandardFolderPath);
            File actualItemVersionCustomFile = new File(latestItemVersionCustomFolderPath);

            createXMLFile(itemStandard, actualItemVersionStandardFile, actualItemVersionCustomFile);
            files.add(latestFileCustom);
        }

        return files;
    }

    private void createXMLFile(ItemStandard itemStandard, File itemStandardFile, File itemCustomFile) {

        try {
            String itemFileUriname = itemStandard.getItemclass().getUriname();
            /**
             * STANDARD XML
             */
            JAXBContext jaxbContextLang = JAXBContext.newInstance(ItemStandard.class);
            Marshaller marshallerclassLanguage = jaxbContextLang.createMarshaller();
            marshallerclassLanguage.setProperty(Marshaller.JAXB_FORMATTED_OUTPUT, Boolean.TRUE);
            marshallerclassLanguage.marshal(itemStandard, itemStandardFile);
            log.info("Create with success: " + itemStandardFile);

            /**
             * CUSTOM XML, JSON, HTML, ATOM
             */
            for (String ext : startStaticizer.getEXTENSIONS()) {
                try {
                    String itemFileXSL = startStaticizer.getStaticizerXSLFolder() + "/" + ext + "/" + itemFileUriname + "." + ext + ".xsl";
                    String finalOutputPath = itemCustomFile.getAbsolutePath().replace("xml", ext);

                    File finalOutFile = new File(finalOutputPath);
                    finalOutFile.createNewFile();
                    File transformerFile = new File(itemFileXSL);

                    TransformerFactoryImpl factory = new net.sf.saxon.TransformerFactoryImpl();
                    Transformer transformer = factory.newTransformer(new StreamSource(transformerFile));
                    transformer.transform(new StreamSource(itemStandardFile), new StreamResult(finalOutFile));

                    log.info("Create with success: " + finalOutFile);
                } catch (Exception ex) {
                    log.error("Error in creation the transformation file: " + itemStandardFile + " == " + ex.getMessage());
                }
            }
        } catch (JAXBException ex) {
            log.error("Error in creation file: " + itemStandardFile + " -JAXBException- " + ex.getMessage());
        }
    }

    private void addItemStandardFields(ItemStandard itemStandard, Item item) {
        try {
            Register register = item.getItemclass().getRegister();
            itemStandard.setUuid(item.getUuid());
            itemStandard.setBaseuri(register.getBaseuri());
            itemStandard.setUriname(item.getUriname());

            ItemcollectionMgr itemcollectionMgr = new ItemcollectionMgr(em);
            ItemMgr itemMgr = new ItemMgr(em);
            List<Item> previousVersions = itemMgr.getAllItemVersionOrderDescByVersionnumber(item);
            int lastestVersion = previousVersions.get(0).getVersionnumber() + 1;

            try {
                Itemcollection itemcollection = itemcollectionMgr.findByItem(item).get(0);
                Item collection = itemcollection.getCollection();

                String codelistName = collection.getUriname();
                itemStandard.setUri(register.getBaseuri() + "/" + item.getItemclass().getRegister().getUriname() + "/" + codelistName + "/" + item.getUriname());
            } catch (Exception ex) {
                itemStandard.setUri(register.getBaseuri() + "/" + item.getItemclass().getRegister().getUriname() + "/" + item.getUriname());

            }
            itemStandard.setVersionnumber(item.getVersionnumber());

            PreviousVersions historyVersion = new PreviousVersions();
            ArrayList<Version> versionarray = new ArrayList<Version>();
            for (Item versionItem : previousVersions) {
                Version versionForPrevious = new Version();
                int versionNumber = versionItem.getVersionnumber();

                if (versionNumber != item.getVersionnumber() && versionNumber != 0) {
                    if (versionNumber == 0) {
                        versionForPrevious.setUri(itemStandard.getUri());
                    } else {
                        versionForPrevious.setUri(itemStandard.getUri() + ":" + versionNumber);
                    }

                    if (itemStandard.getVersionnumber() != 0) {
                        if (itemStandard.getVersionnumber() > versionNumber) {
                            versionarray.add(versionForPrevious);
                        }
                    } else {
                        versionarray.add(versionForPrevious);
                    }
                }
            }
            if (versionarray.size() > 0) {
                historyVersion.setVersion(versionarray);
                itemStandard.setPreviousversion(historyVersion);
            }

            LatestVersion latestVersion = new LatestVersion();
            latestVersion.setUri(itemStandard.getUri());
            itemStandard.setLastestversion(latestVersion);

            ThisVersion thisVersion = new ThisVersion();
            if (item.getVersionnumber() == 0) {
                thisVersion.setUri(itemStandard.getUri() + ":" + lastestVersion);
            } else {
                thisVersion.setUri(itemStandard.getUri() + ":" + item.getVersionnumber());
            }
            itemStandard.setThisversion(thisVersion);

            if (item.getVersionnumber() != 0) {
                itemStandard.setUristandard(itemStandard.getUri() + "/" + item.getVersionnumber());
            } else {
                itemStandard.setUristandard(itemStandard.getUri());
            }
        } catch (Exception ex) {
//            log.error("addItemStandardFields " + ex.getMessage());
        }
    }

    private void addStandardItemLabel(Localization localization, Item item, ItemStandard itemStandard) {
        /**
         * LABEL
         */
        try {
            LabelAttribute labelAttribute = new LabelAttribute();

            if (localization != null && localization.getLabel() != null) {
                Languagecode languagecode = localization.getLanguage();
                labelAttribute.setLanguage(languagecode.getIsocode());
                labelAttribute.setValue(localization.getLabel());
                itemStandard.setLabel(labelAttribute);
            } else {
                LocalizationMgr localizationMgr = new LocalizationMgr(em);
                Localization masterLocalization;
                try {
                    masterLocalization = localizationMgr.findByItemAndLanguagecode(item, masterLanguage);

                    labelAttribute.setLanguage(masterLanguage.getIsocode());
                    labelAttribute.setValue(masterLocalization.getLabel());

                    itemStandard.setLabel(labelAttribute);
                } catch (Exception ex) {
                }

            }
        } catch (Exception ex) {
//            log.error("addStandardItemLabel" + ex.getMessage());
        }
    }

    private void addStandardItemDefinition(Localization localization, Item item, ItemStandard itemStandard) {
        /**
         * DEFINITION if the definition is not present in the specific language
         * it will be taken from the maste language
         */
        try {
            StringUtils stringUtils = new StringUtils();

            DefinitionAttribute definitionAttribute = new DefinitionAttribute();

            if (localization != null && localization.getDefinition() != null) {
                Languagecode languagecode = localization.getLanguage();
                definitionAttribute.setLanguage(languagecode.getIsocode());

                String definition = stringUtils.replaceSpecialCharacters(localization.getDefinition());
                definitionAttribute.setValue(definition);
                itemStandard.setDefinition(definitionAttribute);
            } else {
                LocalizationMgr localizationMgr = new LocalizationMgr(em);
                Localization masterLocalization;
                try {
                    masterLocalization = localizationMgr.findByItemAndLanguagecode(item, masterLanguage);

                    definitionAttribute.setLanguage(masterLanguage.getIsocode());

                    String definition = stringUtils.replaceSpecialCharacters(masterLocalization.getDefinition());
                    definitionAttribute.setValue(definition);

                    itemStandard.setDefinition(definitionAttribute);
                } catch (Exception ex) {
                }
            }
        } catch (Exception ex) {
//            log.error("addStandardItemDefinition " + ex.getMessage());
        }
    }

    private void addStandardItemDescription(Localization localization, Item item, ItemStandard itemStandard) {
        /**
         * DESCRIPTION if the description is not present in the specific
         * language it will be taken from the master language
         */
        try {
            StringUtils stringUtils = new StringUtils();

            DescriptionAttribute descriptionAttribute = new DescriptionAttribute();

            if (localization != null && localization.getDescription() != null) {
                Languagecode languagecode = localization.getLanguage();
                descriptionAttribute.setLanguage(languagecode.getIsocode());

                String description = stringUtils.replaceSpecialCharacters(localization.getDescription());
                descriptionAttribute.setValue(description);
                itemStandard.setDescription(descriptionAttribute);
            } else {
                LocalizationMgr localizationMgr = new LocalizationMgr(em);
                Localization masterLocalization;
                try {
                    masterLocalization = localizationMgr.findByItemAndLanguagecode(item, masterLanguage);

                    descriptionAttribute.setLanguage(masterLanguage.getIsocode());

                    String description = stringUtils.replaceSpecialCharacters(masterLocalization.getDescription());
                    descriptionAttribute.setValue(description);

                    itemStandard.setDescription(descriptionAttribute);
                } catch (Exception ex) {
                }
            }
        } catch (Exception ex) {
//            log.error("addStandardItemDescription " + ex.getMessage());
        }
    }

    private void addStandardItemStatus(Item item, Languagecode languagecode, ItemStandard itemStandard) {
        try {
            String isocode = languagecode.getIsocode();
            /**
             * STATUS
             */
            LocalizationMgr localizationMgr = new LocalizationMgr(em);
            Localization localization;
            try {
                localization = localizationMgr.findByLanguagecodeAndStatus(item.getStatus(), languagecode);
            } catch (Exception ex) {
                localization = localizationMgr.findByLanguagecodeAndStatus(item.getStatus(), masterLanguage);
                isocode = masterLanguage.getIsocode();
            }
            String statusLabelFromLocalization = localization.getLabel();

            StatusLabel statusLabel = new StatusLabel();
            statusLabel.setUuid(item.getStatus().getUuid());
            statusLabel.setBaseuri(item.getStatus().getBaseuri());
            statusLabel.setUriname(item.getStatus().getUriname());
            statusLabel.setLabelAttribute(statusLabelFromLocalization, isocode);
            itemStandard.setStatus(statusLabel);
        } catch (Exception ex) {
//            log.error("addStandardItemStatus" + ex.getMessage());
        }
    }

    private void addStandardItemItemClass(Item item, Languagecode languagecode, ItemStandard itemStandard) {
        try {
            String isocode = languagecode.getIsocode();
            /**
             * ITEMCLASS
             */
            LocalizationMgr localizationMgr = new LocalizationMgr(em);
            String itemclassLabelFromLocaliation;
            try {
                itemclassLabelFromLocaliation = (localizationMgr.findByItemclassAndLanguagecode(item.getItemclass(), languagecode)).getLabel();
            } catch (Exception ex) {
                itemclassLabelFromLocaliation = (localizationMgr.findByItemclassAndLanguagecode(item.getItemclass(), masterLanguage)).getLabel();
                isocode = masterLanguage.getIsocode();
            }

            ItemClassLabel itemClassLabel = new ItemClassLabel();
            itemClassLabel.setUuid(item.getItemclass().getUuid());
            itemClassLabel.setUriname(item.getItemclass().getUriname());
            itemClassLabel.setLabelAttribute(itemclassLabelFromLocaliation, isocode);
            itemStandard.setItemclass(itemClassLabel);
        } catch (Exception ex) {
            log.error("addStandardItemItemClass " + ex.getMessage());
        }
    }

    private void addStandardItemParent(Item item, Languagecode languagecode, ItemStandard itemStandard) {
        try {
            String isocode = languagecode.getIsocode();
            /**
             * PARENT
             */
            ItemparentMgr itemparentMgr = new ItemparentMgr(em);
            List<Itemparent> itemparentlist = itemparentMgr.findByItem(item);

            if (itemparentlist.size() > 0) {
                Itemparent itemparent = itemparentlist.get(0);
                Item parent = itemparent.getParent();

                ParentItemLabel parentItemLabel = new ParentItemLabel();
                LocalizationMgr localizationMgr = new LocalizationMgr(em);

                LabelAttribute labelParentAttribute = new LabelAttribute();
                Localization parentLocalization;
                try {
                    parentLocalization = localizationMgr.findByItemAndLanguagecode(parent, languagecode);
                    labelParentAttribute.setLanguage(isocode);
                } catch (Exception ex) {
                    parentLocalization = localizationMgr.findByItemAndLanguagecode(parent, masterLanguage);
                    labelParentAttribute.setLanguage(masterLanguage.getIsocode());
                }

                labelParentAttribute.setValue(parentLocalization.getLabel());
                parentItemLabel.setLabel(labelParentAttribute);

                String urlParent;
                ItemcollectionMgr itemcollectionMgr = new ItemcollectionMgr(em);
                try {
                    List<Itemcollection> findByItem = itemcollectionMgr.findByItem(parent);

                    if (findByItem != null && findByItem.size() > 0) {
                        Itemcollection itemcollection = findByItem.get(0);
                        Item collection = itemcollection.getCollection();

                        String codelistName = collection.getUriname();
                        if (parent.getVersionnumber() == 0) {
                            urlParent = parent.getItemclass().getRegister().getBaseuri() + "/" + parent.getItemclass().getRegister().getUriname() + "/" + codelistName + "/" + parent.getUriname();
                        } else {
                            urlParent = parent.getItemclass().getRegister().getBaseuri() + "/" + parent.getItemclass().getRegister().getUriname() + "/" + codelistName + "/" + parent.getUriname() + ":" + parent.getVersionnumber();
                        }
                    } else if (parent.getVersionnumber() == 0) {
                        urlParent = parent.getItemclass().getRegister().getBaseuri() + "/" + parent.getItemclass().getRegister().getUriname() + "/" + parent.getUriname();
                    } else {
                        urlParent = parent.getItemclass().getRegister().getBaseuri() + "/" + parent.getItemclass().getRegister().getUriname() + "/" + parent.getUriname() + "/" + parent.getUriname() + ":" + parent.getVersionnumber();
                    }
                } catch (Exception e) {
                    if (parent.getVersionnumber() == 0) {
                        urlParent = parent.getItemclass().getRegister().getBaseuri() + "/" + parent.getItemclass().getRegister().getUriname() + "/" + parent.getUriname();
                    } else {
                        urlParent = parent.getItemclass().getRegister().getBaseuri() + "/" + parent.getItemclass().getRegister().getUriname() + "/" + parent.getUriname() + "/" + parent.getUriname() + ":" + parent.getVersionnumber();
                    }
                }
                if (urlParent != null) {
                    parentItemLabel.setUri(urlParent);

                    itemStandard.setParentItemLabel(parentItemLabel);
                }
            }
        } catch (Exception ex) {
//            log.error("addStandardItemParent " + item.getUriname() + " Has NO parent " + ex.getMessage());
        }
    }

    private void addStandardItemPredecessor(Item item, Languagecode languagecode, ItemStandard itemStandard) {
        try {
            String isocode = languagecode.getIsocode();
            /**
             * PREDECESSOR read the cross table and get all the itemsuccessor
             * with the successor item
             */
            ItemsuccessorMgr itemsuccessorMgr = new ItemsuccessorMgr(em);
            List<Itemsuccessor> itempredecessorList = itemsuccessorMgr.getItempredecessorList(item);

            if (itempredecessorList != null && itempredecessorList.size() > 0) {
                ArrayList<Item> predecessorList = new ArrayList<Item>();

                for (Iterator<Itemsuccessor> its = itempredecessorList.iterator(); its.hasNext();) {
                    Itemsuccessor itempredecessor = its.next();
                    if (!itempredecessor.getItem().equals(item)) {
                        predecessorList.add(itempredecessor.getItem());
                    }
                }

                if (predecessorList.size() > 0) {
                    ArrayList<PredecessorItemLabel> predecessorItemLabelArray = new ArrayList<PredecessorItemLabel>();
                    for (Iterator<Item> predecessorItem = predecessorList.iterator(); predecessorItem.hasNext();) {
                        Item prededecessor = predecessorItem.next();

                        LocalizationMgr localizationMgr = new LocalizationMgr(em);
                        Localization successorLocalization;
                        try {
                            successorLocalization = localizationMgr.findByItemAndLanguagecode(prededecessor, languagecode);
                        } catch (Exception ex) {
                            successorLocalization = localizationMgr.findByItemAndLanguagecode(prededecessor, masterLanguage);
                            isocode = masterLanguage.getIsocode();
                        }

                        PredecessorItemLabel predecessorItemLabel = new PredecessorItemLabel();
                        LabelAttribute predecessprLabelAttribute = new LabelAttribute();
                        predecessprLabelAttribute.setLanguage(isocode);
                        predecessprLabelAttribute.setValue(successorLocalization.getLabel());
                        predecessorItemLabel.setLabel(predecessprLabelAttribute);

                        String urlPredecessor;
                        if (prededecessor.getVersionnumber() == 0) {
                            urlPredecessor = item.getItemclass().getRegister().getBaseuri() + "/" + item.getItemclass().getRegister().getUriname() + "/" + prededecessor.getUriname();
                        } else {
                            urlPredecessor = item.getItemclass().getRegister().getBaseuri() + "/" + item.getItemclass().getRegister().getUriname() + "/" + prededecessor.getUriname() + ":" + prededecessor.getVersionnumber();
                        }

                        predecessorItemLabel.setUri(urlPredecessor);
                        predecessorItemLabelArray.add(predecessorItemLabel);
                    }
                    if (!predecessorItemLabelArray.isEmpty()) {
                        PredecessorItemLabelList predecessprItemLabelList = new PredecessorItemLabelList();
                        predecessprItemLabelList.setItemPredecessor(predecessorItemLabelArray);
                        itemStandard.setPredecessorItemLabelList(predecessprItemLabelList);
                    }
                }
            }
        } catch (Exception ex) {
//            log.error("addStandardItemPredecessor " + item.getUriname() + " has no predecessor " + ex.getMessage());
        }
    }

    private void addStandardItemSuccessor(Item item, Languagecode languagecode, ItemStandard itemStandard) {
        try {
            String isocode = languagecode.getIsocode();
            /**
             * SUCCESSOR read the cross table and get all the itemsuccessor with
             * the item item
             */
            ItemsuccessorMgr itemsuccessorMgr = new ItemsuccessorMgr(em);
            List<Itemsuccessor> itemsuccecessorList = itemsuccessorMgr.getItemsuccessorList(item);

            if (itemsuccecessorList != null && itemsuccecessorList.size() > 0) {
                ArrayList<Item> successorList = new ArrayList<Item>();

                for (Iterator<Itemsuccessor> its = itemsuccecessorList.iterator(); its.hasNext();) {
                    Itemsuccessor itemsuccessor = its.next();
                    if (!itemsuccessor.getSuccessor().equals(item)) {
                        successorList.add(itemsuccessor.getSuccessor());
                    }
                }

                if (successorList.size() > 0) {
                    ArrayList<SuccessorItemLabel> successorItemLabelArray = new ArrayList<SuccessorItemLabel>();
                    for (Iterator<Item> successorItem = successorList.iterator(); successorItem.hasNext();) {
                        Item successor = successorItem.next();

                        LocalizationMgr localizationMgr = new LocalizationMgr(em);
                        Localization successorLocalization;
                        try {
                            successorLocalization = localizationMgr.findByItemAndLanguagecode(successor, languagecode);
                        } catch (Exception ex) {
                            successorLocalization = localizationMgr.findByItemAndLanguagecode(successor, masterLanguage);
                            isocode = masterLanguage.getIsocode();
                        }

                        SuccessorItemLabel successorItemLabel = new SuccessorItemLabel();
                        LabelAttribute successorLabelAttribute = new LabelAttribute();
                        successorLabelAttribute.setLanguage(isocode);
                        successorLabelAttribute.setValue(successorLocalization.getLabel());
                        successorItemLabel.setLabel(successorLabelAttribute);
                        String urlSuccessor;
                        if (successor.getVersionnumber() == 0) {
                            urlSuccessor = item.getItemclass().getRegister().getBaseuri() + "/" + item.getItemclass().getRegister().getUriname() + "/" + successor.getUriname();
                        } else {
                            urlSuccessor = item.getItemclass().getRegister().getBaseuri() + "/" + item.getItemclass().getRegister().getUriname() + "/" + successor.getUriname() + ":" + successor.getVersionnumber();
                        }

                        successorItemLabel.setUri(urlSuccessor);
                        successorItemLabelArray.add(successorItemLabel);
                    }
                    if (!successorItemLabelArray.isEmpty()) {
                        SuccessorItemLabelList successorItemLabelList = new SuccessorItemLabelList();
                        successorItemLabelList.setItemSuccessor(successorItemLabelArray);
                        itemStandard.setSuccessorItemLabelList(successorItemLabelList);
                    }
                }
            }
        } catch (Exception ex) {
//            log.error("addStandardItemSuccessor " + item.getUriname() + " has no successor " + ex.getMessage());
        }
    }

    private void addStandardItemRegister(Item item, Languagecode languagecode, ItemStandard itemStandard) {
        try {
            String isocode = languagecode.getIsocode();
            /**
             * REGISTER
             */
            if (item.getItemclass().getRegister() != null) {
                RegisterAttribute registerAttribute = new RegisterAttribute();

                LocalizationMgr localizationMgr = new LocalizationMgr(em);
                Register register = item.getItemclass().getRegister();
                Localization registerLocalization;
                try {
                    registerLocalization = localizationMgr.findByRegisterAndLanguagecode(register, languagecode);
                } catch (Exception ex) {
                    registerLocalization = localizationMgr.findByRegisterAndLanguagecode(register, masterLanguage);
                    isocode = masterLanguage.getIsocode();
                }

                LabelAttribute registerLabelAttribute = new LabelAttribute();
                registerLabelAttribute.setLanguage(isocode);
                registerLabelAttribute.setValue(registerLocalization.getLabel());

                String urlRegister = item.getItemclass().getRegister().getBaseuri() + "/" + item.getItemclass().getRegister().getUriname();
                registerAttribute.setLabel(registerLabelAttribute);
                registerAttribute.setUri(urlRegister);

                RegistryAttribute registryAttribute = new RegistryAttribute();
                Registry registry = item.getItemclass().getRegister().getRegistry();

                Localization registryLocalization;
                try {
                    registryLocalization = localizationMgr.findByRegistryAndLanguagecode(registry, languagecode);
                } catch (Exception ex) {
                    registryLocalization = localizationMgr.findByRegistryAndLanguagecode(registry, masterLanguage);
                    isocode = masterLanguage.getIsocode();
                }

                LabelAttribute registryLabelAttribute = new LabelAttribute();
                registryLabelAttribute.setLanguage(isocode);
                registryLabelAttribute.setValue(registryLocalization.getLabel());

                String urlRegistry = registry.getBaseuri() + "/" + registry.getUriname();
                registryAttribute.setLabel(registryLabelAttribute);
                registryAttribute.setUri(urlRegistry);

                registerAttribute.setRegistry(registryAttribute);

                itemStandard.setRegister(registerAttribute);
            }
        } catch (Exception ex) {
//            log.error("addStandardItemRegister " + ex.getMessage());
        }
    }

    private void addStandardItemCustomattribut(Languagecode languagecode, Item item, ItemStandard itemStandard) {
        try {
            String isocode = languagecode.getIsocode();
            LocalizationMgr localizationMgr = new LocalizationMgr(em);
            /**
             * CUSTOMATTRIBUTE
             */
            CustomattributeLabelList customattributeLabelList = new CustomattributeLabelList();
            ArrayList<CustomattributeLabel> customattributeLabelArray = new ArrayList<CustomattributeLabel>();

            /**
             * get all the custom attribute for the itemclass
             */
            ItemclasscustomattributeMgr itemclasscustomattributeMgr = new ItemclasscustomattributeMgr(em);
            List<Itemclasscustomattribute> itemclasscustomattributeList = itemclasscustomattributeMgr.findAllByItemclass(item.getItemclass());
            for (Itemclasscustomattribute itemclasscustomattribute : itemclasscustomattributeList) {
                Customattribute customattribute = itemclasscustomattribute.getCustomattribute();
                Itemclass itemclass = itemclasscustomattribute.getItemclass();
                boolean foreygnkey = itemclasscustomattribute.getIsforeignkey();

                CustomattributevalueMgr customattributevalueMgr = new CustomattributevalueMgr(em);
                List<Customattributevalue> findCustomAttributeValueFromitemAndCustomAttributeList = customattributevalueMgr.findCustomAttributeValueFromItemAndCustomAttribute(item, customattribute);

                for (Iterator<Customattributevalue> cav = findCustomAttributeValueFromitemAndCustomAttributeList.iterator(); cav.hasNext();) {
                    Customattributevalue customattributevalue = cav.next();

                    Localization findAllByCustomattributeValueAndLanguage;
                    try {
                        findAllByCustomattributeValueAndLanguage = localizationMgr.findByCustomattributevalueAndLanguagecode(customattributevalue, languagecode);
                    } catch (Exception ex) {
                        findAllByCustomattributeValueAndLanguage = localizationMgr.findByCustomattributevalueAndLanguagecode(customattributevalue, masterLanguage);
                    }
                    String uriname = findAllByCustomattributeValueAndLanguage.getLabel();

                    CustomattributeLabel customattributeLabel = new CustomattributeLabel();
                    customattributeLabel.setName(customattribute.getName());
                    customattributeLabel.setUriname(uriname);
                    customattributeLabel.setMultivalue(customattribute.getMultivalue());
                    customattributeLabel.setIsforeignKey(foreygnkey);
                    customattributeLabel.setRequired(itemclasscustomattribute.getRequired());
                    customattributeLabel.setCoded(customattribute.getCoded());
                    customattributeLabel.setDatecreation(customattribute.getDatecreation());
                    customattributeLabel.setDatelastupdate(customattribute.getDatelastupdate());

                    if (foreygnkey) {
                        try {
                            ItemMgr itemMgr = new ItemMgr(em);

                            ItemclassMgr itemclassMgr = new ItemclassMgr(em);
                            Itemclass itemclassCustomattribute = itemclassMgr.getItemclassByUriname(customattribute.getName());

                            Item itemcustomattribute = itemMgr.findByItemclassAndUriname(itemclassCustomattribute, uriname);
                            Localization itemLocalization;
                            try {
                                itemLocalization = localizationMgr.findByItemAndLanguagecode(itemcustomattribute, languagecode);
                            } catch (Exception e) {
                                itemLocalization = localizationMgr.findByItemAndLanguagecode(itemcustomattribute, masterLanguage);
                                isocode = masterLanguage.getIsocode();
                            }

                            LabelAttribute customattributeLabelAttribute = new LabelAttribute();
                            customattributeLabelAttribute.setLanguage(isocode);
                            customattributeLabelAttribute.setValue(itemLocalization.getLabel());
                            customattributeLabel.setLabel(customattributeLabelAttribute);

                            customattributeLabel.setUri(itemclassCustomattribute.getRegister().getBaseuri() + "/" + itemclassCustomattribute.getRegister().getUriname() + "/" + uriname);
                        } catch (Exception ex) {
//                        log.error("No custom attribute localization itemclass: " + itemclass + ", uriname" + uriname + ", language " + languagecode + " " + ex.getMessage());
                        }
                    }

                    customattributeLabelArray.add(customattributeLabel);
                }
            }

            if (!customattributeLabelArray.isEmpty()) {
                customattributeLabelList.setCustomattributeLabel(customattributeLabelArray);
                itemStandard.setCustomattributeLabelList(customattributeLabelList);
            }
        } catch (Exception ex) {
//            log.error("addStandardItemCustomattribut " + ex.getMessage());
        }
    }

    private void addItemStandardCodelist(Languagecode languagecode, Item item, ItemStandard itemStandard) {
        /**
         * CODELIST
         */
        String isocode = languagecode.getIsocode();
        try {
            ItemcollectionMgr itemcollectionMgr = new ItemcollectionMgr(em);
            List<Itemcollection> itemcollectionList = itemcollectionMgr.findByItem(item);

            if (itemcollectionList != null && itemcollectionList.size() > 0) {
                Itemcollection itemcollection = itemcollectionList.get(0);
                Item collection = itemcollection.getCollection();
                CodelistAttribute codelistAttribute = new CodelistAttribute();

                LocalizationMgr localizationMgr = new LocalizationMgr(em);
                LabelAttribute codelistLabelAttribute = new LabelAttribute();
                Localization itemFromCollectionLocalization;
                try {
                    itemFromCollectionLocalization = localizationMgr.findByItemAndLanguagecode(collection, languagecode);
                } catch (Exception ex) {
                    itemFromCollectionLocalization = localizationMgr.findByItemAndLanguagecode(collection, masterLanguage);
                    isocode = masterLanguage.getIsocode();
                }

                codelistLabelAttribute.setLanguage(isocode);
                codelistLabelAttribute.setValue(itemFromCollectionLocalization.getLabel());

                codelistAttribute.setLabel(codelistLabelAttribute);

                String uriCodelist = item.getItemclass().getRegister().getBaseuri() + "/" + item.getItemclass().getRegister().getUriname() + "/" + collection.getUriname();
                codelistAttribute.setUri(uriCodelist);
                codelistAttribute.setUriname(collection.getUriname());

                itemStandard.setCodelist(codelistAttribute);
            }
        } catch (Exception ex) {
//            log.error("addItemStandardCodelist " + item.getUriname() + " Has NO parent " + ex.getMessage());
        }
    }

    private void addItemStandardCollectionItems(Item item, Languagecode languagecode, ItemStandard itemStandard) {
        /**
         * COLLECTION
         */
        /**
         * get all the items with collection == item
         */
        try {
            ItemcollectionMgr itemcollectionMgr = new ItemcollectionMgr(em);
            ArrayList<ItemStandard> itemStandardArray = new ArrayList<ItemStandard>();
            List<Itemcollection> itemcollectionList = itemcollectionMgr.findByCollection(item);

            if (itemcollectionList.size() > 0) {
                for (Iterator<Itemcollection> it = itemcollectionList.iterator(); it.hasNext();) {
                    Item itemWithCollection = it.next().getItem();
                    if (itemWithCollection.getVersionnumber() == 0) {
                        /**
                         * for all items from the collection get the
                         * localization
                         */
                        LocalizationMgr localizationMgr = new LocalizationMgr(em);

                        Localization findLocalizationFromItemWithCollection;
                        try {
                            findLocalizationFromItemWithCollection = localizationMgr.findByItemAndLanguagecode(itemWithCollection, languagecode);
                        } catch (Exception ex) {
                            findLocalizationFromItemWithCollection = localizationMgr.findByItemAndLanguagecode(itemWithCollection, masterLanguage);
                        }

                        ItemStandard itemStandardWithCollection = new ItemStandard();
                        addItemStandardFields(itemStandardWithCollection, itemWithCollection);
                        addStandardItemLabel(findLocalizationFromItemWithCollection, itemWithCollection, itemStandardWithCollection);
                        addStandardItemDefinition(findLocalizationFromItemWithCollection, itemWithCollection, itemStandardWithCollection);
                        addStandardItemDescription(findLocalizationFromItemWithCollection, itemWithCollection, itemStandardWithCollection);
                        addStandardItemStatus(itemWithCollection, languagecode, itemStandardWithCollection);
                        addStandardItemItemClass(itemWithCollection, languagecode, itemStandardWithCollection);
                        addStandardItemParent(itemWithCollection, languagecode, itemStandardWithCollection);
                        addStandardItemPredecessor(itemWithCollection, languagecode, itemStandardWithCollection);
                        addStandardItemSuccessor(itemWithCollection, languagecode, itemStandardWithCollection);
                        addStandardItemRegister(itemWithCollection, languagecode, itemStandardWithCollection);
                        addItemStandardCodelist(languagecode, itemWithCollection, itemStandardWithCollection);
                        addStandardItemCustomattribut(languagecode, itemWithCollection, itemStandardWithCollection);
//                    addItemStandardCollection(itemWithCollection, languagecode, itemStandardWithCollection);
//                    addItemStandardChildren(itemWithCollection, languagecode, itemStandardWithCollection);
                        addItemStandardDates(itemStandard, itemWithCollection);

                        itemStandardArray.add(itemStandardWithCollection);
                    }
                }

                CollectionItemLabel collectionLabelList = new CollectionItemLabel();
                collectionLabelList.setItemLabel(itemStandardArray);
                itemStandard.setCollectionlabelList(collectionLabelList);
            }
        } catch (Exception ex) {
//            log.error("addItemStandardCollectionItems " + ex.getMessage());
        }
    }

    private void addItemStandardDates(ItemStandard itemStandard, Item item) {
        /**
         * DATES
         */
        try {
            itemStandard.setDatecreation(item.getDatecreation());
            itemStandard.setDatelastupdate(item.getDatelastupdate());
            itemStandard.setDatetimeaddition(item.getDatetimeaddition());
            itemStandard.setDatetimesupersession(item.getDatetimesupersession());
            itemStandard.setDatetimeretirment(item.getDatetimeretirment());
            itemStandard.setDatetimeinvalidation(item.getDatetimeinvalidation());
        } catch (Exception ex) {
//            log.error("addItemStandardDates " + ex.getMessage());
        }
    }

    private void addItemStandardChildren(Item item, Languagecode languagecode, ItemStandard itemStandard) {
        /**
         * CHILDREN get all the items with the parent = item
         */
        try {
            ItemparentMgr itemparentMgr = new ItemparentMgr(em);
            List<Itemparent> itemparentList = itemparentMgr.findByParent(item);
            if (itemparentList != null && itemparentList.size() > 0) {
                ArrayList<ItemStandard> itemChildrenArray = new ArrayList<ItemStandard>();

                for (Iterator<Itemparent> it = itemparentList.iterator(); it.hasNext();) {
                    Item itemWithParent = it.next().getItem();
                    if (itemWithParent.getVersionnumber() == 0) {
                        /**
                         * get Localization for item = itemWithParent and
                         * language
                         */
                        LocalizationMgr localizationMgr = new LocalizationMgr(em);
                        Localization findLocalizationFromItemWithParentAndLanguage;
                        try {
                            findLocalizationFromItemWithParentAndLanguage = localizationMgr.findByItemAndLanguagecode(itemWithParent, languagecode);
                        } catch (Exception ex) {
                            findLocalizationFromItemWithParentAndLanguage = localizationMgr.findByItemAndLanguagecode(itemWithParent, masterLanguage);
                            languagecode = masterLanguage;
                        }

                        ItemStandard itemStandardWithParent = new ItemStandard();
                        addItemStandardFields(itemStandardWithParent, itemWithParent);
                        addStandardItemLabel(findLocalizationFromItemWithParentAndLanguage, itemWithParent, itemStandardWithParent);
                        addStandardItemDefinition(findLocalizationFromItemWithParentAndLanguage, itemWithParent, itemStandardWithParent);
                        addStandardItemDescription(findLocalizationFromItemWithParentAndLanguage, itemWithParent, itemStandardWithParent);
                        addStandardItemStatus(itemWithParent, languagecode, itemStandardWithParent);
                        addStandardItemItemClass(itemWithParent, languagecode, itemStandardWithParent);
                        addStandardItemParent(itemWithParent, languagecode, itemStandardWithParent);
                        addStandardItemPredecessor(itemWithParent, languagecode, itemStandardWithParent);
                        addStandardItemSuccessor(itemWithParent, languagecode, itemStandardWithParent);
                        addStandardItemRegister(itemWithParent, languagecode, itemStandardWithParent);
                        addItemStandardCodelist(languagecode, itemWithParent, itemStandardWithParent);
                        addStandardItemCustomattribut(languagecode, itemWithParent, itemStandardWithParent);
//                        addItemStandardCollectionItems(itemWithParent, languagecode, itemStandardWithParent);
//                    addItemStandardChildren(itemWithParent, languagecode, itemStandardWithParent);
                        addItemStandardDates(itemStandardWithParent, itemWithParent);

                        itemChildrenArray.add(itemStandardWithParent);
                    }
                }
                ItemChildrenLabelList itemChildrenLabelList = new ItemChildrenLabelList();
                itemChildrenLabelList.setItemlabelList(itemChildrenArray);
                itemStandard.setChildren(itemChildrenLabelList);
            }
        } catch (Exception ex) {
//            log.error("addItemStandardChildren " + ex.getMessage());
        }
    }

    private void addMiniItemStandardChildren(Item item, Languagecode languagecode, ItemStandard itemStandard) {
        /**
         * CHILDREN get all the items with the parent = item
         */
        try {
            ItemparentMgr itemparentMgr = new ItemparentMgr(em);
            List<Itemparent> itemparentList = itemparentMgr.findByParent(item);
            if (itemparentList != null && itemparentList.size() > 0) {
                ArrayList<ItemStandard> itemChildrenArray = new ArrayList<ItemStandard>();

                for (Iterator<Itemparent> it = itemparentList.iterator(); it.hasNext();) {
                    Item itemWithParent = it.next().getParent();

                    /**
                     * get Localization for item = itemWithParent and language
                     */
                    LocalizationMgr localizationMgr = new LocalizationMgr(em);
                    Localization findLocalizationFromItemWithParentAndLanguage;
                    try {
                        findLocalizationFromItemWithParentAndLanguage = localizationMgr.findByItemAndLanguagecode(itemWithParent, languagecode);
                    } catch (Exception ex) {
                        findLocalizationFromItemWithParentAndLanguage = localizationMgr.findByItemAndLanguagecode(itemWithParent, masterLanguage);
                        languagecode = masterLanguage;
                    }

                    ItemStandard itemStandardWithParent = new ItemStandard();
                    addItemStandardFields(itemStandardWithParent, itemWithParent);
                    addStandardItemLabel(findLocalizationFromItemWithParentAndLanguage, itemWithParent, itemStandardWithParent);
                    addStandardItemDefinition(findLocalizationFromItemWithParentAndLanguage, itemWithParent, itemStandardWithParent);
                    addStandardItemDescription(findLocalizationFromItemWithParentAndLanguage, itemWithParent, itemStandardWithParent);
                    addStandardItemStatus(itemWithParent, languagecode, itemStandardWithParent);
                    addStandardItemItemClass(itemWithParent, languagecode, itemStandardWithParent);
                    addStandardItemParent(itemWithParent, languagecode, itemStandardWithParent);
                    addStandardItemPredecessor(itemWithParent, languagecode, itemStandardWithParent);
                    addStandardItemSuccessor(itemWithParent, languagecode, itemStandardWithParent);
                    addStandardItemRegister(itemWithParent, languagecode, itemStandardWithParent);
                    addItemStandardCodelist(languagecode, item, itemStandard);
                    addStandardItemCustomattribut(languagecode, itemWithParent, itemStandardWithParent);
//                    addItemStandardCollectionItems(item, languagecode, itemStandard);
//                    addItemStandardChildren(itemWithParent, languagecode, itemStandardWithParent);
                    addItemStandardDates(itemStandardWithParent, itemWithParent);

                    itemChildrenArray.add(itemStandardWithParent);
                }
                ItemChildrenLabelList itemChildrenLabelList = new ItemChildrenLabelList();
                itemChildrenLabelList.setItemlabelList(itemChildrenArray);
                itemStandard.setChildren(itemChildrenLabelList);
            }
        } catch (Exception ex) {
//            log.error("addItemStandardChildren " + ex.getMessage());
        }
    }
}
