/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrystaticizer.servlet;

import eu.europa.ec.re3gistrycommon.managers.ChangelogMgr;
import eu.europa.ec.re3gistrycommon.managers.DataprocedureMgr;
import eu.europa.ec.re3gistrycommon.managers.StaticizerMgr;
import eu.europa.ec.re3gistrycommon.model.Changelog;
import eu.europa.ec.re3gistrycommon.model.Staticizer;
import eu.europa.ec.re3gistrycommon.model.Dataprocedure;
import eu.europa.ec.re3gistrycommon.model.Item;
import eu.europa.ec.re3gistrycommon.utils.PersistenceFactory;
import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import eu.europa.ec.re3gistrystaticizer.manager.DataprocedureManagerBean;
import eu.europa.ec.re3gistrystaticizer.manager.ItemManagerBean;
import eu.europa.ec.re3gistrystaticizer.manager.StaticizerManagerBean;

import java.io.IOException;
import java.util.Date;
import java.util.Iterator;
import java.util.List;
import javax.persistence.EntityManager;

import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class AnalizeStaticizer extends HttpServlet {

    private static final long serialVersionUID = 1L;
    private static org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);

    protected void analyzeRequest(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        log.info("####################################################################");
        log.info("##################### START ANALIZE STATICIZER #####################");

        StaticizerManagerBean staticizerManagerBean = new StaticizerManagerBean();
        DataprocedureManagerBean dataprocedureManagerBean = new DataprocedureManagerBean();
        ItemManagerBean itemManagerBean = new ItemManagerBean();

        Date lastStartStaticizerDate = null;
        try {
            EntityManager em = PersistenceFactory.getEntityManagerFactory().createEntityManager();

            StaticizerMgr staticizerMgr = new StaticizerMgr(em);
            try {
                /**
                 * get all the staticizer ordered desc by the start date
                 */
                List<Staticizer> staticizerList = staticizerMgr.getAllStaticizerOrderDescByDatestart();
                if (!staticizerList.isEmpty()) {

                    /**
                     * add the details of the all the staticizer to a bean list,
                     * which will be used to fill the GUI table
                     */
                    for (Staticizer staticizer : staticizerList) {
                        Date dateEnd = staticizer.getDateend();
                        if (dateEnd == null) {
                            staticizerManagerBean.addStaticizer(staticizer.getUuid(), staticizer.getProcedurestatus().getLabel(), staticizer.getDatestart().toString(), "");
                        } else {
                            staticizerManagerBean.addStaticizer(staticizer.getUuid(), staticizer.getProcedurestatus().getLabel(), staticizer.getDatestart().toString(), dateEnd.toString());
                        }
                    }

                    /**
                     * save the start date of the last staticizer
                     */
                    lastStartStaticizerDate = staticizerList.get(0).getDatestart();
                }
            } catch (Exception e) {
                log.error("@@ An error occurs while executing the operations: " + e.getMessage());
            }

            DataprocedureMgr dataprocedureMgr = new DataprocedureMgr(em);
            try {
                List<Dataprocedure> dataprocedureList;
                /**
                 * if there is almost one staticizer done, than take all the
                 * data procedure after the data start of last staticizer
                 * ordered by data completed, else take all the data procedure
                 * ordered by data completed
                 */
                if (lastStartStaticizerDate != null) {
                    dataprocedureList = dataprocedureMgr.findAllAfterDateOrderAscByDatecompleted(lastStartStaticizerDate);
                } else {
                    dataprocedureList = dataprocedureMgr.findAllOrderAscByDatecompleted();
                }

                /**
                 * if there is almost one data procedure add the details of the
                 * all the data procedure to a bean list, which will be used to
                 * fill the GUI table, and all the details of the items of each
                 * data procedure in another bean which will be shown by the GUI
                 * table
                 */
                if (!dataprocedureList.isEmpty()) {
                    for (Iterator<Dataprocedure> dp = dataprocedureList.iterator(); dp.hasNext();) {
                        Dataprocedure dataprocedure = dp.next();

                        dataprocedureManagerBean.addDataprocedure(dataprocedure.getComment(), dataprocedure.getFolder(), dataprocedure.getDatecompleted());

                        /**
                         * For each data procedure read in the changelog table
                         * the items to be staticized
                         */
                        ChangelogMgr changelogMgr = new ChangelogMgr(em);
                        List<Changelog> changeLogItems = changelogMgr.getChangelogByDataProcedure(dataprocedure);

                        for (Iterator<Changelog> it = changeLogItems.iterator(); it.hasNext();) {
                            Changelog changelog = it.next();

                            Item item = changelog.getItem();
                            if (changelog.getLanguagecode() != null) {
                                itemManagerBean.addItemBean(item.getUriname(), item.getItemclass().getUriname(), changelog.getAction(), changelog.getLanguagecode().getLabel(), item.getDatecreation());
                            } else {
                                itemManagerBean.addItemBean(item.getUriname(), item.getItemclass().getUriname(), changelog.getAction(), "", item.getDatecreation());
                            }
                        }
                    }
                } else {
                    log.info(Constants.ANALYZE_DATA_PROCEDURE + " == " + Constants.NO_DATA_PROCEDURE);
                }
            } catch (Exception e) {
                log.error("@@ An error occurs while executing the operations: " + e.getMessage());
            }

        } catch (Exception e) {
            log.error("@@ An error occurs while executing the operations: " + e.getMessage());
        }

        /**
         * set to the HttpServletRequest all the attributs
         */
        request.setAttribute(Constants.STATICIZER_LIST_ATTRIBUTE, staticizerManagerBean);
        request.setAttribute(Constants.STATICIZER_LIST_SIZE_ATTRIBUTE, staticizerManagerBean.getSize());

        request.setAttribute(Constants.DATA_PROCEDURE_LIST_ATTRIBUTE, dataprocedureManagerBean);
        request.setAttribute(Constants.DATA_PROCEDURE_LIST_SIZE_ATTRIBUTE, dataprocedureManagerBean.getSize());

        request.setAttribute(Constants.ITEM_LIST_ATTRIBUTE, itemManagerBean);
        request.setAttribute(Constants.ITEM_LIST_SIZE_ATTRIBUTE, itemManagerBean.getSize());

        /**
         * redirect to the Staticizer page
         */
        request.getRequestDispatcher("?m=Re3gistryStaticizer").forward(request, response);

        log.info("##################### END ANALIZE STATICIZER #####################");
        log.info("##################################################################");
    }

    /**
     * Handles the HTTP
     * <code>GET</code> method.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        analyzeRequest(request, response);
    }

    /**
     * Handles the HTTP
     * <code>POST</code> method.
     *
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        analyzeRequest(request, response);
    }

    /**
     * Returns a short description of the servlet.
     *
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }
}