/*
 * Copyright 2010,2014 EUROPEAN UNION
 * Licensed under the EUPL, Version 1.1 or - as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://ec.europa.eu/idabc/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 *
 * Date: 29/09/2014
 * Authors: European Commission, Joint Research Centre
 * Daniele Francioli, Emanuela Epure
 * inspire-registry-info@jrc.ec.europa.eu
 *
 * This work was supported by the EU  Interoperability Solutions for
 * European Public Administrations Programme (http://ec.europa.eu/isa)
 * through Action 1.17: Re-usable INSPIRE Reference Platform 
 */
package eu.europa.ec.re3gistrystaticizer.servlet;

import eu.europa.ec.re3gistrycommon.managers.ChangelogMgr;
import eu.europa.ec.re3gistrycommon.managers.DataprocedureMgr;
import eu.europa.ec.re3gistrycommon.managers.LanguagecodeMgr;
import eu.europa.ec.re3gistrycommon.managers.LocalizationMgr;
import eu.europa.ec.re3gistrycommon.managers.ProcedurestatusMgr;
import eu.europa.ec.re3gistrycommon.managers.StaticizerMgr;
import eu.europa.ec.re3gistrycommon.model.Changelog;
import eu.europa.ec.re3gistrycommon.model.Dataprocedure;
import eu.europa.ec.re3gistrycommon.model.Item;
import eu.europa.ec.re3gistrycommon.model.Itemclass;
import eu.europa.ec.re3gistrycommon.model.Languagecode;
import eu.europa.ec.re3gistrycommon.model.Localization;
import eu.europa.ec.re3gistrycommon.model.Procedurestatus;
import eu.europa.ec.re3gistrycommon.model.Register;
import eu.europa.ec.re3gistrycommon.model.Staticizer;
import eu.europa.ec.re3gistrycommon.utils.Mail;
import eu.europa.ec.re3gistrycommon.utils.PersistenceFactory;
import eu.europa.ec.re3gistrycommon.utils.StringUtils;
import eu.europa.ec.re3gistrystaticizer.constants.Constants;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.ItemStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.RegisterStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.RegistryStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.collection.CollectionItemStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.collection.CollectionRegisterStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.collection.CollectionRegistryStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.collection.ContainerCollectionItemStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.collection.ContainerCollectionRegisterStandard;
import eu.europa.ec.re3gistrystaticizer.jaxbmodelstandard.collection.ContainerCollectionRegistryStandard;
import eu.europa.ec.re3gistrystaticizer.marshaller.RegisterStaticizer;
import eu.europa.ec.re3gistrystaticizer.marshaller.RegistryStaticizer;
import eu.europa.ec.re3gistrystaticizer.marshaller.SolrLastImportedItems;
import eu.europa.ec.re3gistrystaticizer.marshaller.SolrRegisterStaticizer;
import eu.europa.ec.re3gistrystaticizer.marshaller.SolrRegistryStaticizer;
import eu.europa.ec.re3gistrystaticizer.marshaller.StaticizeLastImportedItems;
import eu.europa.ec.re3gistrystaticizer.vargenerator.VarGenerator;
import java.io.File;
import java.io.IOException;
import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.Date;
import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;
import java.util.ResourceBundle;
import java.util.SortedSet;
import java.util.TreeSet;
import javax.persistence.EntityManager;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.servlet.http.HttpSession;

public class StartStaticizer extends HttpServlet {

    private static final long serialVersionUID = 1L;
    private String staticizerMainfolderName;
    private String staticizerStandardFolder;
    private String staticizerCutomFolder;
    private String staticizerSolrStandardFolder;
    private String staticizerSolrCustomFolder;
    private String staticizerXSLFolder;
    private String folderStandardStaticizer;
    private String folderCustomStaticizer;
    private String folderSolrStaticizer;
    private String folderSolrCustomStaticizer;
    private String[] EXTENSIONS;
    private String[] EXTENSIONSSOLR;
    private static Properties properties;
    private HttpServletRequest request;
    private ResourceBundle localizationres;
    private final String folderSeparator = System.getProperty("file.separator");
    private static final org.apache.log4j.Logger log = org.apache.log4j.Logger.getLogger(Constants.MODULE_NAME);

    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
        this.request = request;
        /**
         * Initializing the system localization
         */
        HttpSession s = this.request.getSession();
        String currentLanguage = (String) s.getAttribute(Constants.LANGUAGE_SESSION_KEY);
        if (currentLanguage == null) {
            currentLanguage = this.request.getLocale().toString();
        }
        localizationres = ResourceBundle.getBundle(Constants.LOCALIZATION_PREFIX + Constants.MODULE_NAME + Constants.LOCALIZATION_SUFFIX, new Locale(currentLanguage));

        log.info("############################################################");
        log.info("##################### START STATICIZER #####################");
        log.info("############################################################");

        /**
         * initialize the properties and the main staticizer folder
         */
        initProperties();
        initalizateMainStaticizerFolder();

        try {
            EntityManager em = PersistenceFactory.getEntityManagerFactory().createEntityManager();

            /**
             * get all the staticizer ordered desc by the start date
             */
            StaticizerMgr staticizerMgr = new StaticizerMgr(em);
            List<Staticizer> staticizerList = staticizerMgr.getAllStaticizerOrderDescByDatestart();

            if (staticizerList.isEmpty()) {

                DataprocedureMgr dataprocedureMgr = new DataprocedureMgr(em);

                /**
                 * get all the data procedure ordered asc by date completed
                 */
                List<Dataprocedure> dataprocedureList = dataprocedureMgr.findAllOrderAscByDatecompleted();

                if (!dataprocedureList.isEmpty()) {
                    /**
                     * start the saving of the files in the file system
                     */
                    startToStaticizeLastImportedItems(em);
                    request.setAttribute(Constants.STATICIZER_ATTRIBUTE, "The data has been staticized");
                } else {
                    request.setAttribute(Constants.STATICIZER_ATTRIBUTE, "There is no data to be staticized");
                }
            } else {
                /**
                 * start the saving on the files in the file system with the
                 * started date of the last staticizer which mean that there is
                 * no staticizer saved in the system, so will take all the item
                 * of all the data procedure and save them
                 */
                startToStaticizeLastImportedItems(em);
                request.setAttribute(Constants.STATICIZER_ATTRIBUTE, "The data has been staticized");
            }

            em.close();
        } catch (Exception ex) {
            log.info(StartStaticizer.class + " === " + ex.getMessage());
        }
        request.getRequestDispatcher("?m=Re3gistryStaticizer").forward(request, response);

        log.info("############################################################");
        log.info("##################### END STATICIZER #####################");
        log.info("############################################################");
    }

    private void initProperties() {
        if (properties == null) {
            properties = eu.europa.ec.re3gistrycommon.utils.Configuration.getInstance().getProperties(Constants.MODULE_NAME);
            log.info("Module properties loaded");
        }
    }

    private void initalizateMainStaticizerFolder() {
        /**
         * initialize the main staticizer folder
         */
        staticizerMainfolderName = properties.getProperty(Constants.STATICIZER_FOLDER_PATH, "E:/re3gistry-data/staticizer");

        new File(staticizerMainfolderName).mkdirs();
    }

    private void initalizateStaticizerStandardAndCustomFolders() {
        /**
         * initialize the staticizer standard and custom folder
         */
        staticizerMainfolderName = properties.getProperty(Constants.STATICIZER_FOLDER_PATH, "E:/re3gistry-data/staticizer");

        staticizerStandardFolder = properties.getProperty(Constants.STATICIZER_STANDARD_FOLDER, "standard");
        folderStandardStaticizer = staticizerMainfolderName + folderSeparator + staticizerStandardFolder;
        new File(folderStandardStaticizer).mkdirs();

        staticizerCutomFolder = properties.getProperty(Constants.STATICIZER_CUSTOM_FOLDER, "custom");
        folderCustomStaticizer = staticizerMainfolderName + folderSeparator + staticizerCutomFolder;
        new File(folderCustomStaticizer).mkdirs();

        staticizerXSLFolder = properties.getProperty(Constants.STATICIZER_FORMATS_PATH, "E:/re3gistry-data/xsl");
        String formatList = properties.getProperty(Constants.STATICIZER_FORMATS);
        EXTENSIONS = formatList.split(",");
    }

    private void initalizateSOLRFolderAndSubFolders() {
        /**
         * initialize the SOLR standard and custom folder
         */
        staticizerSolrStandardFolder = properties.getProperty(Constants.STATICIZER_SOLR_FOLDER, "solr");
        folderSolrStaticizer = staticizerMainfolderName + folderSeparator + staticizerSolrStandardFolder;
        new File(folderSolrStaticizer).mkdirs();

        staticizerSolrCustomFolder = properties.getProperty(Constants.STATICIZER_SOLR_CUSTOM_FOLDER, "solrcustom");
        folderSolrCustomStaticizer = staticizerMainfolderName + folderSeparator + staticizerSolrCustomFolder;
        new File(folderSolrCustomStaticizer).mkdirs();

        EXTENSIONSSOLR = new String[]{properties.getProperty(Constants.STATICIZER_SOLR_FORMAT)};
    }

    public void startToStaticizeLastImportedItems(EntityManager em) {
        try {
            /**
             * check if there is any staticizer in the queued, if yes at the
             * actual staticizer will be set the queued status, else will start
             * the staticization of the items, at the end of the staticizetion,
             * will be checked if there is any staticizer in queued, if yes will
             * be started the oldest
             */
            if (!checkIfStaticizerInProgressAndCreateQueue(em)) {
                createStaticizer(em);
                checkIfStaticizerInQueue(em);
            }
        } catch (Exception ex) {
            log.error("StaticizeLastImportedItems " + ex.getMessage());
        }
    }

    private void createStaticizer(EntityManager em) throws Exception {
        ProcedurestatusMgr procedurestatusMgr = new ProcedurestatusMgr(em);
        Staticizer staticizer = new Staticizer();
        String staticizerUuid = StringUtils.createUUID(new Timestamp(new Date().getTime()) + "", Staticizer.class);

        staticizer.setUuid(staticizerUuid);
        staticizer.setDatestart(new Date());
        Procedurestatus procedurestatusInProgress = procedurestatusMgr.getStatusByUuid("1");
        staticizer.setProcedurestatus(procedurestatusInProgress);

        em.getTransaction().begin();
        em.persist(staticizer);
        em.getTransaction().commit();

        try {
            staticizeTheLastImportedItems(em, staticizer.getDatestart());

            Procedurestatus procedurestatusCompleted = procedurestatusMgr.getStatusByUuid("3");
            staticizer.setProcedurestatus(procedurestatusCompleted);

            Mail mail = new Mail();
            String subject = localizationres.getString("staticizer.mail.subject");
            String body = localizationres.getString("staticizer.mail.body.completed");
            mail.sendbyMail(request, null, subject, body);
        } catch (Exception ex) {
            Procedurestatus procedurestatusFailed = procedurestatusMgr.getStatusByUuid("2");
            staticizer.setProcedurestatus(procedurestatusFailed);
            log.error("StaticizeLastImportedItems setProcedurestatus " + ex.getMessage());

            Mail mail = new Mail();
            String subject = localizationres.getString("staticizer.mail.subject");
            String body = localizationres.getString("staticizer.mail.body.failed");
            mail.sendbyMail(request, null, subject, body);
        }

        em.getTransaction().begin();
        staticizer.setDateend(new Date());
        em.merge(staticizer);
        em.getTransaction().commit();
    }

    private void updateStaticizer(Staticizer staticizer, EntityManager em) throws Exception {
        ProcedurestatusMgr procedurestatusMgr = new ProcedurestatusMgr(em);

        try {
            Procedurestatus procedurestatusInProgress = procedurestatusMgr.getStatusByUuid("1");
            staticizer.setProcedurestatus(procedurestatusInProgress);

            em.getTransaction().begin();
            em.merge(staticizer);
            em.getTransaction().commit();

            staticizeTheLastImportedItems(em, staticizer.getDatestart());
            Procedurestatus procedurestatusCompleted = procedurestatusMgr.getStatusByUuid("3");
            staticizer.setProcedurestatus(procedurestatusCompleted);

            Mail mail = new Mail();
            String subject = localizationres.getString("staticizer.mail.subject");
            String body = localizationres.getString("staticizer.mail.body.completed");
            mail.sendbyMail(request, null, subject, body);
        } catch (Exception ex) {
            Procedurestatus procedurestatusFailed = procedurestatusMgr.getStatusByUuid("2");
            staticizer.setProcedurestatus(procedurestatusFailed);
            log.error("StaticizeLastImportedItems setProcedurestatus " + ex.getMessage());

            Mail mail = new Mail();
            String subject = localizationres.getString("staticizer.mail.subject");
            String body = localizationres.getString("staticizer.mail.body.failed");
            mail.sendbyMail(request, null, subject, body);
        }

        em.getTransaction().begin();
        staticizer.setDateend(new Date());
        em.merge(staticizer);
        em.getTransaction().commit();
    }

    private boolean checkIfStaticizerInProgressAndCreateQueue(EntityManager em) throws Exception {
        ProcedurestatusMgr procedurestatusMgr = new ProcedurestatusMgr(em);
        StaticizerMgr staticizerMgr = new StaticizerMgr(em);

        List<Staticizer> findInProgressOrderDescByDateStart = staticizerMgr.findInProgressOrderDescByDateStart();
        int size = findInProgressOrderDescByDateStart.size();
        if (size != 0) {
            Staticizer staticizer = new Staticizer();
            String staticizerUuid = StringUtils.createUUID(new Timestamp(new Date().getTime()) + "", Staticizer.class);

            staticizer.setUuid(staticizerUuid);
            staticizer.setDatestart(new Date());

            Procedurestatus procedurestatusQueue = procedurestatusMgr.getStatusByUuid("5");
            staticizer.setProcedurestatus(procedurestatusQueue);

            em.getTransaction().begin();
            em.persist(staticizer);
            em.getTransaction().commit();

            Mail mail = new Mail();
            String subject = localizationres.getString("staticizer.mail.subject");
            String body = localizationres.getString("staticizer.mail.body.queued");
            mail.sendbyMail(request, null, subject, body);

            return true;
        }
        return false;
    }

    private void checkIfStaticizerInQueue(EntityManager em) throws Exception {
        StaticizerMgr staticizerMgr = new StaticizerMgr(em);
        List<Staticizer> queueStaticizer = staticizerMgr.findQueuedOrderAscByDateStart();

        if (!queueStaticizer.isEmpty()) {
            for (Staticizer staticizer : queueStaticizer) {
                updateStaticizer(staticizer, em);
            }
            checkIfStaticizerInQueue(em);
        }
    }

    private void staticizeTheLastImportedItems(EntityManager em, Date inprogressStaticizerDatestart) {
        try {
            DataprocedureMgr dataprocedureMgr = new DataprocedureMgr(em);
            ChangelogMgr changelogMgr = new ChangelogMgr(em);

            List<Dataprocedure> dataprocedureList;
            List<Changelog> changeLogItems = new ArrayList<Changelog>();

            /**
             * if lastStartStaticizerDate is not null, than take all the data
             * procedure after the data start of last staticizer ordered by data
             * completed, else take all the data procedure ordered by data
             * completed
             */
            StaticizerMgr staticizerMgr = new StaticizerMgr(em);

            try {
                Staticizer lastCompletedStaticizer = staticizerMgr.getLastCompletedStaticizer();
                Date lastCompletedStaticizerDatestart = lastCompletedStaticizer.getDatestart();

                if (lastCompletedStaticizerDatestart != null) {
                    dataprocedureList = dataprocedureMgr.findAllBetweenDatesOrderAscByDatecompleted(lastCompletedStaticizerDatestart, inprogressStaticizerDatestart);
                } else {
                    dataprocedureList = dataprocedureMgr.findAllAfterDateOrderAscByDatecompleted(inprogressStaticizerDatestart);
                }
            } catch (Exception ex) {
                dataprocedureList = dataprocedureMgr.findAllOrderAscByDatecompleted();
            }

            /**
             * add to changeLogItems all the items of all the data procedure not
             * staticized
             */
            if (!dataprocedureList.isEmpty()) {
                for (Dataprocedure dataprocedure : dataprocedureList) {
                    List<Changelog> terms = changelogMgr.getChangelogByDataProcedure(dataprocedure);
                    changeLogItems.addAll(terms);
                }
            }

            /**
             * add the a linked map all the data procedure with the items
             * related
             */
            LinkedHashMap<String, ArrayList<Changelog>> linkedHashMap = new LinkedHashMap();
            for (Changelog changelog : changeLogItems) {
                int dataProcedureOrder = changelog.getItem().getItemclass().getDataprocedureorder();

                if (linkedHashMap.containsKey(String.valueOf(dataProcedureOrder))) {
                    linkedHashMap.get(String.valueOf(dataProcedureOrder)).add(changelog);
                } else {
                    ArrayList<Changelog> array = new ArrayList<Changelog>();
                    array.add(changelog);
                    linkedHashMap.put(String.valueOf(dataProcedureOrder), array);
                }
            }

            /**
             * order the linked map by key
             */
            linkedHashMap.keySet();
            SortedSet<String> sortedSet = new TreeSet<String>(linkedHashMap.keySet());

            LanguagecodeMgr languagecodeMgr = new LanguagecodeMgr(em);
            List<Languagecode> allLanguagecode = languagecodeMgr.findAll();

            LinkedHashMap<Item, List<Languagecode>> itemsTostaticize = new LinkedHashMap<Item, List<Languagecode>>();
            LinkedHashMap<Itemclass, List<Languagecode>> registerToStaticize = new LinkedHashMap<Itemclass, List<Languagecode>>();

            /**
             * for all the items in the linked map staticize them (with the
             * language modified or all the languages) and get the register to
             * be updated
             */
            if (linkedHashMap.size() > 0) {
                for (String string : sortedSet) {
                    ArrayList<Changelog> arrayList = linkedHashMap.get(string);

                    for (Changelog changelog : arrayList) {
                        Item item = changelog.getItem();

                        if (!itemsTostaticize.containsKey(item)) {
                            itemsTostaticize.put(item, allLanguagecode);
                        }

                        Itemclass itemclass = item.getItemclass();
                        if (itemclass.getParent() == null) {
                            if (!registerToStaticize.containsKey(itemclass)) {
                                registerToStaticize.put(itemclass, allLanguagecode);
                            }
                        }
                    }
                }
            }

            /**
             * add to the list all the folder that are created
             */
            LinkedHashMap<File, String> linkedHashMapVAR = new LinkedHashMap();
            log.info("=========== Standard && Custom Files XML, JSON, HTML, ATOM ===========");
            initalizateStaticizerStandardAndCustomFolders();
            createStandardFiles(itemsTostaticize, linkedHashMapVAR, registerToStaticize, em);
            log.info("======================================================================");
            log.info("================================= VAR Files ==========================");
            createVARFiles(linkedHashMapVAR, em);
            log.info("======================================================================");
            log.info("==========================SOLR Files =================================");
            initalizateSOLRFolderAndSubFolders();
            createSOLRFiles(itemsTostaticize, registerToStaticize, em);
            log.info("======================================================================");

        } catch (Exception e) {
            log.error("@@ An error occurs while executing the operations: " + e.getMessage());
        }

    }

    private void createSOLRFiles(LinkedHashMap<Item, List<Languagecode>> itemsTostaticize, LinkedHashMap<Itemclass, List<Languagecode>> registerToStaticize, EntityManager em) throws Exception {
        /**
         * Generate the SOLR standard/custom files
         */
        LocalizationMgr localizationMgr = new LocalizationMgr(em);
        StaticizeLastImportedItems staticizeLastImportedItems = new StaticizeLastImportedItems(this, em);
        SolrLastImportedItems solrLastImportedItems = new SolrLastImportedItems(this, em);

        for (Map.Entry<Item, List<Languagecode>> entry : itemsTostaticize.entrySet()) {
            Item item = entry.getKey();

            CollectionItemStandard collectionItemStandard = new CollectionItemStandard();
            ArrayList<ItemStandard> arrayListItemStandard = new ArrayList<ItemStandard>();

            List<Localization> localizationList = localizationMgr.findByItem(item);
            for (Localization localization : localizationList) {
                ItemStandard itemStandard = staticizeLastImportedItems.createItemStandard(item, localization, localization.getLanguage());
                if (itemStandard.getVersionnumber() == 0) {
                    arrayListItemStandard.add(itemStandard);
                }
            }
            if (arrayListItemStandard.size() > 0) {
                collectionItemStandard.setItemStandard(arrayListItemStandard);

                ContainerCollectionItemStandard containerCollectionItemStandard = new ContainerCollectionItemStandard();
                containerCollectionItemStandard.setCollectionItemStandard(collectionItemStandard);

                solrLastImportedItems.createItemStandardSOLRFile(item, containerCollectionItemStandard);
            }
        }
        /**
         * SOLR registry
         */
        SolrRegistryStaticizer solrRegistryStaticizer = new SolrRegistryStaticizer(this, em);
        CollectionRegistryStandard collectionRegistryStandard = new CollectionRegistryStandard();
        ArrayList<RegistryStandard> registryStandardaArrayList = solrRegistryStaticizer.addRegistryFiles();
        collectionRegistryStandard.setRegistryStandard(registryStandardaArrayList);
        ContainerCollectionRegistryStandard containerCollectionRegistryStandard = new ContainerCollectionRegistryStandard();
        containerCollectionRegistryStandard.setCollectionRegistryStandard(collectionRegistryStandard);
        solrRegistryStaticizer.createSOLRRegistryFile(containerCollectionRegistryStandard);

        /**
         * SOLR register
         */
        SolrRegisterStaticizer solrRegisterStaticizer = new SolrRegisterStaticizer(this);
        for (Map.Entry<Itemclass, List<Languagecode>> entry : registerToStaticize.entrySet()) {
            Itemclass itemclass = entry.getKey();
            Register register = itemclass.getRegister();

            CollectionRegisterStandard collectionRegisterStandard = new CollectionRegisterStandard();
            ArrayList<RegisterStandard> registerStaticizerArrayList = new ArrayList<RegisterStandard>();

            List<Localization> localizationList = localizationMgr.findRegisterLocalization(register);
            for (Localization localization : localizationList) {
                RegisterStaticizer registerStaticizer = new RegisterStaticizer(this, em, staticizeLastImportedItems);
                registerStaticizerArrayList.add(registerStaticizer.addRegisterStandard(register, localization));
            }
            collectionRegisterStandard.setRegisterStandard(registerStaticizerArrayList);

            ContainerCollectionRegisterStandard containerCollectionRegisterStandard = new ContainerCollectionRegisterStandard();
            containerCollectionRegisterStandard.setCollectionRegisterStandard(collectionRegisterStandard);

            solrRegisterStaticizer.createSOLRRegisterFile(containerCollectionRegisterStandard, register);
        }
    }

    private void createVARFiles(LinkedHashMap<File, String> linkedHashMap, EntityManager em) throws Exception {
        /**
         * Generate VAR files
         */
        VarGenerator varGenerator = new VarGenerator(getServletContext(), this);
        for (File file : linkedHashMap.keySet()) {
            varGenerator.writeVar(file);
        }
    }

    private StaticizeLastImportedItems createStandardFiles(LinkedHashMap<Item, List<Languagecode>> itemsTostaticize, LinkedHashMap<File, String> linkedHashMap, LinkedHashMap<Itemclass, List<Languagecode>> registerToStaticize, EntityManager em) throws Exception {
        /**
         * read/write the items
         */
        List<File> folderItemList = new ArrayList<File>();
        LocalizationMgr localizationMgr = new LocalizationMgr(em);
        LanguagecodeMgr languagecodeMgr = new LanguagecodeMgr(em);
        Languagecode masterLanguage = languagecodeMgr.getMasterLanguagecode();

        StaticizeLastImportedItems staticizeLastImportedItems = new StaticizeLastImportedItems(this, em);
        for (Map.Entry<Item, List<Languagecode>> entry : itemsTostaticize.entrySet()) {
            Item item = entry.getKey();
            List<Languagecode> list = entry.getValue();
            for (Languagecode languagecode : list) {
                Localization itemLocalization;
                try {
                    itemLocalization = localizationMgr.findByItemAndLanguagecode(item, languagecode);
                    if (itemLocalization != null) {
                        folderItemList.addAll(staticizeLastImportedItems.createItemFiles(item, itemLocalization, languagecode));
                    } else {
                        itemLocalization = localizationMgr.findByItemAndLanguagecode(item, masterLanguage);
                        folderItemList.addAll(staticizeLastImportedItems.createItemFiles(item, itemLocalization, languagecode));
                    }
                } catch (Exception ex) {
                    itemLocalization = localizationMgr.findByItemAndLanguagecode(item, masterLanguage);
                    folderItemList.addAll(staticizeLastImportedItems.createItemFiles(item, itemLocalization, languagecode));
                }
            }
        }

        /**
         * create the registry
         */
        RegistryStaticizer registryStaticizer = new RegistryStaticizer(this, em);
        folderItemList.addAll(registryStaticizer.addRegistryFiles());
        /**
         * create the register
         */
        for (Map.Entry<Itemclass, List<Languagecode>> entry : registerToStaticize.entrySet()) {
            Itemclass itemclass = entry.getKey();
            List<Languagecode> list = entry.getValue();
            for (Iterator<Languagecode> it = list.iterator(); it.hasNext();) {
                Languagecode languagecode = it.next();
                RegisterStaticizer registerStaticizer = new RegisterStaticizer(this, em, staticizeLastImportedItems);
                folderItemList.add(registerStaticizer.addRegisterFiles(itemclass.getRegister(), languagecode));
            }
        }

        for (File file : folderItemList) {
            if (!linkedHashMap.containsKey(file)) {
                linkedHashMap.put(file, "");
            }
        }

        return staticizeLastImportedItems;
    }

    public String getFolderSeparator() {
        return folderSeparator;
    }

    public String getFolderCustomStaticizer() {
        return folderCustomStaticizer;
    }

    public String getFolderStandardStaticizer() {
        return folderStandardStaticizer;
    }

    public String getFolderSolrStaticizer() {
        return folderSolrStaticizer;
    }

    public String getFolderSolrCustomStaticizer() {
        return folderSolrCustomStaticizer;
    }

    public String getStaticizerXSLFolder() {
        return staticizerXSLFolder;
    }

    public String[] getEXTENSIONS() {
        return EXTENSIONS;
    }

    public String[] getEXTENSIONSSOLR() {
        return EXTENSIONSSOLR;
    }

    public static Properties getProperties() {
        return properties;
    }
}
